Class: Cadenya::Models::AIProviderConfigOpenAICompatible

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/ai_provider_config_openai_compatible.rb,
sig/cadenya/models/ai_provider_config_openai_compatible.rbs

Defined Under Namespace

Modules: Type Classes: OpenAICompatible

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(base_url:) ⇒ Object

OpenAICompatibleConfig configures a generic endpoint that speaks the OpenAI Chat Completions API. The base URL is required and its model catalog is discovered live via GET base_url/models.

Parameters:

  • base_url (String)


# File 'lib/cadenya/models/ai_provider_config_openai_compatible.rb', line 21

Instance Attribute Details

#openai_compatibleCadenya::Models::AIProviderConfigOpenAICompatible::OpenAICompatible

OpenAICompatibleConfig configures a generic endpoint that speaks the OpenAI Chat Completions API. The base URL is required and its model catalog is discovered live via GET base_url/models.

Parameters:

  • value (Cadenya::AIProviderConfigOpenAICompatible::OpenAICompatible)

Returns:



12
13
14
# File 'lib/cadenya/models/ai_provider_config_openai_compatible.rb', line 12

required :openai_compatible,
-> { Cadenya::AIProviderConfigOpenAICompatible::OpenAICompatible },
api_name: :openaiCompatible

#typeSymbol, Cadenya::Models::AIProviderConfigOpenAICompatible::Type

Parameters:

  • value (Cadenya::Models::AIProviderConfigOpenAICompatible::type_)

Returns:



19
# File 'lib/cadenya/models/ai_provider_config_openai_compatible.rb', line 19

required :type, enum: -> { Cadenya::AIProviderConfigOpenAICompatible::Type }

Instance Method Details

#to_hash{

Returns:

  • ({)


19
# File 'sig/cadenya/models/ai_provider_config_openai_compatible.rbs', line 19

def to_hash: -> {