Module: Cadenya::Models::AIProviderKeySpec::Credentials

Extended by:
Internal::Type::Union
Defined in:
lib/cadenya/models/ai_provider_key_spec.rb,
sig/cadenya/models/ai_provider_key_spec.rbs

Overview

AIProviderCredential is the secret material used to authenticate with a provider. The set case must correspond to AIProviderKeySpec.provider. The server encrypts the serialized message at rest and never returns it on reads.

See Also:

  • Cadenya::Models::AIProviderKeySpec#credentials

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.variants::Array[Cadenya::Models::AIProviderKeySpec::credentials]

Returns:

  • (::Array[Cadenya::Models::AIProviderKeySpec::credentials])


59
# File 'sig/cadenya/models/ai_provider_key_spec.rbs', line 59

def self?.variants: -> ::Array[Cadenya::Models::AIProviderKeySpec::credentials]