Class: Cadenya::Models::APIKeyCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cadenya/models/api_key_create_params.rb

Overview

Defined Under Namespace

Classes: Metadata

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Cadenya::Internal::Type::BaseModel

Instance Attribute Details

#initial_workspace_idsArray<String>?

Workspaces this API key will have access to on creation. Optional — a key can be created with no workspace access and granted later via AddAPIKeyWorkspace.

Returns:

  • (Array<String>, nil)


29
30
31
# File 'lib/cadenya/models/api_key_create_params.rb', line 29

optional :initial_workspace_ids,
Cadenya::Internal::Type::ArrayOf[String],
api_name: :initialWorkspaceIds

#metadataCadenya::Models::APIKeyCreateParams::Metadata

CreateAccountResourceMetadata contains the user-provided fields for creating an account-scoped resource. Read-only fields (id, account_id, profile_id) are excluded since they are set by the server.



16
# File 'lib/cadenya/models/api_key_create_params.rb', line 16

required :metadata, -> { Cadenya::APIKeyCreateParams::Metadata }

#specCadenya::Models::APIKeySpec

Configuration for an API key.



22
# File 'lib/cadenya/models/api_key_create_params.rb', line 22

required :spec, -> { Cadenya::APIKeySpec }