Class: Cadenya::Models::APIKeyCreateParams::Metadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::APIKeyCreateParams::Metadata
- Defined in:
- lib/cadenya/models/api_key_create_params.rb
Instance Attribute Summary collapse
-
#external_id ⇒ String?
External ID for the resource (e.g., a workflow ID from an external system).
-
#labels ⇒ Hash{Symbol=>String}?
Arbitrary key-value pairs for categorization and filtering Examples: “production”, “team”: “platform”, “version”: “v2”.
-
#name ⇒ String
Human-readable name for the resource (e.g., “Production API Key”, “Staging Workspace”).
Instance Method Summary collapse
-
#initialize(name:, external_id: nil, labels: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Metadata for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, external_id: nil, labels: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::APIKeyCreateParams::Metadata for more details.
CreateAccountResourceMetadata contains the user-provided fields for creating an account-scoped resource. Read-only fields (id, account_id, profile_id) are excluded since they are set by the server.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/cadenya/models/api_key_create_params.rb', line 45 class Metadata < Cadenya::Internal::Type::BaseModel # @!attribute name # Human-readable name for the resource (e.g., "Production API Key", "Staging # Workspace") # # @return [String] required :name, String # @!attribute external_id # External ID for the resource (e.g., a workflow ID from an external system) # # @return [String, nil] optional :external_id, String, api_name: :externalId # @!attribute labels # Arbitrary key-value pairs for categorization and filtering Examples: # {"environment": "production", "team": "platform", "version": "v2"} # # @return [Hash{Symbol=>String}, nil] optional :labels, Cadenya::Internal::Type::HashOf[String] # @!method initialize(name:, external_id: nil, labels: nil) # Some parameter documentations has been truncated, see # {Cadenya::Models::APIKeyCreateParams::Metadata} for more details. # # CreateAccountResourceMetadata contains the user-provided fields for creating an # account-scoped resource. Read-only fields (id, account_id, profile_id) are # excluded since they are set by the server. # # @param name [String] Human-readable name for the resource (e.g., "Production API Key", "Staging Works # # @param external_id [String] External ID for the resource (e.g., a workflow ID from an external system) # # @param labels [Hash{Symbol=>String}] Arbitrary key-value pairs for categorization and filtering end |
Instance Attribute Details
#external_id ⇒ String?
External ID for the resource (e.g., a workflow ID from an external system)
57 |
# File 'lib/cadenya/models/api_key_create_params.rb', line 57 optional :external_id, String, api_name: :externalId |
#labels ⇒ Hash{Symbol=>String}?
Arbitrary key-value pairs for categorization and filtering Examples: “production”, “team”: “platform”, “version”: “v2”
64 |
# File 'lib/cadenya/models/api_key_create_params.rb', line 64 optional :labels, Cadenya::Internal::Type::HashOf[String] |
#name ⇒ String
Human-readable name for the resource (e.g., “Production API Key”, “Staging Workspace”)
51 |
# File 'lib/cadenya/models/api_key_create_params.rb', line 51 required :name, String |