Class: Cadenya::Models::APIKeyInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/api_key_info.rb,
sig/cadenya/models/api_key_info.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_by: nil, workspaces_preview: nil, workspaces_total: nil) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::APIKeyInfo for more details.

Parameters:

  • created_by (Cadenya::Models::Profile) (defaults to: nil)

    A profile identifies a user or non-human principal (such as an API key)

  • workspaces_preview (Array<Cadenya::Models::BareMetadata>) (defaults to: nil)

    Up to a small number of workspaces this key has access to, intended

  • workspaces_total (Integer) (defaults to: nil)

    Total number of workspaces this key has access to.



# File 'lib/cadenya/models/api_key_info.rb', line 32

Instance Attribute Details

#created_byCadenya::Profile? (readonly)

Returns the value of attribute created_by.

Returns:



11
12
13
# File 'sig/cadenya/models/api_key_info.rbs', line 11

def created_by
  @created_by
end

#workspaces_preview::Array[Cadenya::BareMetadata]? (readonly)

Returns the value of attribute workspaces_preview.

Returns:



15
16
17
# File 'sig/cadenya/models/api_key_info.rbs', line 15

def workspaces_preview
  @workspaces_preview
end

#workspaces_totalInteger? (readonly)

Returns the value of attribute workspaces_total.

Returns:

  • (Integer, nil)


21
22
23
# File 'sig/cadenya/models/api_key_info.rbs', line 21

def workspaces_total
  @workspaces_total
end

Instance Method Details

#created_by=Cadenya::Profile (readonly)

Parameters:

Returns:



13
# File 'sig/cadenya/models/api_key_info.rbs', line 13

def created_by=: (Cadenya::Profile) -> Cadenya::Profile

#to_hash{

Returns:

  • ({)


31
# File 'sig/cadenya/models/api_key_info.rbs', line 31

def to_hash: -> {

#workspaces_preview=Object (readonly)



17
# File 'sig/cadenya/models/api_key_info.rbs', line 17

def workspaces_preview=: (

#workspaces_total=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


23
# File 'sig/cadenya/models/api_key_info.rbs', line 23

def workspaces_total=: (Integer) -> Integer