Class: Cadenya::Models::APIKeyUpdateParams::Metadata

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/api_key_update_params.rb,
sig/cadenya/models/api_key_update_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, external_id: nil, labels: nil) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::APIKeyUpdateParams::Metadata for more details.

UpdateAccountResourceMetadata contains the user-provided fields for updating an account-scoped resource. Read-only fields (id, account_id, profile_id) are excluded since they are set by the server.

Parameters:

  • name (String)

    Human-readable name for the resource (e.g., "Production API Key", "Staging Works

  • external_id (String) (defaults to: nil)

    External ID for the resource (e.g., a workflow ID from an external system)

  • labels (Hash{Symbol=>String}) (defaults to: nil)

    Key-value pairs for categorization and filtering. Values are 0-63



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/cadenya/models/api_key_update_params.rb', line 49

class Metadata < Cadenya::Internal::Type::BaseModel
  # @!attribute name
  #   Human-readable name for the resource (e.g., "Production API Key", "Staging
  #   Workspace")
  #
  #   @return [String]
  required :name, String

  # @!attribute external_id
  #   External ID for the resource (e.g., a workflow ID from an external system)
  #
  #   @return [String, nil]
  optional :external_id, String, api_name: :externalId

  # @!attribute labels
  #   Key-value pairs for categorization and filtering. Values are 0-63 alphanumeric
  #   characters with "-", "\_", or "." allowed between; keys follow the same shape
  #   and additionally accept an optional DNS-subdomain prefix (e.g. "cadenya.com/")
  #   of at most 253 characters. Examples: {"environment": "production", "team":
  #   "platform", "version": "v2"}
  #
  #   @return [Hash{Symbol=>String}, nil]
  optional :labels, Cadenya::Internal::Type::HashOf[String]

  # @!method initialize(name:, external_id: nil, labels: nil)
  #   Some parameter documentations has been truncated, see
  #   {Cadenya::Models::APIKeyUpdateParams::Metadata} for more details.
  #
  #   UpdateAccountResourceMetadata contains the user-provided fields for updating an
  #   account-scoped resource. Read-only fields (id, account_id, profile_id) are
  #   excluded since they are set by the server.
  #
  #   @param name [String] Human-readable name for the resource (e.g., "Production API Key", "Staging Works
  #
  #   @param external_id [String] External ID for the resource (e.g., a workflow ID from an external system)
  #
  #   @param labels [Hash{Symbol=>String}] Key-value pairs for categorization and filtering. Values are 0-63
end

Instance Attribute Details

#external_idString?

External ID for the resource (e.g., a workflow ID from an external system)

Parameters:

  • (String)

Returns:

  • (String, nil)


61
# File 'lib/cadenya/models/api_key_update_params.rb', line 61

optional :external_id, String, api_name: :externalId

#labelsHash{Symbol=>String}?

Key-value pairs for categorization and filtering. Values are 0-63 alphanumeric characters with "-", "_", or "." allowed between; keys follow the same shape and additionally accept an optional DNS-subdomain prefix (e.g. "cadenya.com/") of at most 253 characters. Examples: "production", "team": "platform", "version": "v2"

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


71
# File 'lib/cadenya/models/api_key_update_params.rb', line 71

optional :labels, Cadenya::Internal::Type::HashOf[String]

#nameString

Human-readable name for the resource (e.g., "Production API Key", "Staging Workspace")

Parameters:

  • value (String)

Returns:

  • (String)


55
# File 'lib/cadenya/models/api_key_update_params.rb', line 55

required :name, String

Instance Method Details

#to_hash{

Returns:

  • ({)


68
# File 'sig/cadenya/models/api_key_update_params.rbs', line 68

def to_hash: -> {