Class: Cadenya::Models::AgentCreateParams::DefaultVariation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/agent_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(metadata:, spec:) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::AgentCreateParams::DefaultVariation for more details.

Create agent variation request

Parameters:



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/cadenya/models/agent_create_params.rb', line 51

class DefaultVariation < Cadenya::Internal::Type::BaseModel
  # @!attribute metadata
  #   CreateResourceMetadata contains the user-provided fields for creating a
  #   workspace-scoped resource. Read-only fields (id, account_id, workspace_id,
  #   profile_id, created_at) are excluded since they are set by the server.
  #
  #   @return [Cadenya::Models::CreateResourceMetadata]
  required :metadata, -> { Cadenya::CreateResourceMetadata }

  # @!attribute spec
  #   AgentVariationSpec defines the operational configuration for a variation
  #
  #   @return [Cadenya::Models::Agents::AgentVariationSpec]
  required :spec, -> { Cadenya::Agents::AgentVariationSpec }

  # @!method initialize(metadata:, spec:)
  #   Some parameter documentations has been truncated, see
  #   {Cadenya::Models::AgentCreateParams::DefaultVariation} for more details.
  #
  #   Create agent variation request
  #
  #   @param metadata [Cadenya::Models::CreateResourceMetadata] CreateResourceMetadata contains the user-provided fields for creating
  #
  #   @param spec [Cadenya::Models::Agents::AgentVariationSpec] AgentVariationSpec defines the operational configuration for a variation
end

Instance Attribute Details

#metadataCadenya::Models::CreateResourceMetadata

CreateResourceMetadata contains the user-provided fields for creating a workspace-scoped resource. Read-only fields (id, account_id, workspace_id, profile_id, created_at) are excluded since they are set by the server.



58
# File 'lib/cadenya/models/agent_create_params.rb', line 58

required :metadata, -> { Cadenya::CreateResourceMetadata }

#specCadenya::Models::Agents::AgentVariationSpec

AgentVariationSpec defines the operational configuration for a variation



64
# File 'lib/cadenya/models/agent_create_params.rb', line 64

required :spec, -> { Cadenya::Agents::AgentVariationSpec }