Class: Cadenya::Models::AgentInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/agent_info.rb,
sig/cadenya/models/agent_info.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_by: nil, variation_count: nil) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::AgentInfo for more details.

AgentInfo contains simple information about an agent for display or quick reference

Parameters:

  • created_by (Cadenya::Models::Profile) (defaults to: nil)

    A profile identifies a user or non-human principal (such as an API key)

  • variation_count (Integer) (defaults to: nil)


# File 'lib/cadenya/models/agent_info.rb', line 21

Instance Attribute Details

#created_byCadenya::Models::Profile?

A profile identifies a user or non-human principal (such as an API key) at the account level. Profiles are account-scoped and can be granted access to multiple workspaces.

Parameters:

Returns:



12
# File 'lib/cadenya/models/agent_info.rb', line 12

optional :created_by, -> { Cadenya::Profile }, api_name: :createdBy

#variation_countInteger? (readonly)

Returns the value of attribute variation_count.

Returns:

  • (Integer, nil)


10
11
12
# File 'sig/cadenya/models/agent_info.rbs', line 10

def variation_count
  @variation_count
end

Instance Method Details

#to_hash{ created_by: Cadenya::Profile, variation_count: Integer }

Returns:



19
# File 'sig/cadenya/models/agent_info.rbs', line 19

def to_hash: -> { created_by: Cadenya::Profile, variation_count: Integer }

#variation_count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


12
# File 'sig/cadenya/models/agent_info.rbs', line 12

def variation_count=: (Integer) -> Integer