Class: Cadenya::Models::AgentVariationEntry
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::AgentVariationEntry
- Defined in:
- lib/cadenya/models/agent_variation_entry.rb
Instance Attribute Summary collapse
-
#assignments ⇒ Array<Cadenya::Models::VariationAssignmentEntry>?
Reconciled list — server adjusts the variation’s assignments to exactly this set when the variation is bundle-owned.
- #labels ⇒ Hash{Symbol=>String}?
-
#memory_layers ⇒ Array<Cadenya::Models::VariationMemoryLayerEntry>?
Reconciled list of memory layer assignments.
- #name ⇒ String
-
#spec ⇒ Cadenya::Models::Agents::AgentVariationSpec
AgentVariationSpec defines the operational configuration for a variation.
Instance Method Summary collapse
-
#initialize(name:, spec:, assignments: nil, labels: nil, memory_layers: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AgentVariationEntry for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, spec:, assignments: nil, labels: nil, memory_layers: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::AgentVariationEntry for more details.
|
|
# File 'lib/cadenya/models/agent_variation_entry.rb', line 37
|
Instance Attribute Details
#assignments ⇒ Array<Cadenya::Models::VariationAssignmentEntry>?
Reconciled list — server adjusts the variation’s assignments to exactly this set when the variation is bundle-owned.
22 |
# File 'lib/cadenya/models/agent_variation_entry.rb', line 22 optional :assignments, -> { Cadenya::Internal::Type::ArrayOf[Cadenya::VariationAssignmentEntry] } |
#labels ⇒ Hash{Symbol=>String}?
27 |
# File 'lib/cadenya/models/agent_variation_entry.rb', line 27 optional :labels, Cadenya::Internal::Type::HashOf[String] |
#memory_layers ⇒ Array<Cadenya::Models::VariationMemoryLayerEntry>?
Reconciled list of memory layer assignments. Up to 10 entries.
33 34 35 |
# File 'lib/cadenya/models/agent_variation_entry.rb', line 33 optional :memory_layers, -> { Cadenya::Internal::Type::ArrayOf[Cadenya::VariationMemoryLayerEntry] }, api_name: :memoryLayers |
#name ⇒ String
9 |
# File 'lib/cadenya/models/agent_variation_entry.rb', line 9 required :name, String |
#spec ⇒ Cadenya::Models::Agents::AgentVariationSpec
AgentVariationSpec defines the operational configuration for a variation
15 |
# File 'lib/cadenya/models/agent_variation_entry.rb', line 15 required :spec, -> { Cadenya::Agents::AgentVariationSpec } |