Class: Cadenya::Models::Agents::AgentVariationInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/agents/agent_variation_info.rb,
sig/cadenya/models/agents/agent_variation_info.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



65
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 65

def initialize: (

Instance Attribute Details

#assignments::Array[Cadenya::Agents::VariationAssignment]? (readonly)

Returns the value of attribute assignments.

Returns:

  • (::Array[Cadenya::Agents::VariationAssignment], nil)


33
34
35
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 33

def assignments
  @assignments
end

#created_byCadenya::Models::Profile?

A profile identifies a user or non-human principal (such as an API key) at the account level. Profiles are account-scoped and can be granted access to multiple workspaces.

Parameters:

Returns:



13
# File 'lib/cadenya/models/agents/agent_variation_info.rb', line 13

optional :created_by, -> { Cadenya::Profile }, api_name: :createdBy

#feedback_countInteger?

Total number of objective feedbacks received for this variation

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


19
# File 'lib/cadenya/models/agents/agent_variation_info.rb', line 19

optional :feedback_count, Integer, api_name: :feedbackCount

#memory_layer_assignments::Array[Cadenya::Agents::VariationMemoryLayerAssignment]? (readonly)

Returns the value of attribute memory_layer_assignments.

Returns:

  • (::Array[Cadenya::Agents::VariationMemoryLayerAssignment], nil)


39
40
41
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 39

def memory_layer_assignments
  @memory_layer_assignments
end

#memory_layer_countInteger? (readonly)

Returns the value of attribute memory_layer_count.

Returns:

  • (Integer, nil)


45
46
47
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 45

def memory_layer_count
  @memory_layer_count
end

#modelCadenya::ResourceMetadata? (readonly)

Returns the value of attribute model.

Returns:



49
50
51
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 49

def model
  @model
end

#scoreFloat?

Thompson Sampling score: posterior mean of Beta(ts_alpha, ts_beta). Range [0, 1] where 0.5 = neutral, >0.5 = positive, <0.5 = negative.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


26
# File 'lib/cadenya/models/agents/agent_variation_info.rb', line 26

optional :score, Float

#sub_agent_countInteger? (readonly)

Returns the value of attribute sub_agent_count.

Returns:

  • (Integer, nil)


53
54
55
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 53

def sub_agent_count
  @sub_agent_count
end

#tool_countInteger? (readonly)

Returns the value of attribute tool_count.

Returns:

  • (Integer, nil)


57
58
59
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 57

def tool_count
  @tool_count
end

#tool_set_countInteger? (readonly)

Returns the value of attribute tool_set_count.

Returns:

  • (Integer, nil)


61
62
63
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 61

def tool_set_count
  @tool_set_count
end

Instance Method Details

#assignments=Object (readonly)



35
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 35

def assignments=: (

#memory_layer_assignments=Object (readonly)



41
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 41

def memory_layer_assignments=: (

#memory_layer_count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


47
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 47

def memory_layer_count=: (Integer) -> Integer

#model=Cadenya::ResourceMetadata (readonly)



51
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 51

def model=: (Cadenya::ResourceMetadata) -> Cadenya::ResourceMetadata

#sub_agent_count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


55
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 55

def sub_agent_count=: (Integer) -> Integer

#to_hash{

Returns:

  • ({)


78
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 78

def to_hash: -> {

#tool_count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


59
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 59

def tool_count=: (Integer) -> Integer

#tool_set_count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


63
# File 'sig/cadenya/models/agents/agent_variation_info.rbs', line 63

def tool_set_count=: (Integer) -> Integer