Class: Cadenya::Models::Agents::CompactionConfigToolResultClearingStrategy
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Agents::CompactionConfigToolResultClearingStrategy
- Defined in:
- lib/cadenya/models/agents/compaction_config_tool_result_clearing_strategy.rb
Instance Attribute Summary collapse
-
#preserve_recent_results ⇒ Integer?
Number of most recent tool call results to keep intact.
Instance Method Summary collapse
-
#initialize(preserve_recent_results: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CompactionConfigToolResultClearingStrategy for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(preserve_recent_results: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::Agents::CompactionConfigToolResultClearingStrategy for more details.
ToolResultClearingStrategy configures clearing of older tool result content.
|
|
# File 'lib/cadenya/models/agents/compaction_config_tool_result_clearing_strategy.rb', line 15
|
Instance Attribute Details
#preserve_recent_results ⇒ Integer?
Number of most recent tool call results to keep intact. Older tool results have their content replaced with “[result cleared]” while preserving the assistant tool call message (function name, arguments). Default: 2
13 |
# File 'lib/cadenya/models/agents/compaction_config_tool_result_clearing_strategy.rb', line 13 optional :preserve_recent_results, Integer, api_name: :preserveRecentResults |