Class: Cadenya::Models::Agents::FeedbackListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cadenya/models/agents/feedback_list_params.rb

Overview

Defined Under Namespace

Modules: Sentiment

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workspace_id:, agent_id:, agent_variation_id: nil, created_after: nil, created_before: nil, cursor: nil, include_info: nil, limit: nil, query: nil, sentiment: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::Agents::FeedbackListParams for more details.

Parameters:

  • workspace_id (String)
  • agent_id (String)
  • agent_variation_id (String) (defaults to: nil)

    Optional filter to limit results to feedback on objectives run by a single

  • created_after (Time) (defaults to: nil)

    Inclusive lower bound on feedback creation time.

  • created_before (Time) (defaults to: nil)

    Exclusive upper bound on feedback creation time.

  • cursor (String) (defaults to: nil)

    Pagination cursor from previous response.

  • include_info (Boolean) (defaults to: nil)

    When set to true you may use more of your alloted API rate-limit

  • limit (Integer) (defaults to: nil)

    Maximum number of results to return.

  • query (String) (defaults to: nil)

    Free-text search applied to the feedback comment. Case-insensitive substring mat

  • sentiment (Symbol, Cadenya::Models::Agents::FeedbackListParams::Sentiment) (defaults to: nil)

    Filter by sentiment. UNSPECIFIED returns feedback regardless of score.

  • request_options (Cadenya::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 71

Instance Attribute Details

#agent_idString

Returns:

  • (String)


19
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 19

required :agent_id, String

#agent_variation_idString?

Optional filter to limit results to feedback on objectives run by a single agent variation. Supports “external_id:” prefix for external IDs.

Returns:

  • (String, nil)


26
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 26

optional :agent_variation_id, String

#created_afterTime?

Inclusive lower bound on feedback creation time.

Returns:

  • (Time, nil)


32
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 32

optional :created_after, Time

#created_beforeTime?

Exclusive upper bound on feedback creation time.

Returns:

  • (Time, nil)


38
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 38

optional :created_before, Time

#cursorString?

Pagination cursor from previous response.

Returns:

  • (String, nil)


44
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 44

optional :cursor, String

#include_infoBoolean?

When set to true you may use more of your alloted API rate-limit

Returns:

  • (Boolean, nil)


50
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 50

optional :include_info, Cadenya::Internal::Type::Boolean

#limitInteger?

Maximum number of results to return.

Returns:

  • (Integer, nil)


56
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 56

optional :limit, Integer

#queryString?

Free-text search applied to the feedback comment. Case-insensitive substring match.

Returns:

  • (String, nil)


63
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 63

optional :query, String

#sentimentSymbol, ...

Filter by sentiment. UNSPECIFIED returns feedback regardless of score.



69
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 69

optional :sentiment, enum: -> { Cadenya::Agents::FeedbackListParams::Sentiment }

#workspace_idString

Returns:

  • (String)


14
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 14

required :workspace_id, String