Class: Cadenya::Models::Agents::VariationAddAssignmentParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Agents::VariationAddAssignmentParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cadenya/models/agents/variation_add_assignment_params.rb,
sig/cadenya/models/agents/variation_add_assignment_params.rbs
Overview
Defined Under Namespace
Modules: Body
Instance Attribute Summary collapse
- #agent_id ⇒ String
-
#body ⇒ Cadenya::Models::Agents::AddAgentVariationAssignmentRequestToolID, ...
Attach a single tool, tool set, or sub-agent to a variation.
- #variation_id ⇒ String
- #workspace_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(agent_id:, variation_id:, body:, workspace_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see VariationAddAssignmentParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_id:, variation_id:, body:, workspace_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::Agents::VariationAddAssignmentParams for more details.
|
|
# File 'lib/cadenya/models/agents/variation_add_assignment_params.rb', line 34
|
Instance Attribute Details
#agent_id ⇒ String
19 |
# File 'lib/cadenya/models/agents/variation_add_assignment_params.rb', line 19 required :agent_id, String |
#body ⇒ Cadenya::Models::Agents::AddAgentVariationAssignmentRequestToolID, ...
Attach a single tool, tool set, or sub-agent to a variation. Exactly one of the target fields must be set; the assignment kind is inferred from the populated field.
32 |
# File 'lib/cadenya/models/agents/variation_add_assignment_params.rb', line 32 required :body, union: -> { Cadenya::Agents::VariationAddAssignmentParams::Body } |
#variation_id ⇒ String
24 |
# File 'lib/cadenya/models/agents/variation_add_assignment_params.rb', line 24 required :variation_id, String |
#workspace_id ⇒ String?
14 |
# File 'lib/cadenya/models/agents/variation_add_assignment_params.rb', line 14 optional :workspace_id, String |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/cadenya/models/agents/variation_add_assignment_params.rbs', line 35
def to_hash: -> {
|