Class: Cadenya::Models::ApprovalRequirementFilter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ApprovalRequirementFilter
- Defined in:
- lib/cadenya/models/approval_requirement_filter.rb
Instance Attribute Summary collapse
- #always ⇒ Boolean?
-
#only ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting).
Instance Method Summary collapse
-
#initialize(always: nil, only: nil) ⇒ Object
constructor
Approval filters that will automatically set the approval requirement on tools synced from an external source.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(always: nil, only: nil) ⇒ Object
Approval filters that will automatically set the approval requirement on tools synced from an external source
|
|
# File 'lib/cadenya/models/approval_requirement_filter.rb', line 17
|
Instance Attribute Details
#always ⇒ Boolean?
9 |
# File 'lib/cadenya/models/approval_requirement_filter.rb', line 9 optional :always, Cadenya::Internal::Type::Boolean |
#only ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting)
15 |
# File 'lib/cadenya/models/approval_requirement_filter.rb', line 15 optional :only, -> { Cadenya::ToolFilter } |