Class: Cadenya::Models::BareMetadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::BareMetadata
- Defined in:
- lib/cadenya/models/bare_metadata.rb,
sig/cadenya/models/bare_metadata.rbs
Instance Attribute Summary collapse
-
#id ⇒ String?
readonly
Returns the value of attribute id.
-
#name ⇒ String?
readonly
Returns the value of attribute name.
Instance Method Summary collapse
- #id ⇒ String readonly
-
#initialize(id: nil, name: nil) ⇒ BareMetadata
constructor
Some parameter documentations has been truncated, see BareMetadata for more details.
- #name ⇒ String readonly
- #to_hash ⇒ { id: String, name: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, name: nil) ⇒ BareMetadata
Some parameter documentations has been truncated, see Cadenya::Models::BareMetadata for more details.
BareMetadata contains the minimal metadata for a resource: the ID and an optional human-readable name. These are used for reference fields where the full metadata (account scoping, timestamps, labels, external IDs) is not needed — e.g., the tool references inside an agent variation spec or the tools assigned to an objective. Both fields are server-populated; clients provide IDs through sibling fields rather than by constructing a BareMetadata themselves.
|
|
# File 'lib/cadenya/models/bare_metadata.rb', line 21
|
Instance Attribute Details
#id ⇒ String? (readonly)
Returns the value of attribute id.
6 7 8 |
# File 'sig/cadenya/models/bare_metadata.rbs', line 6 def id @id end |
#name ⇒ String? (readonly)
Returns the value of attribute name.
10 11 12 |
# File 'sig/cadenya/models/bare_metadata.rbs', line 10 def name @name end |
Instance Method Details
#id= ⇒ String (readonly)
8 |
# File 'sig/cadenya/models/bare_metadata.rbs', line 8
def id=: (String) -> String
|
#name= ⇒ String (readonly)
12 |
# File 'sig/cadenya/models/bare_metadata.rbs', line 12
def name=: (String) -> String
|
#to_hash ⇒ { id: String, name: String }
16 |
# File 'sig/cadenya/models/bare_metadata.rbs', line 16
def to_hash: -> { id: String, name: String }
|