Class: Cadenya::Models::BulkWorkspaceApplyStatus
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::BulkWorkspaceApplyStatus
- Defined in:
- lib/cadenya/models/bulk_workspace_apply_status.rb
Defined Under Namespace
Modules: State Classes: PreflightError
Instance Attribute Summary collapse
- #message ⇒ String?
-
#preflight_error ⇒ Cadenya::Models::BulkWorkspaceApplyStatus::PreflightError?
The ‘Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
- #state ⇒ Symbol, Cadenya::Models::BulkWorkspaceApplyStatus::State
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(state:, message: nil, preflight_error: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BulkWorkspaceApplyStatus for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(state:, message: nil, preflight_error: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::BulkWorkspaceApplyStatus for more details.
|
|
# File 'lib/cadenya/models/bulk_workspace_apply_status.rb', line 29
|
Instance Attribute Details
#message ⇒ String?
14 |
# File 'lib/cadenya/models/bulk_workspace_apply_status.rb', line 14 optional :message, String |
#preflight_error ⇒ Cadenya::Models::BulkWorkspaceApplyStatus::PreflightError?
The ‘Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by [gRPC](github.com/grpc). Each `Status` message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the [API Design Guide](cloud.google.com/apis/design/errors).
25 26 27 |
# File 'lib/cadenya/models/bulk_workspace_apply_status.rb', line 25 optional :preflight_error, -> { Cadenya::BulkWorkspaceApplyStatus::PreflightError }, api_name: :preflightError |
#state ⇒ Symbol, Cadenya::Models::BulkWorkspaceApplyStatus::State
9 |
# File 'lib/cadenya/models/bulk_workspace_apply_status.rb', line 9 required :state, enum: -> { Cadenya::BulkWorkspaceApplyStatus::State } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/cadenya/models/bulk_workspace_apply_status.rb', line 52
|