Class: Cadenya::Models::BulkWorkspaceApplyStatus::PreflightError::Detail
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::BulkWorkspaceApplyStatus::PreflightError::Detail
- Defined in:
- lib/cadenya/models/bulk_workspace_apply_status.rb
Instance Attribute Summary collapse
-
#type ⇒ String?
The type of the serialized message.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ Object
constructor
Contains an arbitrary serialized message along with a @type that describes the type of the serialized message.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type: nil) ⇒ Object
Contains an arbitrary serialized message along with a @type that describes the type of the serialized message.
99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/cadenya/models/bulk_workspace_apply_status.rb', line 99 class Detail < Cadenya::Internal::Type::BaseModel # @!attribute type # The type of the serialized message. # # @return [String, nil] optional :type, String, api_name: :@type # @!method initialize(type: nil) # Contains an arbitrary serialized message along with a @type that describes the # type of the serialized message. # # @param type [String] The type of the serialized message. end |
Instance Attribute Details
#type ⇒ String?
The type of the serialized message.
104 |
# File 'lib/cadenya/models/bulk_workspace_apply_status.rb', line 104 optional :type, String, api_name: :@type |