Class: Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataAgentOutcome
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataAgentOutcome
- Defined in:
- lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_agent_outcome.rb
Defined Under Namespace
Modules: Action Classes: Error
Instance Attribute Summary collapse
- #action ⇒ Symbol, ...
-
#error ⇒ Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataAgentOutcome::Error?
The ‘Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
- #external_id ⇒ String?
-
#resource ⇒ Cadenya::Models::Agent?
Agent resource.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(action: nil, error: nil, external_id: nil, resource: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BulkWorkspaceApplyResultDataAgentOutcome for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action: nil, error: nil, external_id: nil, resource: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataAgentOutcome for more details.
|
|
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_agent_outcome.rb', line 35
|
Instance Attribute Details
#action ⇒ Symbol, ...
10 11 |
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_agent_outcome.rb', line 10 optional :action, enum: -> { Cadenya::BulkWorkspaceResources::BulkWorkspaceApplyResultDataAgentOutcome::Action } |
#error ⇒ Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataAgentOutcome::Error?
The ‘Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by [gRPC](github.com/grpc). Each `Status` message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the [API Design Guide](cloud.google.com/apis/design/errors).
22 |
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_agent_outcome.rb', line 22 optional :error, -> { Cadenya::BulkWorkspaceResources::BulkWorkspaceApplyResultDataAgentOutcome::Error } |
#external_id ⇒ String?
27 |
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_agent_outcome.rb', line 27 optional :external_id, String, api_name: :externalId |
#resource ⇒ Cadenya::Models::Agent?
Agent resource
33 |
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_agent_outcome.rb', line 33 optional :resource, -> { Cadenya::Agent } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_agent_outcome.rb', line 59
|