Class: Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataMemoryLayerOutcome::Error::Detail

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_memory_layer_outcome.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type: nil) ⇒ Object

Contains an arbitrary serialized message along with a @type that describes the type of the serialized message.

Parameters:

  • type (String) (defaults to: nil)

    The type of the serialized message.



113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_memory_layer_outcome.rb', line 113

class Detail < Cadenya::Internal::Type::BaseModel
  # @!attribute type
  #   The type of the serialized message.
  #
  #   @return [String, nil]
  optional :type, String, api_name: :@type

  # @!method initialize(type: nil)
  #   Contains an arbitrary serialized message along with a @type that describes the
  #   type of the serialized message.
  #
  #   @param type [String] The type of the serialized message.
end

Instance Attribute Details

#typeString?

The type of the serialized message.

Returns:

  • (String, nil)


118
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_memory_layer_outcome.rb', line 118

optional :type, String, api_name: :@type