Class: Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationAssignmentOutcome
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationAssignmentOutcome
- Defined in:
- lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_assignment_outcome.rb
Defined Under Namespace
Modules: Action Classes: Error
Instance Attribute Summary collapse
- #action ⇒ Symbol, ...
-
#error ⇒ Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationAssignmentOutcome::Error?
The ‘Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
-
#resource ⇒ Cadenya::Models::Agents::VariationAssignment?
A read-only reference to a single tool, tool set, or sub-agent attached to a variation.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(action: nil, error: nil, resource: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BulkWorkspaceApplyResultDataVariationAssignmentOutcome for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action: nil, error: nil, resource: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationAssignmentOutcome for more details.
|
|
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_assignment_outcome.rb', line 38
|
Instance Attribute Details
#action ⇒ Symbol, ...
10 11 |
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_assignment_outcome.rb', line 10 optional :action, enum: -> { Cadenya::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationAssignmentOutcome::Action } |
#error ⇒ Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationAssignmentOutcome::Error?
The ‘Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by [gRPC](github.com/grpc). Each `Status` message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the [API Design Guide](cloud.google.com/apis/design/errors).
22 23 |
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_assignment_outcome.rb', line 22 optional :error, -> { Cadenya::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationAssignmentOutcome::Error } |
#resource ⇒ Cadenya::Models::Agents::VariationAssignment?
A read-only reference to a single tool, tool set, or sub-agent attached to a variation. Read the full set of assignments via ‘AgentVariationInfo.assignments`; mutations go through the dedicated add/remove assignment endpoints.
The ‘id` identifies the assignment itself (not the referenced resource) and is the handle used to remove the assignment. It is returned by the add endpoint and present on every entry in `AgentVariationInfo.assignments`.
36 |
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_assignment_outcome.rb', line 36 optional :resource, -> { Cadenya::Agents::VariationAssignment } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_assignment_outcome.rb', line 60
|