Class: Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome
- Defined in:
- lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb
Defined Under Namespace
Modules: Action Classes: Error
Instance Attribute Summary collapse
- #action ⇒ Symbol, ...
-
#error ⇒ Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome::Error?
The ‘Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
-
#resource ⇒ Cadenya::Models::Agents::VariationMemoryLayerAssignment?
VariationMemoryLayerAssignment attaches a single MemoryLayer to a variation at a given position in the variation’s baseline memory stack.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(action: nil, error: nil, resource: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action: nil, error: nil, resource: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome for more details.
|
|
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb', line 36
|
Instance Attribute Details
#action ⇒ Symbol, ...
10 11 |
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb', line 10 optional :action, enum: -> { Cadenya::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome::Action } |
#error ⇒ Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome::Error?
The ‘Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by [gRPC](github.com/grpc). Each `Status` message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the [API Design Guide](cloud.google.com/apis/design/errors).
22 23 |
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb', line 22 optional :error, -> { Cadenya::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome::Error } |
#resource ⇒ Cadenya::Models::Agents::VariationMemoryLayerAssignment?
VariationMemoryLayerAssignment attaches a single MemoryLayer to a variation at a given position in the variation’s baseline memory stack. A variation has at most one assignment per memory_layer_id.
Variations only support whole-layer attachments — entry pinning is an objective-level capability.
34 |
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb', line 34 optional :resource, -> { Cadenya::Agents::VariationMemoryLayerAssignment } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb', line 58
|