Class: Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome::Error

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb

Overview

See Also:

Defined Under Namespace

Classes: Detail

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Cadenya::Internal::Type::BaseModel

Instance Attribute Details

#codeInteger?

The status code, which should be an enum value of [google.rpc.Code].

Returns:

  • (Integer, nil)


69
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb', line 69

optional :code, Integer

#detailsArray<Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome::Error::Detail>?

A list of messages that carry the error details. There is a common set of message types for APIs to use.



76
77
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb', line 76

optional :details,
-> { Cadenya::Internal::Type::ArrayOf[Cadenya::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome::Error::Detail] }

#messageString?

A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the

google.rpc.Status.details][google.rpc.Status.details

field, or localized by

the client.

Returns:

  • (String, nil)


86
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb', line 86

optional :message, String