Class: Cadenya::Models::CapabilityReasoning

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/capability_reasoning.rb,
sig/cadenya/models/capability_reasoning.rbs

Defined Under Namespace

Modules: Mode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(mode: nil) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::CapabilityReasoning for more details.

Reasoning / extended thinking (ModelConfig.reasoning_effort). A model that does not reason simply omits this capability.

Parameters:



# File 'lib/cadenya/models/capability_reasoning.rb', line 13

Instance Attribute Details

#modeSymbol, ...

How reasoning is enabled for this model. Catalog data used to decide whether thinking is requested for objective iterations on this model.



11
# File 'lib/cadenya/models/capability_reasoning.rb', line 11

optional :mode, enum: -> { Cadenya::CapabilityReasoning::Mode }

Instance Method Details

#to_hash{ mode: Cadenya::Models::CapabilityReasoning::mode }

Returns:

  • ({ mode: Cadenya::Models::CapabilityReasoning::mode })


17
# File 'sig/cadenya/models/capability_reasoning.rbs', line 17

def to_hash: -> { mode: Cadenya::Models::CapabilityReasoning::mode }