Class: Cadenya::Models::CapabilityStopSequences

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/capability_stop_sequences.rb,
sig/cadenya/models/capability_stop_sequences.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(limit: nil) ⇒ CapabilityStopSequences

Some parameter documentations has been truncated, see Cadenya::Models::CapabilityStopSequences for more details.

Custom stop sequences (ModelConfig.stop_sequences).

Parameters:

  • limit (Integer) (defaults to: nil)

    Maximum number of stop sequences the model accepts per request.

  • limit: (Integer) (defaults to: nil)


# File 'lib/cadenya/models/capability_stop_sequences.rb', line 13

Instance Attribute Details

#limitInteger?

Maximum number of stop sequences the model accepts per request. 0 means the provider imposes no meaningful limit.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


11
# File 'lib/cadenya/models/capability_stop_sequences.rb', line 11

optional :limit, Integer

Instance Method Details

#to_hash{ limit: Integer }

Returns:

  • ({ limit: Integer })


12
# File 'sig/cadenya/models/capability_stop_sequences.rbs', line 12

def to_hash: -> { limit: Integer }