Class: Cadenya::Models::ContextWindowCompacted

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/context_window_compacted.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(messages_compacted: nil, new_context_window: nil, strategies: nil, summary: nil) ⇒ Object

Parameters:

  • messages_compacted (Integer) (defaults to: nil)

    Number of messages that were compacted

  • new_context_window (Cadenya::Models::ObjectiveContextWindowData) (defaults to: nil)

    The new context window created by this compaction

  • strategies (Array<String>) (defaults to: nil)

    The strategies that were applied during this compaction

  • summary (String) (defaults to: nil)

    The summary generated by the summarization strategy, if used.



# File 'lib/cadenya/models/context_window_compacted.rb', line 30

Instance Attribute Details

#messages_compactedInteger?

Number of messages that were compacted

Returns:

  • (Integer, nil)


10
# File 'lib/cadenya/models/context_window_compacted.rb', line 10

optional :messages_compacted, Integer, api_name: :messagesCompacted

#new_context_windowCadenya::Models::ObjectiveContextWindowData?

The new context window created by this compaction



16
# File 'lib/cadenya/models/context_window_compacted.rb', line 16

optional :new_context_window, -> { Cadenya::ObjectiveContextWindowData }, api_name: :newContextWindow

#strategiesArray<String>?

The strategies that were applied during this compaction

Returns:

  • (Array<String>, nil)


22
# File 'lib/cadenya/models/context_window_compacted.rb', line 22

optional :strategies, Cadenya::Internal::Type::ArrayOf[String]

#summaryString?

The summary generated by the summarization strategy, if used.

Returns:

  • (String, nil)


28
# File 'lib/cadenya/models/context_window_compacted.rb', line 28

optional :summary, String