Class: Cadenya::Models::MemoryLayerInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/memory_layer_info.rb,
sig/cadenya/models/memory_layer_info.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent: nil, created_by: nil, entry_count: nil, last_used_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::MemoryLayerInfo for more details.

Parameters:

  • agent (Cadenya::Models::ResourceMetadata) (defaults to: nil)

    Standard metadata for persistent, named resources (e.g., agents, tools, prompts)

  • created_by (Cadenya::Models::Profile) (defaults to: nil)

    A profile identifies a user or non-human principal (such as an API key)

  • entry_count (Integer) (defaults to: nil)

    Number of entries currently in this layer.

  • last_used_at (Time) (defaults to: nil)

    Timestamp of the most recent objective that resolved against this layer.



# File 'lib/cadenya/models/memory_layer_info.rb', line 35

Instance Attribute Details

#agentCadenya::ResourceMetadata? (readonly)

Returns the value of attribute agent.

Returns:



16
17
18
# File 'sig/cadenya/models/memory_layer_info.rbs', line 16

def agent
  @agent
end

#created_byCadenya::Models::Profile?

A profile identifies a user or non-human principal (such as an API key) at the account level. Profiles are account-scoped and can be granted access to multiple workspaces.

Parameters:

Returns:



12
# File 'lib/cadenya/models/memory_layer_info.rb', line 12

optional :created_by, -> { Cadenya::Profile }, api_name: :createdBy

#entry_countInteger? (readonly)

Returns the value of attribute entry_count.

Returns:

  • (Integer, nil)


20
21
22
# File 'sig/cadenya/models/memory_layer_info.rbs', line 20

def entry_count
  @entry_count
end

#last_used_atTime? (readonly)

Returns the value of attribute last_used_at.

Returns:

  • (Time, nil)


24
25
26
# File 'sig/cadenya/models/memory_layer_info.rbs', line 24

def last_used_at
  @last_used_at
end

Instance Method Details

#agent=Cadenya::ResourceMetadata (readonly)



18
# File 'sig/cadenya/models/memory_layer_info.rbs', line 18

def agent=: (Cadenya::ResourceMetadata) -> Cadenya::ResourceMetadata

#entry_count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


22
# File 'sig/cadenya/models/memory_layer_info.rbs', line 22

def entry_count=: (Integer) -> Integer

#last_used_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


26
# File 'sig/cadenya/models/memory_layer_info.rbs', line 26

def last_used_at=: (Time) -> Time

#to_hash{

Returns:

  • ({)


35
# File 'sig/cadenya/models/memory_layer_info.rbs', line 35

def to_hash: -> {