Class: Cadenya::Models::MemoryLayerListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cadenya/models/memory_layer_list_params.rb

Overview

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workspace_id:, agent_id: nil, bundle_key: nil, cursor: nil, episodic_key_prefix: nil, include_info: nil, limit: nil, prefix: nil, query: nil, sort_order: nil, type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::MemoryLayerListParams for more details.

Parameters:

  • workspace_id (String)
  • agent_id (String) (defaults to: nil)

    Filter to episodic layers belonging to this agent.

  • bundle_key (String) (defaults to: nil)

    Filter by bundle_key — return only resources owned by this bundle.

  • cursor (String) (defaults to: nil)

    Pagination cursor from previous response

  • episodic_key_prefix (String) (defaults to: nil)

    Filter to episodic layers whose episodic key starts with this prefix

  • include_info (Boolean) (defaults to: nil)

    When set to true you may use more of your alloted API rate-limit

  • limit (Integer) (defaults to: nil)

    Maximum number of results to return

  • prefix (String) (defaults to: nil)

    Filter expression (query param: prefix)

  • query (String) (defaults to: nil)

    Free-form search query

  • sort_order (String) (defaults to: nil)

    Sort order for results (asc or desc by creation time)

  • type (Symbol, Cadenya::Models::MemoryLayerListParams::Type) (defaults to: nil)

    Filter by layer type

  • request_options (Cadenya::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/cadenya/models/memory_layer_list_params.rb', line 77

Instance Attribute Details

#agent_idString?

Filter to episodic layers belonging to this agent.

Returns:

  • (String, nil)


19
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 19

optional :agent_id, String

#bundle_keyString?

Filter by bundle_key — return only resources owned by this bundle.

Returns:

  • (String, nil)


25
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 25

optional :bundle_key, String

#cursorString?

Pagination cursor from previous response

Returns:

  • (String, nil)


31
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 31

optional :cursor, String

#episodic_key_prefixString?

Filter to episodic layers whose episodic key starts with this prefix (e.g. “customer/” matches “customer/42” and “customer/43”). Useful for namespaced keys, similar to a redis key scan.

Returns:

  • (String, nil)


39
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 39

optional :episodic_key_prefix, String

#include_infoBoolean?

When set to true you may use more of your alloted API rate-limit

Returns:

  • (Boolean, nil)


45
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 45

optional :include_info, Cadenya::Internal::Type::Boolean

#limitInteger?

Maximum number of results to return

Returns:

  • (Integer, nil)


51
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 51

optional :limit, Integer

#prefixString?

Filter expression (query param: prefix)

Returns:

  • (String, nil)


57
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 57

optional :prefix, String

#queryString?

Free-form search query

Returns:

  • (String, nil)


63
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 63

optional :query, String

#sort_orderString?

Sort order for results (asc or desc by creation time)

Returns:

  • (String, nil)


69
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 69

optional :sort_order, String

#typeSymbol, ...

Filter by layer type



75
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 75

optional :type, enum: -> { Cadenya::MemoryLayerListParams::Type }

#workspace_idString

Returns:

  • (String)


13
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 13

required :workspace_id, String