Class: Cadenya::Models::MemoryLayers::MemoryEntryCreateSpecUploadID

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/memory_layers/memory_entry_create_spec_upload_id.rb,
sig/cadenya/models/memory_layers/memory_entry_create_spec_upload_id.rbs

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, upload_id:, description: nil, key: nil) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::MemoryLayers::MemoryEntryCreateSpecUploadID for more details.

Parameters:



# File 'lib/cadenya/models/memory_layers/memory_entry_create_spec_upload_id.rb', line 30

Instance Attribute Details

#descriptionString?

Parameters:

  • (String)

Returns:

  • (String, nil)


22
# File 'lib/cadenya/models/memory_layers/memory_entry_create_spec_upload_id.rb', line 22

optional :description, String

#keyString?

See MemoryEntrySpec.key for the full rule set. Same constraints apply here.

Parameters:

  • (String)

Returns:

  • (String, nil)


28
# File 'lib/cadenya/models/memory_layers/memory_entry_create_spec_upload_id.rb', line 28

optional :key, String

#typeSymbol, Cadenya::Models::MemoryLayers::MemoryEntryCreateSpecUploadID::Type

Parameters:

  • value (Cadenya::Models::MemoryLayers::MemoryEntryCreateSpecUploadID::type_)

Returns:



10
# File 'lib/cadenya/models/memory_layers/memory_entry_create_spec_upload_id.rb', line 10

required :type, enum: -> { Cadenya::MemoryLayers::MemoryEntryCreateSpecUploadID::Type }

#upload_idString

ID of a COMPLETE Upload. The server reads the object from storage, copies its bytes into the entry, and marks the upload consumed.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/cadenya/models/memory_layers/memory_entry_create_spec_upload_id.rb', line 17

required :upload_id, String, api_name: :uploadId

Instance Method Details

#to_hash{

Returns:

  • ({)


32
# File 'sig/cadenya/models/memory_layers/memory_entry_create_spec_upload_id.rbs', line 32

def to_hash: -> {