Class: Cadenya::Models::Model::Info

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/model.rb,
sig/cadenya/models/model.rbs

Overview

See Also:

  • Cadenya::Models::Model#info

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_variation_count: nil, ai_provider_key: nil, last_used_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::Model::Info for more details.

ModelInfo carries server-derived, read-only details about a model.

Parameters:

  • agent_variation_count (Integer) (defaults to: nil)

    Number of agent variations currently provisioned on this model. Useful for

  • ai_provider_key (Cadenya::Models::AIProviderKey) (defaults to: nil)

    AIProviderKey is a credential for an AI provider, scoped to a workspace.

  • last_used_at (Time) (defaults to: nil)

    Represents the last time this model was used in an agent objective



# File 'lib/cadenya/models/model.rb', line 87

Instance Attribute Details

#agent_variation_countInteger? (readonly)

Returns the value of attribute agent_variation_count.

Returns:

  • (Integer, nil)


56
57
58
# File 'sig/cadenya/models/model.rbs', line 56

def agent_variation_count
  @agent_variation_count
end

#ai_provider_keyCadenya::AIProviderKey? (readonly)

Returns the value of attribute ai_provider_key.

Returns:



60
61
62
# File 'sig/cadenya/models/model.rbs', line 60

def ai_provider_key
  @ai_provider_key
end

#last_used_atTime? (readonly)

Returns the value of attribute last_used_at.

Returns:

  • (Time, nil)


64
65
66
# File 'sig/cadenya/models/model.rbs', line 64

def last_used_at
  @last_used_at
end

Instance Method Details

#agent_variation_count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


58
# File 'sig/cadenya/models/model.rbs', line 58

def agent_variation_count=: (Integer) -> Integer

#ai_provider_key=Cadenya::AIProviderKey (readonly)



62
# File 'sig/cadenya/models/model.rbs', line 62

def ai_provider_key=: (Cadenya::AIProviderKey) -> Cadenya::AIProviderKey

#last_used_at=Time (readonly)

Parameters:

  • (Time)

Returns:

  • (Time)


66
# File 'sig/cadenya/models/model.rbs', line 66

def last_used_at=: (Time) -> Time

#to_hash{

Returns:

  • ({)


74
# File 'sig/cadenya/models/model.rbs', line 74

def to_hash: -> {