Class: Cadenya::Models::ObjectiveConfigSnapshot
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ObjectiveConfigSnapshot
- Defined in:
- lib/cadenya/models/objective_config_snapshot.rb
Instance Attribute Summary collapse
-
#agent ⇒ Cadenya::Models::Agent?
Agent resource.
-
#agent_schedule ⇒ Cadenya::Models::Agents::AgentSchedule?
AgentSchedule resource — a recurring trigger attached to an agent that creates objectives on its cadence.
-
#agent_variation ⇒ Cadenya::Models::Agents::AgentVariation?
AgentVariation resource.
Instance Method Summary collapse
-
#initialize(agent: nil, agent_schedule: nil, agent_variation: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ObjectiveConfigSnapshot for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent: nil, agent_schedule: nil, agent_variation: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ObjectiveConfigSnapshot for more details.
ObjectiveConfigSnapshot is the point-in-time snapshot of the agent, variation, and (when applicable) schedule that an objective was started with.
|
|
# File 'lib/cadenya/models/objective_config_snapshot.rb', line 25
|
Instance Attribute Details
#agent ⇒ Cadenya::Models::Agent?
Agent resource
10 |
# File 'lib/cadenya/models/objective_config_snapshot.rb', line 10 optional :agent, -> { Cadenya::Agent } |
#agent_schedule ⇒ Cadenya::Models::Agents::AgentSchedule?
AgentSchedule resource — a recurring trigger attached to an agent that creates objectives on its cadence.
17 |
# File 'lib/cadenya/models/objective_config_snapshot.rb', line 17 optional :agent_schedule, -> { Cadenya::Agents::AgentSchedule }, api_name: :agentSchedule |
#agent_variation ⇒ Cadenya::Models::Agents::AgentVariation?
AgentVariation resource
23 |
# File 'lib/cadenya/models/objective_config_snapshot.rb', line 23 optional :agent_variation, -> { Cadenya::Agents::AgentVariation }, api_name: :agentVariation |