Class: Cadenya::Models::ObjectiveContextWindow

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/objective_context_window.rb

Overview

Defined Under Namespace

Classes: Info

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(data:, metadata:, info: nil) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::ObjectiveContextWindow for more details.

ObjectiveContextWindow is a window of chat completions that is grouped together to prevent context-window overflows. Context windows also allow agents to compact their windows and carry on into a new one.

Parameters:



# File 'lib/cadenya/models/objective_context_window.rb', line 24

Instance Attribute Details

#dataCadenya::Models::ObjectiveContextWindowData



10
# File 'lib/cadenya/models/objective_context_window.rb', line 10

required :data, -> { Cadenya::ObjectiveContextWindowData }

#infoCadenya::Models::ObjectiveContextWindow::Info?



22
# File 'lib/cadenya/models/objective_context_window.rb', line 22

optional :info, -> { Cadenya::ObjectiveContextWindow::Info }

#metadataCadenya::Models::OperationMetadata

Metadata for ephemeral operations and activities (e.g., objectives, executions, runs)



17
# File 'lib/cadenya/models/objective_context_window.rb', line 17

required :metadata, -> { Cadenya::OperationMetadata }