Class: Cadenya::Models::ObjectiveContinueParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ObjectiveContinueParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cadenya/models/objective_continue_params.rb,
sig/cadenya/models/objective_continue_params.rbs
Overview
Instance Attribute Summary collapse
-
#enqueue ⇒ Boolean?
When set to true, the message will be enqueued for when the agent loop is available to process it.
-
#message ⇒ String?
The message to continue an objective that has completed (or you are enqueing).
- #objective_id ⇒ String
- #workspace_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(workspace_id:, objective_id:, enqueue: nil, message: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ObjectiveContinueParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(workspace_id:, objective_id:, enqueue: nil, message: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ObjectiveContinueParams for more details.
|
|
# File 'lib/cadenya/models/objective_continue_params.rb', line 33
|
Instance Attribute Details
#enqueue ⇒ Boolean?
When set to true, the message will be enqueued for when the agent loop is available to process it.
25 |
# File 'lib/cadenya/models/objective_continue_params.rb', line 25 optional :enqueue, Cadenya::Internal::Type::Boolean |
#message ⇒ String?
The message to continue an objective that has completed (or you are enqueing)
31 |
# File 'lib/cadenya/models/objective_continue_params.rb', line 31 optional :message, String |
#objective_id ⇒ String
18 |
# File 'lib/cadenya/models/objective_continue_params.rb', line 18 required :objective_id, String |
#workspace_id ⇒ String
13 |
# File 'lib/cadenya/models/objective_continue_params.rb', line 13 required :workspace_id, String |
Instance Method Details
#to_hash ⇒ {
36 |
# File 'sig/cadenya/models/objective_continue_params.rbs', line 36
def to_hash: -> {
|