Class: Cadenya::Models::ObjectiveCreateParams::EpisodicMemory

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/objective_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workspace_id:, agent_id:, data:, episodic_memory: nil, initial_message: nil, memory_cascade: nil, metadata: nil, secrets: nil, user_data: nil, variation_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::ObjectiveCreateParams for more details.

Parameters:

  • workspace_id (String)
  • agent_id (String)
  • data (Hash{Symbol=>Object})

    Arbitrary data for the objective. May be used in liquid templates for prompts co

  • episodic_memory (Cadenya::Models::ObjectiveCreateParams::EpisodicMemory) (defaults to: nil)

    Episodic is used to configure the episodic memory for the objective

  • initial_message (String) (defaults to: nil)

    Optional override for the initial message sent to the agent. This becomes the fi

  • memory_cascade (Array<Cadenya::Models::MemoryReference>) (defaults to: nil)

    Memory layers/entries layered over the baseline cascade inherited

  • metadata (Cadenya::Models::CreateOperationMetadata) (defaults to: nil)

    CreateOperationMetadata contains the user-provided fields for creating

  • secrets (Array<Cadenya::Models::ObjectiveCreateParams::Secret>) (defaults to: nil)

    Secrets that can be used in the headers for tool calls using the secret interpol

  • user_data (Hash{Symbol=>Object}) (defaults to: nil)

    Arbitrary data rendered into the selected variation’s user_message_template

  • variation_id (String) (defaults to: nil)

    Optional explicit variation selection. Overrides the agent’s variation_selection

  • request_options (Cadenya::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/cadenya/models/objective_create_params.rb', line 123

class EpisodicMemory < Cadenya::Internal::Type::BaseModel
  # @!attribute key
  #   The caller-supplied episodic key. Objectives created with the same key (for the
  #   same agent) share one episodic memory layer.
  #
  #   @return [String, nil]
  optional :key, String

  # @!method initialize(key: nil)
  #   Some parameter documentations has been truncated, see
  #   {Cadenya::Models::ObjectiveCreateParams::EpisodicMemory} for more details.
  #
  #   Episodic is used to configure the episodic memory for the objective
  #
  #   @param key [String] The caller-supplied episodic key. Objectives created with the same key
end

Instance Attribute Details

#keyString?

The caller-supplied episodic key. Objectives created with the same key (for the same agent) share one episodic memory layer.

Returns:

  • (String, nil)


129
# File 'lib/cadenya/models/objective_create_params.rb', line 129

optional :key, String