Class: Cadenya::Models::ObjectiveEventData::Finalized
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ObjectiveEventData::Finalized
- Defined in:
- lib/cadenya/models/objective_event_data.rb,
sig/cadenya/models/objective_event_data.rbs
Overview
Instance Attribute Summary collapse
-
#output ⇒ Object?
If the objective was created with an output schema, and the agent successfully completed the objective, this field will contain the structured output of the objective.
Instance Method Summary collapse
-
#initialize ⇒ Finalized
constructor
A new instance of Finalized.
- #to_hash ⇒ { output: top }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Finalized
Returns a new instance of Finalized.
168 |
# File 'sig/cadenya/models/objective_event_data.rbs', line 168
def initialize: (?output: top) -> void
|
Instance Attribute Details
#output ⇒ Object?
If the objective was created with an output schema, and the agent successfully completed the objective, this field will contain the structured output of the objective.
178 |
# File 'lib/cadenya/models/objective_event_data.rb', line 178 optional :output, Cadenya::Internal::Type::Unknown |
Instance Method Details
#to_hash ⇒ { output: top }
170 |
# File 'sig/cadenya/models/objective_event_data.rbs', line 170
def to_hash: -> { output: top }
|