Class: Cadenya::Models::ObjectiveEventDataCancelled

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/objective_event_data_cancelled.rb,
sig/cadenya/models/objective_event_data_cancelled.rbs

Defined Under Namespace

Modules: Type Classes: Cancelled

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(message: nil) ⇒ Object

Some parameter documentations has been truncated, see Cancelled for more details.

ObjectiveCancelled is the terminal event written when an objective is cancelled. After this event, the objective is super-terminal: no further iterations, compaction, or continuation are permitted.

Parameters:

  • message (String) (defaults to: nil)

    Optional human-readable note recorded at cancel time. Today the workflow



# File 'lib/cadenya/models/objective_event_data_cancelled.rb', line 19

Instance Attribute Details

#cancelledCadenya::Models::ObjectiveEventDataCancelled::Cancelled

ObjectiveCancelled is the terminal event written when an objective is cancelled. After this event, the objective is super-terminal: no further iterations, compaction, or continuation are permitted.

Parameters:

  • value (Cadenya::ObjectiveEventDataCancelled::Cancelled)

Returns:



12
# File 'lib/cadenya/models/objective_event_data_cancelled.rb', line 12

required :cancelled, -> { Cadenya::ObjectiveEventDataCancelled::Cancelled }

#typeSymbol, Cadenya::Models::ObjectiveEventDataCancelled::Type

Parameters:

  • value (Cadenya::Models::ObjectiveEventDataCancelled::type_)

Returns:



17
# File 'lib/cadenya/models/objective_event_data_cancelled.rb', line 17

required :type, enum: -> { Cadenya::ObjectiveEventDataCancelled::Type }

Instance Method Details

#to_hash{

Returns:

  • ({)


19
# File 'sig/cadenya/models/objective_event_data_cancelled.rbs', line 19

def to_hash: -> {