Class: Cadenya::Models::ObjectiveEventDataFinalized
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ObjectiveEventDataFinalized
- Defined in:
- lib/cadenya/models/objective_event_data_finalized.rb,
sig/cadenya/models/objective_event_data_finalized.rbs
Defined Under Namespace
Modules: Type Classes: Finalized
Instance Attribute Summary collapse
-
#finalized ⇒ Cadenya::Models::ObjectiveEventDataFinalized::Finalized
ObjectiveFinalized is the terminal event written when an objective is finalized.
- #type ⇒ Symbol, Cadenya::Models::ObjectiveEventDataFinalized::Type
Instance Method Summary collapse
-
#initialize(output: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Finalized for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(output: nil) ⇒ Object
Some parameter documentations has been truncated, see Finalized for more details.
ObjectiveFinalized is the terminal event written when an objective is finalized. After this event, the objective is super-terminal: no further iterations, compaction, or continuation are permitted.
|
|
# File 'lib/cadenya/models/objective_event_data_finalized.rb', line 19
|
Instance Attribute Details
#finalized ⇒ Cadenya::Models::ObjectiveEventDataFinalized::Finalized
ObjectiveFinalized is the terminal event written when an objective is finalized. After this event, the objective is super-terminal: no further iterations, compaction, or continuation are permitted.
12 |
# File 'lib/cadenya/models/objective_event_data_finalized.rb', line 12 required :finalized, -> { Cadenya::ObjectiveEventDataFinalized::Finalized } |
#type ⇒ Symbol, Cadenya::Models::ObjectiveEventDataFinalized::Type
17 |
# File 'lib/cadenya/models/objective_event_data_finalized.rb', line 17 required :type, enum: -> { Cadenya::ObjectiveEventDataFinalized::Type } |
Instance Method Details
#to_hash ⇒ {
19 |
# File 'sig/cadenya/models/objective_event_data_finalized.rbs', line 19
def to_hash: -> {
|