Class: Cadenya::Models::ObjectiveEventDataMemoryRead

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/objective_event_data_memory_read.rb,
sig/cadenya/models/objective_event_data_memory_read.rbs

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(memory_read:, type:) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::ObjectiveEventDataMemoryRead for more details.

Parameters:



# File 'lib/cadenya/models/objective_event_data_memory_read.rb', line 19

Instance Attribute Details

#memory_readCadenya::Models::MemoryRead

MemoryRead is emitted each time the agent resolves a key against the memory cascade and loads an entry. Lookups that miss (key not found in any layer) do not emit this event.

Parameters:

Returns:



12
# File 'lib/cadenya/models/objective_event_data_memory_read.rb', line 12

required :memory_read, -> { Cadenya::MemoryRead }, api_name: :memoryRead

#typeSymbol, Cadenya::Models::ObjectiveEventDataMemoryRead::Type

Parameters:

  • value (Cadenya::Models::ObjectiveEventDataMemoryRead::type_)

Returns:



17
# File 'lib/cadenya/models/objective_event_data_memory_read.rb', line 17

required :type, enum: -> { Cadenya::ObjectiveEventDataMemoryRead::Type }

Instance Method Details

#to_hash{

Returns:

  • ({)


19
# File 'sig/cadenya/models/objective_event_data_memory_read.rbs', line 19

def to_hash: -> {