Class: Cadenya::Models::ObjectiveEventDataTimedOut

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/objective_event_data_timed_out.rb,
sig/cadenya/models/objective_event_data_timed_out.rbs

Defined Under Namespace

Modules: Type Classes: TimedOut

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(message: nil) ⇒ Object

Some parameter documentations has been truncated, see TimedOut for more details.

ObjectiveTimedOut is the terminal event written when an objective is finalized by the inactivity sweep because it saw no activity (no user messages, no LLM calls) within its variation's inactivity timeout — or the system-wide 24 hour maximum when no timeout is configured. The objective produces no output. After this event, the objective is super-terminal: no further iterations, compaction, or continuation are permitted.

Parameters:

  • message (String) (defaults to: nil)

    Human-readable note recorded at timeout time (e.g. "Timed out after 2h



# File 'lib/cadenya/models/objective_event_data_timed_out.rb', line 22

Instance Attribute Details

#timed_outCadenya::Models::ObjectiveEventDataTimedOut::TimedOut

ObjectiveTimedOut is the terminal event written when an objective is finalized by the inactivity sweep because it saw no activity (no user messages, no LLM calls) within its variation's inactivity timeout — or the system-wide 24 hour maximum when no timeout is configured. The objective produces no output. After this event, the objective is super-terminal: no further iterations, compaction, or continuation are permitted.

Parameters:

  • value (Cadenya::ObjectiveEventDataTimedOut::TimedOut)

Returns:



15
# File 'lib/cadenya/models/objective_event_data_timed_out.rb', line 15

required :timed_out, -> { Cadenya::ObjectiveEventDataTimedOut::TimedOut }, api_name: :timedOut

#typeSymbol, Cadenya::Models::ObjectiveEventDataTimedOut::Type

Parameters:

  • value (Cadenya::Models::ObjectiveEventDataTimedOut::type_)

Returns:



20
# File 'lib/cadenya/models/objective_event_data_timed_out.rb', line 20

required :type, enum: -> { Cadenya::ObjectiveEventDataTimedOut::Type }

Instance Method Details

#to_hash{

Returns:

  • ({)


19
# File 'sig/cadenya/models/objective_event_data_timed_out.rbs', line 19

def to_hash: -> {