Class: Cadenya::Models::ObjectiveInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/objective_info.rb,
sig/cadenya/models/objective_info.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent:, agent_variation:, created_by:, current_context_window_id:, effective_memory_cascade:, total_context_windows:, total_events:, total_input_tokens:, total_iterations:, total_output_tokens:, total_tool_calls:, subject: nil, tenant: nil, widget: nil) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::ObjectiveInfo for more details.

ObjectiveInfo provides read-only aggregated statistics about an objective's execution

Parameters:

  • agent (Cadenya::Models::ResourceMetadata)

    Standard metadata for persistent, named resources (e.g., agents, tools, prompts)

  • agent_variation (Cadenya::Models::ResourceMetadata)

    Standard metadata for persistent, named resources (e.g., agents, tools, prompts)

  • created_by (Cadenya::Models::Profile)

    A profile identifies a user or non-human principal (such as an API key)

  • current_context_window_id (String)

    ID of the objective's current (most recent) context window. Hydrated on

  • effective_memory_cascade (Array<Cadenya::Models::MemoryReference>)

    The effective memory cascade at objective creation time: the

  • total_context_windows (Integer)

    Total number of context windows that this objective has generated

  • total_events (Integer)

    Total number of events generated during this objective's execution

  • total_input_tokens (Integer)

    Total input tokens consumed across all LLM completions across all context window

  • total_iterations (Integer)
  • total_output_tokens (Integer)

    Total output tokens generated across all LLM completions across all context wind

  • total_tool_calls (Integer)

    Total number of tool calls made during execution

  • subject (Cadenya::Models::SubjectReference) (defaults to: nil)

    SubjectReference is the read-only echo of a resource's subject association,

  • tenant (Cadenya::Models::TenantReference) (defaults to: nil)

    TenantReference is the read-only echo of a resource's tenant association,

  • widget (Cadenya::Models::BareMetadata) (defaults to: nil)

    BareMetadata contains the minimal metadata for a resource: the ID and an



# File 'lib/cadenya/models/objective_info.rb', line 110

Instance Attribute Details

#agentCadenya::ResourceMetadata

Returns the value of attribute agent.



24
25
26
# File 'sig/cadenya/models/objective_info.rbs', line 24

def agent
  @agent
end

#agent_variationCadenya::ResourceMetadata

Returns the value of attribute agent_variation.



26
27
28
# File 'sig/cadenya/models/objective_info.rbs', line 26

def agent_variation
  @agent_variation
end

#created_byCadenya::Models::Profile

A profile identifies a user or non-human principal (such as an API key) at the account level. Profiles are account-scoped and can be granted access to multiple workspaces.

Parameters:

Returns:



12
# File 'lib/cadenya/models/objective_info.rb', line 12

required :created_by, -> { Cadenya::Profile }, api_name: :createdBy

#current_context_window_idString

Returns the value of attribute current_context_window_id.

Returns:

  • (String)


28
29
30
# File 'sig/cadenya/models/objective_info.rbs', line 28

def current_context_window_id
  @current_context_window_id
end

#effective_memory_cascade::Array[Cadenya::MemoryReference]

Returns the value of attribute effective_memory_cascade.

Returns:



30
31
32
# File 'sig/cadenya/models/objective_info.rbs', line 30

def effective_memory_cascade
  @effective_memory_cascade
end

#subjectCadenya::SubjectReference? (readonly)

Returns the value of attribute subject.

Returns:



44
45
46
# File 'sig/cadenya/models/objective_info.rbs', line 44

def subject
  @subject
end

#tenantCadenya::TenantReference? (readonly)

Returns the value of attribute tenant.

Returns:



48
49
50
# File 'sig/cadenya/models/objective_info.rbs', line 48

def tenant
  @tenant
end

#total_context_windowsInteger

Returns the value of attribute total_context_windows.

Returns:

  • (Integer)


32
33
34
# File 'sig/cadenya/models/objective_info.rbs', line 32

def total_context_windows
  @total_context_windows
end

#total_eventsInteger

Returns the value of attribute total_events.

Returns:

  • (Integer)


34
35
36
# File 'sig/cadenya/models/objective_info.rbs', line 34

def total_events
  @total_events
end

#total_input_tokensInteger

Returns the value of attribute total_input_tokens.

Returns:

  • (Integer)


36
37
38
# File 'sig/cadenya/models/objective_info.rbs', line 36

def total_input_tokens
  @total_input_tokens
end

#total_iterationsInteger

Returns the value of attribute total_iterations.

Returns:

  • (Integer)


38
39
40
# File 'sig/cadenya/models/objective_info.rbs', line 38

def total_iterations
  @total_iterations
end

#total_output_tokensInteger

Returns the value of attribute total_output_tokens.

Returns:

  • (Integer)


40
41
42
# File 'sig/cadenya/models/objective_info.rbs', line 40

def total_output_tokens
  @total_output_tokens
end

#total_tool_callsInteger

Returns the value of attribute total_tool_calls.

Returns:

  • (Integer)


42
43
44
# File 'sig/cadenya/models/objective_info.rbs', line 42

def total_tool_calls
  @total_tool_calls
end

#widgetCadenya::BareMetadata? (readonly)

Returns the value of attribute widget.

Returns:



52
53
54
# File 'sig/cadenya/models/objective_info.rbs', line 52

def widget
  @widget
end

Instance Method Details

#subject=Cadenya::SubjectReference (readonly)



46
# File 'sig/cadenya/models/objective_info.rbs', line 46

def subject=: (Cadenya::SubjectReference) -> Cadenya::SubjectReference

#tenant=Cadenya::TenantReference (readonly)



50
# File 'sig/cadenya/models/objective_info.rbs', line 50

def tenant=: (Cadenya::TenantReference) -> Cadenya::TenantReference

#to_hash{

Returns:

  • ({)


73
# File 'sig/cadenya/models/objective_info.rbs', line 73

def to_hash: -> {

#widget=Cadenya::BareMetadata (readonly)

Parameters:

Returns:



54
# File 'sig/cadenya/models/objective_info.rbs', line 54

def widget=: (Cadenya::BareMetadata) -> Cadenya::BareMetadata