Class: Cadenya::Models::ObjectiveListEventsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ObjectiveListEventsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cadenya/models/objective_list_events_params.rb
Overview
Instance Attribute Summary collapse
-
#cursor ⇒ String?
Pagination cursor from previous response.
-
#include_info ⇒ Boolean?
When set to true you may use more of your alloted API rate-limit.
-
#limit ⇒ Integer?
Maximum number of results to return.
- #objective_id ⇒ String
-
#sort_order ⇒ String?
Sort order for results (asc or desc by creation time).
-
#window_id ⇒ String?
Optional context window ID to filter events by.
- #workspace_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(workspace_id:, objective_id:, cursor: nil, include_info: nil, limit: nil, sort_order: nil, window_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/cadenya/models/objective_list_events_params.rb', line 50
|
Instance Attribute Details
#cursor ⇒ String?
Pagination cursor from previous response
24 |
# File 'lib/cadenya/models/objective_list_events_params.rb', line 24 optional :cursor, String |
#include_info ⇒ Boolean?
When set to true you may use more of your alloted API rate-limit
30 |
# File 'lib/cadenya/models/objective_list_events_params.rb', line 30 optional :include_info, Cadenya::Internal::Type::Boolean |
#limit ⇒ Integer?
Maximum number of results to return
36 |
# File 'lib/cadenya/models/objective_list_events_params.rb', line 36 optional :limit, Integer |
#objective_id ⇒ String
18 |
# File 'lib/cadenya/models/objective_list_events_params.rb', line 18 required :objective_id, String |
#sort_order ⇒ String?
Sort order for results (asc or desc by creation time)
42 |
# File 'lib/cadenya/models/objective_list_events_params.rb', line 42 optional :sort_order, String |
#window_id ⇒ String?
Optional context window ID to filter events by
48 |
# File 'lib/cadenya/models/objective_list_events_params.rb', line 48 optional :window_id, String |
#workspace_id ⇒ String
13 |
# File 'lib/cadenya/models/objective_list_events_params.rb', line 13 required :workspace_id, String |