Class: Cadenya::Models::ObjectiveListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cadenya/models/objective_list_params.rb

Overview

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workspace_id:, agent_id: nil, agent_schedule_id: nil, cursor: nil, include_info: nil, limit: nil, parent_objective_id: nil, profile_id: nil, sort_order: nil, state: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::ObjectiveListParams for more details.

Parameters:

  • workspace_id (String)
  • agent_id (String) (defaults to: nil)

    Agent ID for filtering

  • agent_schedule_id (String) (defaults to: nil)

    Filter to objectives produced by a specific AgentSchedule. Accepts

  • cursor (String) (defaults to: nil)

    Pagination cursor from previous response

  • include_info (Boolean) (defaults to: nil)

    When set to true you may use more of your alloted API rate-limit

  • limit (Integer) (defaults to: nil)

    Maximum number of results to return

  • parent_objective_id (String) (defaults to: nil)

    Optional filters

  • profile_id (String) (defaults to: nil)
  • sort_order (String) (defaults to: nil)

    Sort order for results (asc or desc by creation time)

  • state (Symbol, Cadenya::Models::ObjectiveListParams::State) (defaults to: nil)

    Filter by state

  • request_options (Cadenya::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/cadenya/models/objective_list_params.rb', line 69

Instance Attribute Details

#agent_idString?

Agent ID for filtering

Returns:

  • (String, nil)


19
# File 'lib/cadenya/models/objective_list_params.rb', line 19

optional :agent_id, String

#agent_schedule_idString?

Filter to objectives produced by a specific AgentSchedule. Accepts canonical as_… form or external_id:<value> form.

Returns:

  • (String, nil)


26
# File 'lib/cadenya/models/objective_list_params.rb', line 26

optional :agent_schedule_id, String

#cursorString?

Pagination cursor from previous response

Returns:

  • (String, nil)


32
# File 'lib/cadenya/models/objective_list_params.rb', line 32

optional :cursor, String

#include_infoBoolean?

When set to true you may use more of your alloted API rate-limit

Returns:

  • (Boolean, nil)


38
# File 'lib/cadenya/models/objective_list_params.rb', line 38

optional :include_info, Cadenya::Internal::Type::Boolean

#limitInteger?

Maximum number of results to return

Returns:

  • (Integer, nil)


44
# File 'lib/cadenya/models/objective_list_params.rb', line 44

optional :limit, Integer

#parent_objective_idString?

Optional filters

Returns:

  • (String, nil)


50
# File 'lib/cadenya/models/objective_list_params.rb', line 50

optional :parent_objective_id, String

#profile_idString?

Returns:

  • (String, nil)


55
# File 'lib/cadenya/models/objective_list_params.rb', line 55

optional :profile_id, String

#sort_orderString?

Sort order for results (asc or desc by creation time)

Returns:

  • (String, nil)


61
# File 'lib/cadenya/models/objective_list_params.rb', line 61

optional :sort_order, String

#stateSymbol, ...

Filter by state



67
# File 'lib/cadenya/models/objective_list_params.rb', line 67

optional :state, enum: -> { Cadenya::ObjectiveListParams::State }

#workspace_idString

Returns:

  • (String)


13
# File 'lib/cadenya/models/objective_list_params.rb', line 13

required :workspace_id, String