Class: Cadenya::Models::Objectives::ResolvedSecret
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Objectives::ResolvedSecret
- Defined in:
- lib/cadenya/models/objectives/resolved_secret.rb
Defined Under Namespace
Modules: Source
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(key: nil, source: nil) ⇒ Object
constructor
ResolvedSecret is a resolved secret value from the workspace, toolset, or objective.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(key: nil, source: nil) ⇒ Object
ResolvedSecret is a resolved secret value from the workspace, toolset, or objective. When a tool is called, it will rely on secrets in the order of:
-
Objective
-
Toolset
-
Workspace
|
|
# File 'lib/cadenya/models/objectives/resolved_secret.rb', line 17
|
Instance Attribute Details
#key ⇒ String?
10 |
# File 'lib/cadenya/models/objectives/resolved_secret.rb', line 10 optional :key, String |
#source ⇒ Symbol, ...
15 |
# File 'lib/cadenya/models/objectives/resolved_secret.rb', line 15 optional :source, enum: -> { Cadenya::Objectives::ResolvedSecret::Source } |