Class: Cadenya::Models::Objectives::SetToolCallContentRequestContentBlock
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Objectives::SetToolCallContentRequestContentBlock
- Defined in:
- lib/cadenya/models/objectives/set_tool_call_content_request_content_block.rb,
sig/cadenya/models/objectives/set_tool_call_content_request_content_block.rbs
Instance Attribute Summary collapse
- #audio ⇒ Cadenya::Models::Objectives::SetToolCallContentRequestAudioBlock?
- #image ⇒ Cadenya::Models::Objectives::SetToolCallContentRequestImageBlock?
- #text ⇒ Cadenya::Models::Objectives::SetToolCallContentRequestTextBlock?
Instance Method Summary collapse
-
#initialize(audio: nil, image: nil, text: nil) ⇒ Object
constructor
ContentBlock is a single block of tool call content supplied on input.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(audio: nil, image: nil, text: nil) ⇒ Object
ContentBlock is a single block of tool call content supplied on input. Exactly one of the variants is set.
|
|
# File 'lib/cadenya/models/objectives/set_tool_call_content_request_content_block.rb', line 22
|
Instance Attribute Details
#audio ⇒ Cadenya::Models::Objectives::SetToolCallContentRequestAudioBlock?
10 |
# File 'lib/cadenya/models/objectives/set_tool_call_content_request_content_block.rb', line 10 optional :audio, -> { Cadenya::Objectives::SetToolCallContentRequestAudioBlock } |
#image ⇒ Cadenya::Models::Objectives::SetToolCallContentRequestImageBlock?
15 |
# File 'lib/cadenya/models/objectives/set_tool_call_content_request_content_block.rb', line 15 optional :image, -> { Cadenya::Objectives::SetToolCallContentRequestImageBlock } |
#text ⇒ Cadenya::Models::Objectives::SetToolCallContentRequestTextBlock?
20 |
# File 'lib/cadenya/models/objectives/set_tool_call_content_request_content_block.rb', line 20 optional :text, -> { Cadenya::Objectives::SetToolCallContentRequestTextBlock } |
Instance Method Details
#to_hash ⇒ {
36 |
# File 'sig/cadenya/models/objectives/set_tool_call_content_request_content_block.rbs', line 36
def to_hash: -> {
|