Class: Cadenya::Models::Objectives::ToolCallDenyParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cadenya/models/objectives/tool_call_deny_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workspace_id:, objective_id:, tool_call_id:, memo: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::Objectives::ToolCallDenyParams for more details.

Parameters:

  • workspace_id (String)
  • objective_id (String)
  • tool_call_id (String)
  • memo (String) (defaults to: nil)

    A memo to associate to the tool call denial. Use a memo to steer the LLM to a di

  • request_options (Cadenya::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/cadenya/models/objectives/tool_call_deny_params.rb', line 33

Instance Attribute Details

#memoString?

A memo to associate to the tool call denial. Use a memo to steer the LLM to a different decision or usage of the tool.

Returns:

  • (String, nil)


31
# File 'lib/cadenya/models/objectives/tool_call_deny_params.rb', line 31

optional :memo, String

#objective_idString

Returns:

  • (String)


19
# File 'lib/cadenya/models/objectives/tool_call_deny_params.rb', line 19

required :objective_id, String

#tool_call_idString

Returns:

  • (String)


24
# File 'lib/cadenya/models/objectives/tool_call_deny_params.rb', line 24

required :tool_call_id, String

#workspace_idString

Returns:

  • (String)


14
# File 'lib/cadenya/models/objectives/tool_call_deny_params.rb', line 14

required :workspace_id, String