Class: Cadenya::Models::Objectives::ToolCallListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cadenya/models/objectives/tool_call_list_params.rb,
sig/cadenya/models/objectives/tool_call_list_params.rbs

Overview

See Also:

  • Cadenya::Resources::Objectives::ToolCalls#list

Defined Under Namespace

Modules: ExecutionStatus, Status

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workspace_id:, objective_id:, cursor: nil, execution_status: nil, include_info: nil, limit: nil, status: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::Objectives::ToolCallListParams for more details.

Parameters:



# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 53

Instance Attribute Details

#cursorString?

Pagination cursor from previous response

Parameters:

  • (String)

Returns:

  • (String, nil)


25
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 25

optional :cursor, String

#execution_statusSymbol, ...

Filter by tool call execution status. Useful for reverse-harness polling of bare tool calls waiting for externally supplied content (TOOL_CALL_EXECUTION_STATUS_WAITING_FOR_CONTENT).



33
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 33

optional :execution_status, enum: -> { Cadenya::Objectives::ToolCallListParams::ExecutionStatus }

#include_infoBoolean?

When set to true you may use more of your alloted API rate-limit

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


39
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 39

optional :include_info, Cadenya::Internal::Type::Boolean

#limitInteger?

Maximum number of results to return

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


45
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 45

optional :limit, Integer

#objective_idString

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 19

required :objective_id, String

#statusSymbol, ...

Filter by tool call status



51
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 51

optional :status, enum: -> { Cadenya::Objectives::ToolCallListParams::Status }

#workspace_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 14

required :workspace_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 86

Instance Method Details

#to_hash{

Returns:

  • ({)


59
# File 'sig/cadenya/models/objectives/tool_call_list_params.rbs', line 59

def to_hash: -> {