Class: Cadenya::Models::Subject
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Subject
- Defined in:
- lib/cadenya/models/subject.rb,
sig/cadenya/models/subject.rbs
Instance Attribute Summary collapse
-
#info ⇒ Cadenya::Models::SubjectInfo?
SubjectInfo provides read-only server-derived data about a subject.
-
#metadata ⇒ Cadenya::Models::ResourceMetadata
Standard metadata for persistent, named resources (e.g., agents, tools, prompts).
Instance Method Summary collapse
-
#initialize(metadata:, info: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Subject for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(metadata:, info: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::Subject for more details.
Subject is a person within a tenant as a readable record. Like Tenant it carries
no spec — metadata.external_id is the customer's key for them, unique within
the tenant rather than the workspace.
|
|
# File 'lib/cadenya/models/subject.rb', line 18
|
Instance Attribute Details
#info ⇒ Cadenya::Models::SubjectInfo?
SubjectInfo provides read-only server-derived data about a subject.
16 |
# File 'lib/cadenya/models/subject.rb', line 16 optional :info, -> { Cadenya::SubjectInfo } |
#metadata ⇒ Cadenya::Models::ResourceMetadata
Standard metadata for persistent, named resources (e.g., agents, tools, prompts)
10 |
# File 'lib/cadenya/models/subject.rb', line 10 required :metadata, -> { Cadenya::ResourceMetadata } |
Instance Method Details
#to_hash ⇒ {
18 |
# File 'sig/cadenya/models/subject.rbs', line 18
def to_hash: -> {
|