Class: Cadenya::Models::TenantInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/tenant_info.rb,
sig/cadenya/models/tenant_info.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(objective_count: nil, subject_count: nil, widget_session_count: nil) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::TenantInfo for more details.

TenantInfo provides read-only server-derived data about a tenant.

Parameters:

  • objective_count (Integer) (defaults to: nil)

    Number of objectives associated with this tenant, across every surface —

  • subject_count (Integer) (defaults to: nil)

    Number of subjects asserted under this tenant.

  • widget_session_count (Integer) (defaults to: nil)

    Number of widget sessions minted for this tenant that still exist.



# File 'lib/cadenya/models/tenant_info.rb', line 29

Instance Attribute Details

#objective_countInteger? (readonly)

Returns the value of attribute objective_count.

Returns:

  • (Integer, nil)


11
12
13
# File 'sig/cadenya/models/tenant_info.rbs', line 11

def objective_count
  @objective_count
end

#subject_countInteger? (readonly)

Returns the value of attribute subject_count.

Returns:

  • (Integer, nil)


15
16
17
# File 'sig/cadenya/models/tenant_info.rbs', line 15

def subject_count
  @subject_count
end

#widget_session_countInteger? (readonly)

Returns the value of attribute widget_session_count.

Returns:

  • (Integer, nil)


19
20
21
# File 'sig/cadenya/models/tenant_info.rbs', line 19

def widget_session_count
  @widget_session_count
end

Instance Method Details

#objective_count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


13
# File 'sig/cadenya/models/tenant_info.rbs', line 13

def objective_count=: (Integer) -> Integer

#subject_count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


17
# File 'sig/cadenya/models/tenant_info.rbs', line 17

def subject_count=: (Integer) -> Integer

#to_hash{

Returns:

  • ({)


29
# File 'sig/cadenya/models/tenant_info.rbs', line 29

def to_hash: -> {

#widget_session_count=Integer (readonly)

Parameters:

  • (Integer)

Returns:

  • (Integer)


21
# File 'sig/cadenya/models/tenant_info.rbs', line 21

def widget_session_count=: (Integer) -> Integer