Class: Cadenya::Models::ToolDenied
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolDenied
- Defined in:
- lib/cadenya/models/tool_denied.rb
Instance Attribute Summary collapse
-
#memo ⇒ String?
The memo provided by the reviewer when denying the tool call.
-
#tool_call_id ⇒ String?
The ID of the objective tool call record that was denied via the DenyToolCall RPC.
Instance Method Summary collapse
-
#initialize(memo: nil, tool_call_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ToolDenied for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(memo: nil, tool_call_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ToolDenied for more details.
|
|
# File 'lib/cadenya/models/tool_denied.rb', line 20
|
Instance Attribute Details
#memo ⇒ String?
The memo provided by the reviewer when denying the tool call. This is passed to the agent to provide further instructions.
11 |
# File 'lib/cadenya/models/tool_denied.rb', line 11 optional :memo, String |
#tool_call_id ⇒ String?
The ID of the objective tool call record that was denied via the DenyToolCall RPC.
18 |
# File 'lib/cadenya/models/tool_denied.rb', line 18 optional :tool_call_id, String, api_name: :toolCallId |