Class: Cadenya::Models::ToolResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolResult
- Defined in:
- lib/cadenya/models/tool_result.rb
Instance Attribute Summary collapse
-
#result ⇒ Cadenya::Models::Objectives::ObjectiveToolCallResult
ObjectiveToolCallResult is the content a tool returned after execution.
- #tool_call_id ⇒ String
Instance Method Summary collapse
-
#initialize(result:, tool_call_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ToolResult for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(result:, tool_call_id:) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ToolResult for more details.
|
|
# File 'lib/cadenya/models/tool_result.rb', line 20
|
Instance Attribute Details
#result ⇒ Cadenya::Models::Objectives::ObjectiveToolCallResult
ObjectiveToolCallResult is the content a tool returned after execution. Tools can return multiple content blocks, and blocks can be multi-modal (text, image, audio). Media blocks are stored by Cadenya and served as short-lived signed URLs rather than inline bytes.
13 |
# File 'lib/cadenya/models/tool_result.rb', line 13 required :result, -> { Cadenya::Objectives::ObjectiveToolCallResult } |
#tool_call_id ⇒ String
18 |
# File 'lib/cadenya/models/tool_result.rb', line 18 required :tool_call_id, String, api_name: :toolCallId |