Class: Cadenya::Models::ToolSetAdapterBare

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/tool_set_adapter_bare.rb,
sig/cadenya/models/tool_set_adapter_bare.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content_timeout: nil) ⇒ ToolSetAdapterBare

Some parameter documentations has been truncated, see Cadenya::Models::ToolSetAdapterBare for more details.

Bare tool sets define tools without an execution adapter. A bare tool call doesn't fire anything: the objective's workflow pauses and waits for an external API consumer to set the tool call's content (e.g. human-in-the-loop tools, or a reverse harness that polls for pending tool calls, executes locally, and reports results back via SetToolCallContent).

Parameters:

  • content_timeout (Integer) (defaults to: nil)

    How long to wait for content to be set before the tool call errors.

  • content_timeout: (Integer) (defaults to: nil)


# File 'lib/cadenya/models/tool_set_adapter_bare.rb', line 13

Instance Attribute Details

#content_timeoutInteger?

How long to wait for content to be set before the tool call errors. If unset, the call waits indefinitely.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


11
# File 'lib/cadenya/models/tool_set_adapter_bare.rb', line 11

optional :content_timeout, Integer, api_name: :contentTimeout

Instance Method Details

#to_hash{ content_timeout: Integer }

Returns:

  • ({ content_timeout: Integer })


12
# File 'sig/cadenya/models/tool_set_adapter_bare.rbs', line 12

def to_hash: -> { content_timeout: Integer }