Class: Cadenya::Models::ToolSetAdapterBareVariant
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolSetAdapterBareVariant
- Defined in:
- lib/cadenya/models/tool_set_adapter_bare_variant.rb,
sig/cadenya/models/tool_set_adapter_bare_variant.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#bare ⇒ Cadenya::Models::ToolSetAdapterBare
Bare tool sets define tools without an execution adapter.
- #type ⇒ Symbol, Cadenya::Models::ToolSetAdapterBareVariant::Type
Instance Method Summary collapse
-
#initialize(bare:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ToolSetAdapterBareVariant for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bare:, type:) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ToolSetAdapterBareVariant for more details.
|
|
# File 'lib/cadenya/models/tool_set_adapter_bare_variant.rb', line 21
|
Instance Attribute Details
#bare ⇒ Cadenya::Models::ToolSetAdapterBare
Bare tool sets define tools without an execution adapter. A bare tool call doesn't fire anything: the objective's workflow pauses and waits for an external API consumer to set the tool call's content (e.g. human-in-the-loop tools, or a reverse harness that polls for pending tool calls, executes locally, and reports results back via SetToolCallContent).
14 |
# File 'lib/cadenya/models/tool_set_adapter_bare_variant.rb', line 14 required :bare, -> { Cadenya::ToolSetAdapterBare } |
#type ⇒ Symbol, Cadenya::Models::ToolSetAdapterBareVariant::Type
19 |
# File 'lib/cadenya/models/tool_set_adapter_bare_variant.rb', line 19 required :type, enum: -> { Cadenya::ToolSetAdapterBareVariant::Type } |
Instance Method Details
#to_hash ⇒ {
19 |
# File 'sig/cadenya/models/tool_set_adapter_bare_variant.rbs', line 19
def to_hash: -> {
|