Class: Cadenya::Models::ToolSetAdapterMCP
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolSetAdapterMCP
- Defined in:
- lib/cadenya/models/tool_set_adapter_mcp.rb,
sig/cadenya/models/tool_set_adapter_mcp.rbs
Defined Under Namespace
Classes: JustInTime
Instance Attribute Summary collapse
-
#exclude_tools ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting).
- #headers ⇒ Hash{Symbol=>String}?
-
#include_tools ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting).
-
#just_in_time ⇒ Cadenya::Models::ToolSetAdapterMCP::JustInTime?
Defines behavior for just-in-time capable tool set adapters (IE: MCP).
-
#tool_approvals ⇒ Cadenya::Models::ApprovalRequirementFilterAlways, ...
Approval filters that will automatically set the approval requirement on tools synced from an external source.
- #url ⇒ String?
Instance Method Summary collapse
-
#initialize(exclude_tools: nil, headers: nil, include_tools: nil, just_in_time: nil, tool_approvals: nil, url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ToolSetAdapterMCP for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(exclude_tools: nil, headers: nil, include_tools: nil, just_in_time: nil, tool_approvals: nil, url: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ToolSetAdapterMCP for more details.
|
|
# File 'lib/cadenya/models/tool_set_adapter_mcp.rb', line 41
|
Instance Attribute Details
#exclude_tools ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting)
10 |
# File 'lib/cadenya/models/tool_set_adapter_mcp.rb', line 10 optional :exclude_tools, -> { Cadenya::ToolFilter }, api_name: :excludeTools |
#headers ⇒ Hash{Symbol=>String}?
15 |
# File 'lib/cadenya/models/tool_set_adapter_mcp.rb', line 15 optional :headers, Cadenya::Internal::Type::HashOf[String] |
#include_tools ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting)
21 |
# File 'lib/cadenya/models/tool_set_adapter_mcp.rb', line 21 optional :include_tools, -> { Cadenya::ToolFilter }, api_name: :includeTools |
#just_in_time ⇒ Cadenya::Models::ToolSetAdapterMCP::JustInTime?
Defines behavior for just-in-time capable tool set adapters (IE: MCP).
27 |
# File 'lib/cadenya/models/tool_set_adapter_mcp.rb', line 27 optional :just_in_time, -> { Cadenya::ToolSetAdapterMCP::JustInTime }, api_name: :justInTime |
#tool_approvals ⇒ Cadenya::Models::ApprovalRequirementFilterAlways, ...
Approval filters that will automatically set the approval requirement on tools synced from an external source
34 |
# File 'lib/cadenya/models/tool_set_adapter_mcp.rb', line 34 optional :tool_approvals, union: -> { Cadenya::ApprovalRequirementFilter }, api_name: :toolApprovals |
#url ⇒ String?
39 |
# File 'lib/cadenya/models/tool_set_adapter_mcp.rb', line 39 optional :url, String |
Instance Method Details
#to_hash ⇒ {
51 |
# File 'sig/cadenya/models/tool_set_adapter_mcp.rbs', line 51
def to_hash: -> {
|