Class: Cadenya::Models::ToolSetAdapterMcp::JustInTime

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/tool_set_adapter_mcp.rb,
sig/cadenya/models/tool_set_adapter_mcp.rbs

Overview

See Also:

  • Cadenya::Models::ToolSetAdapterMcp#just_in_time

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enabled: nil, fail_objective_on_tool_list_error: nil) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::ToolSetAdapterMcp::JustInTime for more details.

Defines behavior for just-in-time capable tool set adapters (IE: MCP).

Parameters:

  • enabled (Boolean) (defaults to: nil)
  • fail_objective_on_tool_list_error (Boolean) (defaults to: nil)

    If set, an objective will automatically be failed if tools cannot be loaded



# File 'lib/cadenya/models/tool_set_adapter_mcp.rb', line 75

Instance Attribute Details

#enabledBoolean?

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


62
# File 'lib/cadenya/models/tool_set_adapter_mcp.rb', line 62

optional :enabled, Cadenya::Internal::Type::Boolean

#fail_objective_on_tool_list_errorBoolean?

If set, an objective will automatically be failed if tools cannot be loaded in the initial stages of an objective being created. Tools are loaded asynchronously, so this setting is useful for ensuring that an objective continued any further if tools are not available.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


71
72
73
# File 'lib/cadenya/models/tool_set_adapter_mcp.rb', line 71

optional :fail_objective_on_tool_list_error,
Cadenya::Internal::Type::Boolean,
api_name: :failObjectiveOnToolListError

Instance Method Details

#to_hash{

Returns:

  • ({)


77
# File 'sig/cadenya/models/tool_set_adapter_mcp.rbs', line 77

def to_hash: -> {