Class: Cadenya::Models::ToolSetAdapterMcp::ToolApprovals
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolSetAdapterMcp::ToolApprovals
- Defined in:
- lib/cadenya/models/tool_set_adapter_mcp.rb
Overview
Instance Attribute Summary collapse
- #always ⇒ Boolean?
-
#only ⇒ Cadenya::Models::McpToolFilter?
Top-level filter with simple boolean logic (no nesting).
Instance Method Summary collapse
-
#initialize(always: nil, only: nil) ⇒ Object
constructor
Approval filters that will automatically set the approval requirement on the tools synced from the MCP server.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(always: nil, only: nil) ⇒ Object
Approval filters that will automatically set the approval requirement on the tools synced from the MCP server
|
|
# File 'lib/cadenya/models/tool_set_adapter_mcp.rb', line 62
|
Instance Attribute Details
#always ⇒ Boolean?
54 |
# File 'lib/cadenya/models/tool_set_adapter_mcp.rb', line 54 optional :always, Cadenya::Internal::Type::Boolean |
#only ⇒ Cadenya::Models::McpToolFilter?
Top-level filter with simple boolean logic (no nesting)
60 |
# File 'lib/cadenya/models/tool_set_adapter_mcp.rb', line 60 optional :only, -> { Cadenya::McpToolFilter } |