Class: Cadenya::Models::ToolSetAdapterOpenAPI
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolSetAdapterOpenAPI
- Defined in:
- lib/cadenya/models/tool_set_adapter_openapi.rb
Instance Attribute Summary collapse
-
#base_url ⇒ String?
Base URL for dispatching tool calls.
-
#exclude_tools ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting).
-
#headers ⇒ Hash{Symbol=>String}?
Headers sent when fetching the spec from a URL and when dispatching tool calls.
-
#include_tools ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting).
-
#server_name ⇒ String?
Name of the server entry in the spec’s servers array (OpenAPI 3.2 server.name field).
-
#tool_approvals ⇒ Cadenya::Models::ApprovalRequirementFilter?
Approval filters that will automatically set the approval requirement on tools synced from an external source.
-
#upload_id ⇒ String?
ID of a COMPLETE Upload containing the OpenAPI spec document.
-
#url ⇒ String?
URL to fetch the OpenAPI spec from.
Instance Method Summary collapse
-
#initialize(base_url: nil, exclude_tools: nil, headers: nil, include_tools: nil, server_name: nil, tool_approvals: nil, upload_id: nil, url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ToolSetAdapterOpenAPI for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(base_url: nil, exclude_tools: nil, headers: nil, include_tools: nil, server_name: nil, tool_approvals: nil, upload_id: nil, url: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ToolSetAdapterOpenAPI for more details.
|
|
# File 'lib/cadenya/models/tool_set_adapter_openapi.rb', line 58
|
Instance Attribute Details
#base_url ⇒ String?
Base URL for dispatching tool calls. If set, overrides the server resolved from the spec’s servers array.
11 |
# File 'lib/cadenya/models/tool_set_adapter_openapi.rb', line 11 optional :base_url, String, api_name: :baseUrl |
#exclude_tools ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting)
17 |
# File 'lib/cadenya/models/tool_set_adapter_openapi.rb', line 17 optional :exclude_tools, -> { Cadenya::ToolFilter }, api_name: :excludeTools |
#headers ⇒ Hash{Symbol=>String}?
Headers sent when fetching the spec from a URL and when dispatching tool calls.
23 |
# File 'lib/cadenya/models/tool_set_adapter_openapi.rb', line 23 optional :headers, Cadenya::Internal::Type::HashOf[String] |
#include_tools ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting)
29 |
# File 'lib/cadenya/models/tool_set_adapter_openapi.rb', line 29 optional :include_tools, -> { Cadenya::ToolFilter }, api_name: :includeTools |
#server_name ⇒ String?
Name of the server entry in the spec’s servers array (OpenAPI 3.2 server.name field). Used to select which server URL to dispatch to when base_url is not set. If unset, the first server is used. Ignored when base_url is set.
37 |
# File 'lib/cadenya/models/tool_set_adapter_openapi.rb', line 37 optional :server_name, String, api_name: :serverName |
#tool_approvals ⇒ Cadenya::Models::ApprovalRequirementFilter?
Approval filters that will automatically set the approval requirement on tools synced from an external source
44 |
# File 'lib/cadenya/models/tool_set_adapter_openapi.rb', line 44 optional :tool_approvals, -> { Cadenya::ApprovalRequirementFilter }, api_name: :toolApprovals |
#upload_id ⇒ String?
ID of a COMPLETE Upload containing the OpenAPI spec document.
50 |
# File 'lib/cadenya/models/tool_set_adapter_openapi.rb', line 50 optional :upload_id, String, api_name: :uploadId |
#url ⇒ String?
URL to fetch the OpenAPI spec from. Synced automatically every hour.
56 |
# File 'lib/cadenya/models/tool_set_adapter_openapi.rb', line 56 optional :url, String |