Class: Cadenya::Models::ToolSetAdapterOpenAPIURL
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolSetAdapterOpenAPIURL
- Defined in:
- lib/cadenya/models/tool_set_adapter_openapi_url.rb,
sig/cadenya/models/tool_set_adapter_openapi_url.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#base_url ⇒ String?
Base URL for dispatching tool calls.
-
#exclude_tools ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting).
-
#headers ⇒ Hash{Symbol=>String}?
Headers sent when fetching the spec from a URL and when dispatching tool calls.
-
#include_tools ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting).
-
#server_name ⇒ String?
Name of the server entry in the spec's servers array (OpenAPI 3.2 server.name field).
-
#tool_approvals ⇒ Cadenya::Models::ApprovalRequirementFilterAlways, ...
Approval filters that will automatically set the approval requirement on tools synced from an external source.
- #type ⇒ Symbol, Cadenya::Models::ToolSetAdapterOpenAPIURL::Type
-
#url ⇒ String
URL to fetch the OpenAPI spec from.
Instance Method Summary collapse
-
#initialize(type:, url:, base_url: nil, exclude_tools: nil, headers: nil, include_tools: nil, server_name: nil, tool_approvals: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ToolSetAdapterOpenAPIURL for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:, url:, base_url: nil, exclude_tools: nil, headers: nil, include_tools: nil, server_name: nil, tool_approvals: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ToolSetAdapterOpenAPIURL for more details.
|
|
# File 'lib/cadenya/models/tool_set_adapter_openapi_url.rb', line 57
|
Instance Attribute Details
#base_url ⇒ String?
Base URL for dispatching tool calls. If set, overrides the server resolved from the spec's servers array.
22 |
# File 'lib/cadenya/models/tool_set_adapter_openapi_url.rb', line 22 optional :base_url, String, api_name: :baseUrl |
#exclude_tools ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting)
28 |
# File 'lib/cadenya/models/tool_set_adapter_openapi_url.rb', line 28 optional :exclude_tools, -> { Cadenya::ToolFilter }, api_name: :excludeTools |
#headers ⇒ Hash{Symbol=>String}?
Headers sent when fetching the spec from a URL and when dispatching tool calls.
34 |
# File 'lib/cadenya/models/tool_set_adapter_openapi_url.rb', line 34 optional :headers, Cadenya::Internal::Type::HashOf[String] |
#include_tools ⇒ Cadenya::Models::ToolFilter?
Top-level filter with simple boolean logic (no nesting)
40 |
# File 'lib/cadenya/models/tool_set_adapter_openapi_url.rb', line 40 optional :include_tools, -> { Cadenya::ToolFilter }, api_name: :includeTools |
#server_name ⇒ String?
Name of the server entry in the spec's servers array (OpenAPI 3.2 server.name field). Used to select which server URL to dispatch to when base_url is not set. If unset, the first server is used. Ignored when base_url is set.
48 |
# File 'lib/cadenya/models/tool_set_adapter_openapi_url.rb', line 48 optional :server_name, String, api_name: :serverName |
#tool_approvals ⇒ Cadenya::Models::ApprovalRequirementFilterAlways, ...
Approval filters that will automatically set the approval requirement on tools synced from an external source
55 |
# File 'lib/cadenya/models/tool_set_adapter_openapi_url.rb', line 55 optional :tool_approvals, union: -> { Cadenya::ApprovalRequirementFilter }, api_name: :toolApprovals |
#type ⇒ Symbol, Cadenya::Models::ToolSetAdapterOpenAPIURL::Type
9 |
# File 'lib/cadenya/models/tool_set_adapter_openapi_url.rb', line 9 required :type, enum: -> { Cadenya::ToolSetAdapterOpenAPIURL::Type } |
#url ⇒ String
URL to fetch the OpenAPI spec from. Synced automatically every hour.
15 |
# File 'lib/cadenya/models/tool_set_adapter_openapi_url.rb', line 15 required :url, String |
Instance Method Details
#to_hash ⇒ {
57 |
# File 'sig/cadenya/models/tool_set_adapter_openapi_url.rbs', line 57
def to_hash: -> {
|