Class: Cadenya::Models::ToolSetListEventsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cadenya/models/tool_set_list_events_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workspace_id:, tool_set_id:, cursor: nil, include_info: nil, limit: nil, sort_order: nil, request_options: {}) ⇒ Object

Parameters:

  • workspace_id (String)
  • tool_set_id (String)
  • cursor (String) (defaults to: nil)

    Pagination cursor from previous response

  • include_info (Boolean) (defaults to: nil)

    When set to true you may use more of your alloted API rate-limit

  • limit (Integer) (defaults to: nil)

    Maximum number of results to return

  • sort_order (String) (defaults to: nil)

    Sort order for results (asc or desc by creation time)

  • request_options (Cadenya::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/cadenya/models/tool_set_list_events_params.rb', line 44

Instance Attribute Details

#cursorString?

Pagination cursor from previous response

Returns:

  • (String, nil)


24
# File 'lib/cadenya/models/tool_set_list_events_params.rb', line 24

optional :cursor, String

#include_infoBoolean?

When set to true you may use more of your alloted API rate-limit

Returns:

  • (Boolean, nil)


30
# File 'lib/cadenya/models/tool_set_list_events_params.rb', line 30

optional :include_info, Cadenya::Internal::Type::Boolean

#limitInteger?

Maximum number of results to return

Returns:

  • (Integer, nil)


36
# File 'lib/cadenya/models/tool_set_list_events_params.rb', line 36

optional :limit, Integer

#sort_orderString?

Sort order for results (asc or desc by creation time)

Returns:

  • (String, nil)


42
# File 'lib/cadenya/models/tool_set_list_events_params.rb', line 42

optional :sort_order, String

#tool_set_idString

Returns:

  • (String)


18
# File 'lib/cadenya/models/tool_set_list_events_params.rb', line 18

required :tool_set_id, String

#workspace_idString

Returns:

  • (String)


13
# File 'lib/cadenya/models/tool_set_list_events_params.rb', line 13

required :workspace_id, String