Class: Cadenya::Models::ToolSetListUsageParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolSetListUsageParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cadenya/models/tool_set_list_usage_params.rb,
sig/cadenya/models/tool_set_list_usage_params.rbs
Overview
Instance Attribute Summary collapse
-
#cursor ⇒ String?
Pagination cursor from previous response.
-
#limit ⇒ Integer?
Maximum number of results to return.
-
#sort_order ⇒ String?
Sort order for results (asc or desc by assignment creation time).
-
#tool_id ⇒ String?
When set, lists only variations with a direct assignment of this individual tool.
- #tool_set_id ⇒ String
- #workspace_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(tool_set_id:, workspace_id: nil, cursor: nil, limit: nil, sort_order: nil, tool_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ToolSetListUsageParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tool_set_id:, workspace_id: nil, cursor: nil, limit: nil, sort_order: nil, tool_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ToolSetListUsageParams for more details.
|
|
# File 'lib/cadenya/models/tool_set_list_usage_params.rb', line 46
|
Instance Attribute Details
#cursor ⇒ String?
Pagination cursor from previous response
24 |
# File 'lib/cadenya/models/tool_set_list_usage_params.rb', line 24 optional :cursor, String |
#limit ⇒ Integer?
Maximum number of results to return
30 |
# File 'lib/cadenya/models/tool_set_list_usage_params.rb', line 30 optional :limit, Integer |
#sort_order ⇒ String?
Sort order for results (asc or desc by assignment creation time)
36 |
# File 'lib/cadenya/models/tool_set_list_usage_params.rb', line 36 optional :sort_order, String |
#tool_id ⇒ String?
When set, lists only variations with a direct assignment of this individual tool. When unset, lists variations assigned the whole tool set. The tool must belong to the tool set.
44 |
# File 'lib/cadenya/models/tool_set_list_usage_params.rb', line 44 optional :tool_id, String |
#tool_set_id ⇒ String
18 |
# File 'lib/cadenya/models/tool_set_list_usage_params.rb', line 18 required :tool_set_id, String |
#workspace_id ⇒ String?
13 |
# File 'lib/cadenya/models/tool_set_list_usage_params.rb', line 13 optional :workspace_id, String |
Instance Method Details
#to_hash ⇒ {
50 |
# File 'sig/cadenya/models/tool_set_list_usage_params.rbs', line 50
def to_hash: -> {
|