Class: Cadenya::Models::ToolSets::ConfigHTTP

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/tool_sets/config_http.rb

Defined Under Namespace

Modules: RequestMethod

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(request_method:, headers: nil, path: nil, query: nil, request_body_content_type: nil, request_body_template: nil) ⇒ Object

Parameters:

  • request_method (Symbol, Cadenya::Models::ToolSets::ConfigHTTP::RequestMethod)
  • headers (Hash{Symbol=>String}) (defaults to: nil)
  • path (String) (defaults to: nil)
  • query (String) (defaults to: nil)
  • request_body_content_type (String) (defaults to: nil)
  • request_body_template (String) (defaults to: nil)

    These are only used when the request method is a POST, PUT, or PATCH



# File 'lib/cadenya/models/tool_sets/config_http.rb', line 40

Instance Attribute Details

#headersHash{Symbol=>String}?

Returns:

  • (Hash{Symbol=>String}, nil)


17
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 17

optional :headers, Cadenya::Internal::Type::HashOf[String]

#pathString?

Returns:

  • (String, nil)


22
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 22

optional :path, String

#queryString?

Returns:

  • (String, nil)


27
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 27

optional :query, String

#request_body_content_typeString?

Returns:

  • (String, nil)


32
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 32

optional :request_body_content_type, String, api_name: :requestBodyContentType

#request_body_templateString?

These are only used when the request method is a POST, PUT, or PATCH

Returns:

  • (String, nil)


38
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 38

optional :request_body_template, String, api_name: :requestBodyTemplate

#request_methodSymbol, Cadenya::Models::ToolSets::ConfigHTTP::RequestMethod



10
11
12
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 10

required :request_method,
enum: -> { Cadenya::ToolSets::ConfigHTTP::RequestMethod },
api_name: :requestMethod