Class: Cadenya::Models::ToolSets::ConfigMcp
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolSets::ConfigMcp
- Defined in:
- lib/cadenya/models/tool_sets/config_mcp.rb,
sig/cadenya/models/tool_sets/config_mcp.rbs
Instance Attribute Summary collapse
-
#annotations ⇒ Cadenya::Models::ToolSets::McpAnnotations?
Behavior hints synced from the MCP server's tool definition (ToolAnnotations in the MCP specification).
Instance Method Summary collapse
-
#initialize(annotations: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ConfigMcp for more details.
- #to_hash ⇒ { annotations: Cadenya::ToolSets::McpAnnotations }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(annotations: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ToolSets::ConfigMcp for more details.
|
|
# File 'lib/cadenya/models/tool_sets/config_mcp.rb', line 17
|
Instance Attribute Details
#annotations ⇒ Cadenya::Models::ToolSets::McpAnnotations?
Behavior hints synced from the MCP server's tool definition (ToolAnnotations in the MCP specification). All hints are advisory: servers are not required to send them, and clients should not rely on them for security decisions. Absent hints keep the MCP spec defaults (destructiveHint and openWorldHint default to true; readOnlyHint and idempotentHint default to false).
15 |
# File 'lib/cadenya/models/tool_sets/config_mcp.rb', line 15 optional :annotations, -> { Cadenya::ToolSets::McpAnnotations } |
Instance Method Details
#to_hash ⇒ { annotations: Cadenya::ToolSets::McpAnnotations }
17 |
# File 'sig/cadenya/models/tool_sets/config_mcp.rbs', line 17
def to_hash: -> { annotations: Cadenya::ToolSets::McpAnnotations }
|