Class: Cadenya::Models::ToolSets::McpAnnotations

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/tool_sets/mcp_annotations.rb,
sig/cadenya/models/tool_sets/mcp_annotations.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(destructive_hint: nil, idempotent_hint: nil, open_world_hint: nil, read_only_hint: nil, title: nil) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::ToolSets::McpAnnotations for more details.

Behavior hints synced from the MCP server's tool definition (ToolAnnotations in the MCP specification). All hints are advisory: servers are not required to send them, and clients should not rely on them for security decisions. Absent hints keep the MCP spec defaults (destructiveHint and openWorldHint default to true; readOnlyHint and idempotentHint default to false).

Parameters:

  • destructive_hint (Boolean) (defaults to: nil)

    If true, the tool may perform destructive updates to its environment.

  • idempotent_hint (Boolean) (defaults to: nil)

    If true, calling the tool repeatedly with the same arguments has no

  • open_world_hint (Boolean) (defaults to: nil)

    If true, the tool may interact with an "open world" of external

  • read_only_hint (Boolean) (defaults to: nil)

    If true, the tool does not modify its environment.

  • title (String) (defaults to: nil)

    A human-readable title for the tool.



# File 'lib/cadenya/models/tool_sets/mcp_annotations.rb', line 40

Instance Attribute Details

#destructive_hintBoolean?

If true, the tool may perform destructive updates to its environment. Only meaningful when read_only_hint is false.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


12
# File 'lib/cadenya/models/tool_sets/mcp_annotations.rb', line 12

optional :destructive_hint, Cadenya::Internal::Type::Boolean, api_name: :destructiveHint

#idempotent_hintBoolean?

If true, calling the tool repeatedly with the same arguments has no additional effect. Only meaningful when read_only_hint is false.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


19
# File 'lib/cadenya/models/tool_sets/mcp_annotations.rb', line 19

optional :idempotent_hint, Cadenya::Internal::Type::Boolean, api_name: :idempotentHint

#open_world_hintBoolean?

If true, the tool may interact with an "open world" of external entities (e.g. web search); if false, its domain is closed.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


26
# File 'lib/cadenya/models/tool_sets/mcp_annotations.rb', line 26

optional :open_world_hint, Cadenya::Internal::Type::Boolean, api_name: :openWorldHint

#read_only_hintBoolean?

If true, the tool does not modify its environment.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


32
# File 'lib/cadenya/models/tool_sets/mcp_annotations.rb', line 32

optional :read_only_hint, Cadenya::Internal::Type::Boolean, api_name: :readOnlyHint

#titleString?

A human-readable title for the tool.

Parameters:

  • (String)

Returns:

  • (String, nil)


38
# File 'lib/cadenya/models/tool_sets/mcp_annotations.rb', line 38

optional :title, String

Instance Method Details

#to_hash{

Returns:

  • ({)


42
# File 'sig/cadenya/models/tool_sets/mcp_annotations.rbs', line 42

def to_hash: -> {