Class: Cadenya::Models::ToolSets::ToolInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/tool_sets/tool_info.rb,
sig/cadenya/models/tool_sets/tool_info.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_by: nil, signature: nil, tool_set: nil) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::ToolSets::ToolInfo for more details.

Parameters:

  • created_by (Cadenya::Models::Profile) (defaults to: nil)

    A profile identifies a user or non-human principal (such as an API key)

  • signature (String) (defaults to: nil)

    Content signature identifying the tool within its tool set: a hash of the

  • tool_set (Cadenya::Models::ResourceMetadata) (defaults to: nil)

    Standard metadata for persistent, named resources (e.g., agents, tools, prompts)



# File 'lib/cadenya/models/tool_sets/tool_info.rb', line 32

Instance Attribute Details

#created_byCadenya::Models::Profile?

A profile identifies a user or non-human principal (such as an API key) at the account level. Profiles are account-scoped and can be granted access to multiple workspaces.

Parameters:

Returns:



13
# File 'lib/cadenya/models/tool_sets/tool_info.rb', line 13

optional :created_by, -> { Cadenya::Profile }, api_name: :createdBy

#signatureString? (readonly)

Returns the value of attribute signature.

Returns:

  • (String, nil)


20
21
22
# File 'sig/cadenya/models/tool_sets/tool_info.rbs', line 20

def signature
  @signature
end

#tool_setCadenya::Models::ResourceMetadata?

Standard metadata for persistent, named resources (e.g., agents, tools, prompts)



19
# File 'lib/cadenya/models/tool_sets/tool_info.rb', line 19

optional :tool_set, -> { Cadenya::ResourceMetadata }, api_name: :toolSet

Instance Method Details

#signature=String (readonly)

Parameters:

  • (String)

Returns:

  • (String)


22
# File 'sig/cadenya/models/tool_sets/tool_info.rbs', line 22

def signature=: (String) -> String

#to_hash{

Returns:

  • ({)


30
# File 'sig/cadenya/models/tool_sets/tool_info.rbs', line 30

def to_hash: -> {