Class: Cadenya::Models::ToolSets::ToolListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolSets::ToolListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cadenya/models/tool_sets/tool_list_params.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#bundle_key ⇒ String?
Filter by bundle_key — return only resources owned by this bundle.
-
#cursor ⇒ String?
Pagination cursor from previous response.
-
#include_info ⇒ Boolean?
When set to true you may use more of your alloted API rate-limit.
-
#limit ⇒ Integer?
Maximum number of results to return.
-
#names ⇒ Array<String>?
Filter by tool name (exact match).
-
#prefix ⇒ String?
Filter expression (query param: prefix).
-
#query ⇒ String?
Free-form search query.
-
#requires_approval ⇒ Boolean?
Filter by approval requirement.
-
#sort_order ⇒ String?
Sort order for results (asc or desc by creation time).
-
#statuses ⇒ Array<Symbol, Cadenya::Models::ToolSets::ToolListParams::Status>?
Filter by tool status.
- #tool_set_id ⇒ String
- #workspace_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Cadenya::Internal::Type::BaseModel
Instance Attribute Details
#bundle_key ⇒ String?
Filter by bundle_key — return only resources owned by this bundle.
25 |
# File 'lib/cadenya/models/tool_sets/tool_list_params.rb', line 25 optional :bundle_key, String |
#cursor ⇒ String?
Pagination cursor from previous response
31 |
# File 'lib/cadenya/models/tool_sets/tool_list_params.rb', line 31 optional :cursor, String |
#include_info ⇒ Boolean?
When set to true you may use more of your alloted API rate-limit
37 |
# File 'lib/cadenya/models/tool_sets/tool_list_params.rb', line 37 optional :include_info, Cadenya::Internal::Type::Boolean |
#limit ⇒ Integer?
Maximum number of results to return
43 |
# File 'lib/cadenya/models/tool_sets/tool_list_params.rb', line 43 optional :limit, Integer |
#names ⇒ Array<String>?
Filter by tool name (exact match). Multiple values are OR’d together.
49 |
# File 'lib/cadenya/models/tool_sets/tool_list_params.rb', line 49 optional :names, Cadenya::Internal::Type::ArrayOf[String] |
#prefix ⇒ String?
Filter expression (query param: prefix)
55 |
# File 'lib/cadenya/models/tool_sets/tool_list_params.rb', line 55 optional :prefix, String |
#query ⇒ String?
Free-form search query
61 |
# File 'lib/cadenya/models/tool_sets/tool_list_params.rb', line 61 optional :query, String |
#requires_approval ⇒ Boolean?
Filter by approval requirement. Omitted = no filter; true = only tools requiring approval; false = only tools not requiring approval.
68 |
# File 'lib/cadenya/models/tool_sets/tool_list_params.rb', line 68 optional :requires_approval, Cadenya::Internal::Type::Boolean |
#sort_order ⇒ String?
Sort order for results (asc or desc by creation time)
74 |
# File 'lib/cadenya/models/tool_sets/tool_list_params.rb', line 74 optional :sort_order, String |
#statuses ⇒ Array<Symbol, Cadenya::Models::ToolSets::ToolListParams::Status>?
Filter by tool status. Multiple values are OR’d together.
80 81 |
# File 'lib/cadenya/models/tool_sets/tool_list_params.rb', line 80 optional :statuses, -> { Cadenya::Internal::Type::ArrayOf[enum: Cadenya::ToolSets::ToolListParams::Status] } |
#tool_set_id ⇒ String
19 |
# File 'lib/cadenya/models/tool_sets/tool_list_params.rb', line 19 required :tool_set_id, String |
#workspace_id ⇒ String
14 |
# File 'lib/cadenya/models/tool_sets/tool_list_params.rb', line 14 required :workspace_id, String |