Class: Cadenya::Models::WidgetListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::WidgetListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cadenya/models/widget_list_params.rb,
sig/cadenya/models/widget_list_params.rbs
Overview
Instance Attribute Summary collapse
-
#agent_id ⇒ String?
Filter to widgets bound to a specific agent.
-
#cursor ⇒ String?
Pagination cursor from previous response.
-
#include_info ⇒ Boolean?
When true, the
infofield on each returned widget is populated. -
#labels ⇒ String?
Filters by metadata labels.
-
#limit ⇒ Integer?
Maximum number of results to return.
-
#sort_order ⇒ String?
Sort order for results (asc or desc by creation time).
- #workspace_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(workspace_id: nil, agent_id: nil, cursor: nil, include_info: nil, labels: nil, limit: nil, sort_order: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WidgetListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(workspace_id: nil, agent_id: nil, cursor: nil, include_info: nil, labels: nil, limit: nil, sort_order: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::WidgetListParams for more details.
|
|
# File 'lib/cadenya/models/widget_list_params.rb', line 55
|
Instance Attribute Details
#agent_id ⇒ String?
Filter to widgets bound to a specific agent. Accepts the canonical agent_…
form or the external_id:<value> form.
20 |
# File 'lib/cadenya/models/widget_list_params.rb', line 20 optional :agent_id, String |
#cursor ⇒ String?
Pagination cursor from previous response.
26 |
# File 'lib/cadenya/models/widget_list_params.rb', line 26 optional :cursor, String |
#include_info ⇒ Boolean?
When true, the info field on each returned widget is populated. Requests with
this flag count more against your rate limit.
33 |
# File 'lib/cadenya/models/widget_list_params.rb', line 33 optional :include_info, Cadenya::Internal::Type::Boolean |
#labels ⇒ String?
Filters by metadata labels. Comma-separated key=value pairs, e.g. "env=prod,team=ai". A resource matches only if every pair matches exactly (AND semantics).
41 |
# File 'lib/cadenya/models/widget_list_params.rb', line 41 optional :labels, String |
#limit ⇒ Integer?
Maximum number of results to return.
47 |
# File 'lib/cadenya/models/widget_list_params.rb', line 47 optional :limit, Integer |
#sort_order ⇒ String?
Sort order for results (asc or desc by creation time).
53 |
# File 'lib/cadenya/models/widget_list_params.rb', line 53 optional :sort_order, String |
#workspace_id ⇒ String?
13 |
# File 'lib/cadenya/models/widget_list_params.rb', line 13 optional :workspace_id, String |
Instance Method Details
#to_hash ⇒ {
58 |
# File 'sig/cadenya/models/widget_list_params.rbs', line 58
def to_hash: -> {
|