Class: Cadenya::Models::WidgetSessionCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::WidgetSessionCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cadenya/models/widget_session_create_params.rb,
sig/cadenya/models/widget_session_create_params.rbs
Overview
Defined Under Namespace
Classes: Secret
Constant Summary collapse
- Cadenya =
Instance Attribute Summary collapse
-
#metadata ⇒ Cadenya::Models::CreateOperationMetadata?
CreateOperationMetadata contains the user-provided fields for creating an operation.
-
#secrets ⇒ Array<Cadenya::Models::WidgetSessionCreateParams::Secret>?
Secrets to attach to the session.
-
#spec ⇒ Cadenya::Models::WidgetSessionSpec
WidgetSessionSpec is the configuration of a session, fixed at mint.
- #workspace_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
34 |
# File 'sig/cadenya/models/widget_session_create_params.rbs', line 34
def initialize: (
|
Instance Attribute Details
#metadata ⇒ Cadenya::Models::CreateOperationMetadata?
CreateOperationMetadata contains the user-provided fields for creating an operation. Read-only fields (id, account_id, workspace_id, created_at, profile_id) are excluded since they are set by the server.
27 |
# File 'lib/cadenya/models/widget_session_create_params.rb', line 27 optional :metadata, -> { Cadenya::CreateOperationMetadata } |
#secrets ⇒ Array<Cadenya::Models::WidgetSessionCreateParams::Secret>?
Secrets to attach to the session.
33 |
# File 'lib/cadenya/models/widget_session_create_params.rb', line 33 optional :secrets, -> { Cadenya::Internal::Type::ArrayOf[Cadenya::WidgetSessionCreateParams::Secret] } |
#spec ⇒ Cadenya::Models::WidgetSessionSpec
WidgetSessionSpec is the configuration of a session, fixed at mint.
19 |
# File 'lib/cadenya/models/widget_session_create_params.rb', line 19 required :spec, -> { Cadenya::WidgetSessionSpec } |
#workspace_id ⇒ String?
13 |
# File 'lib/cadenya/models/widget_session_create_params.rb', line 13 optional :workspace_id, String |
Instance Method Details
#to_hash ⇒ {
42 |
# File 'sig/cadenya/models/widget_session_create_params.rbs', line 42
def to_hash: -> {
|