Class: Cadenya::Models::WidgetSessionListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cadenya/models/widget_session_list_params.rb,
sig/cadenya/models/widget_session_list_params.rbs

Overview

See Also:

  • Cadenya::Resources::WidgetSessions#list

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workspace_id: nil, cursor: nil, include_info: nil, labels: nil, limit: nil, sort_order: nil, state: nil, subject_id: nil, tenant_id: nil, widget_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::WidgetSessionListParams for more details.

Parameters:

  • workspace_id (String) (defaults to: nil)
  • cursor (String) (defaults to: nil)

    Pagination cursor from previous response.

  • include_info (Boolean) (defaults to: nil)

    When true, the info field on each returned session is populated.

  • labels (String) (defaults to: nil)

    Filters by metadata labels. Comma-separated key=value pairs,

  • limit (Integer) (defaults to: nil)

    Maximum number of results to return.

  • sort_order (String) (defaults to: nil)

    Sort order for results (asc or desc by creation time).

  • state (Symbol, Cadenya::Models::WidgetSessionListParams::State) (defaults to: nil)

    Filter by state.

  • subject_id (String) (defaults to: nil)

    Filter to sessions asserted for a subject. Accepts the canonical

  • tenant_id (String) (defaults to: nil)

    Filter to sessions belonging to a tenant. Accepts the canonical

  • widget_id (String) (defaults to: nil)

    Filter to sessions on a specific widget. Accepts the canonical wgt_…

  • request_options (Cadenya::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/cadenya/models/widget_session_list_params.rb', line 76

Instance Attribute Details

#cursorString?

Pagination cursor from previous response.

Parameters:

  • (String)

Returns:

  • (String, nil)


19
# File 'lib/cadenya/models/widget_session_list_params.rb', line 19

optional :cursor, String

#include_infoBoolean?

When true, the info field on each returned session is populated. Requests with this flag count more against your rate limit.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


26
# File 'lib/cadenya/models/widget_session_list_params.rb', line 26

optional :include_info, Cadenya::Internal::Type::Boolean

#labelsString?

Filters by metadata labels. Comma-separated key=value pairs, e.g. "env=prod,team=ai". A resource matches only if every pair matches exactly (AND semantics).

Parameters:

  • (String)

Returns:

  • (String, nil)


34
# File 'lib/cadenya/models/widget_session_list_params.rb', line 34

optional :labels, String

#limitInteger?

Maximum number of results to return.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


40
# File 'lib/cadenya/models/widget_session_list_params.rb', line 40

optional :limit, Integer

#sort_orderString?

Sort order for results (asc or desc by creation time).

Parameters:

  • (String)

Returns:

  • (String, nil)


46
# File 'lib/cadenya/models/widget_session_list_params.rb', line 46

optional :sort_order, String

#stateSymbol, ...

Filter by state.



52
# File 'lib/cadenya/models/widget_session_list_params.rb', line 52

optional :state, enum: -> { Cadenya::WidgetSessionListParams::State }

#subject_idString?

Filter to sessions asserted for a subject. Accepts the canonical subj_… form or the external_id:<value> form; the external_id form is scoped within a tenant and requires tenant_id to also be set.

Parameters:

  • (String)

Returns:

  • (String, nil)


60
# File 'lib/cadenya/models/widget_session_list_params.rb', line 60

optional :subject_id, String

#tenant_idString?

Filter to sessions belonging to a tenant. Accepts the canonical tenant_… form or the external_id:<value> form.

Parameters:

  • (String)

Returns:

  • (String, nil)


67
# File 'lib/cadenya/models/widget_session_list_params.rb', line 67

optional :tenant_id, String

#widget_idString?

Filter to sessions on a specific widget. Accepts the canonical wgt_… form or the external_id:<value> form.

Parameters:

  • (String)

Returns:

  • (String, nil)


74
# File 'lib/cadenya/models/widget_session_list_params.rb', line 74

optional :widget_id, String

#workspace_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


13
# File 'lib/cadenya/models/widget_session_list_params.rb', line 13

optional :workspace_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


78
# File 'sig/cadenya/models/widget_session_list_params.rbs', line 78

def to_hash: -> {