Class: Cadenya::Models::Workspace
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Workspace
- Defined in:
- lib/cadenya/models/workspace.rb,
sig/cadenya/models/workspace.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#info ⇒ Cadenya::Workspace::Info?
readonly
Returns the value of attribute info.
-
#metadata ⇒ Cadenya::Models::AccountResourceMetadata
AccountResourceMetadata is used to represent a resource that is associated to an account but not to a workspace.
- #spec ⇒ Cadenya::Models::WorkspaceSpec
-
#status ⇒ Cadenya::Models::Workspace::status?
readonly
Returns the value of attribute status.
Instance Method Summary collapse
- #info ⇒ Cadenya::Workspace::Info readonly
-
#initialize(total_agents: nil, total_agent_variations: nil, total_available_tools: nil, total_memory_entries: nil) ⇒ Object
constructor
WorkspaceInfo returns counts.
- #status ⇒ Object readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(total_agents: nil, total_agent_variations: nil, total_available_tools: nil, total_memory_entries: nil) ⇒ Object
WorkspaceInfo returns counts
|
|
# File 'lib/cadenya/models/workspace.rb', line 34
|
Instance Attribute Details
#info ⇒ Cadenya::Workspace::Info? (readonly)
Returns the value of attribute info.
16 17 18 |
# File 'sig/cadenya/models/workspace.rbs', line 16 def info @info end |
#metadata ⇒ Cadenya::Models::AccountResourceMetadata
AccountResourceMetadata is used to represent a resource that is associated to an account but not to a workspace.
12 |
# File 'lib/cadenya/models/workspace.rb', line 12 required :metadata, -> { Cadenya::AccountResourceMetadata } |
#spec ⇒ Cadenya::Models::WorkspaceSpec
17 |
# File 'lib/cadenya/models/workspace.rb', line 17 required :spec, -> { Cadenya::WorkspaceSpec } |
#status ⇒ Cadenya::Models::Workspace::status? (readonly)
Returns the value of attribute status.
20 21 22 |
# File 'sig/cadenya/models/workspace.rbs', line 20 def status @status end |
Instance Method Details
#info= ⇒ Cadenya::Workspace::Info (readonly)
18 |
# File 'sig/cadenya/models/workspace.rbs', line 18
def info=: (Cadenya::Workspace::Info) -> Cadenya::Workspace::Info
|
#status= ⇒ Object (readonly)
22 |
# File 'sig/cadenya/models/workspace.rbs', line 22
def status=: (
|
#to_hash ⇒ {
33 |
# File 'sig/cadenya/models/workspace.rbs', line 33
def to_hash: -> {
|