Class: Cadenya::Models::WorkspaceAdminListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cadenya/models/workspace_admin_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cursor: nil, include_archived: nil, limit: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::WorkspaceAdminListParams for more details.

Parameters:

  • cursor (String) (defaults to: nil)

    Pagination cursor from previous response

  • include_archived (Boolean) (defaults to: nil)

    When true, archived workspaces are included in the results. Defaults to

  • limit (Integer) (defaults to: nil)

    Maximum number of results to return

  • request_options (Cadenya::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/cadenya/models/workspace_admin_list_params.rb', line 29

Instance Attribute Details

#cursorString?

Pagination cursor from previous response

Returns:

  • (String, nil)


14
# File 'lib/cadenya/models/workspace_admin_list_params.rb', line 14

optional :cursor, String

#include_archivedBoolean?

When true, archived workspaces are included in the results. Defaults to false (active workspaces only).

Returns:

  • (Boolean, nil)


21
# File 'lib/cadenya/models/workspace_admin_list_params.rb', line 21

optional :include_archived, Cadenya::Internal::Type::Boolean

#limitInteger?

Maximum number of results to return

Returns:

  • (Integer, nil)


27
# File 'lib/cadenya/models/workspace_admin_list_params.rb', line 27

optional :limit, Integer