Class: Cadenya::Models::AIProviderKeySpec::Credentials
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::AIProviderKeySpec::Credentials
- Defined in:
- lib/cadenya/models/ai_provider_key_spec.rb,
sig/cadenya/models/ai_provider_key_spec.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#api_key ⇒ Cadenya::Models::AIProviderKeySpec::Credentials::APIKey?
CredentialAPIKey carries a single bearer/header API key.
-
#headers ⇒ Cadenya::Models::AIProviderKeySpec::Credentials::Headers?
CredentialHeaders carries arbitrary HTTP headers sent with every request to the provider (e.g. "Bearer ...", "X-Api-Key": "...").
Instance Method Summary collapse
-
#initialize(api_key: nil) ⇒ Object
constructor
CredentialAPIKey carries a single bearer/header API key.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(api_key: nil) ⇒ Object
CredentialAPIKey carries a single bearer/header API key.
|
|
# File 'lib/cadenya/models/ai_provider_key_spec.rb', line 147
|
Instance Attribute Details
#api_key ⇒ Cadenya::Models::AIProviderKeySpec::Credentials::APIKey?
CredentialAPIKey carries a single bearer/header API key.
138 |
# File 'lib/cadenya/models/ai_provider_key_spec.rb', line 138 optional :api_key, -> { Cadenya::AIProviderKeySpec::Credentials::APIKey }, api_name: :apiKey |
#headers ⇒ Cadenya::Models::AIProviderKeySpec::Credentials::Headers?
CredentialHeaders carries arbitrary HTTP headers sent with every request to the provider (e.g. "Bearer ...", "X-Api-Key": "...").
145 |
# File 'lib/cadenya/models/ai_provider_key_spec.rb', line 145 optional :headers, -> { Cadenya::AIProviderKeySpec::Credentials::Headers } |
Instance Method Details
#to_hash ⇒ {
147 |
# File 'sig/cadenya/models/ai_provider_key_spec.rbs', line 147
def to_hash: -> {
|