Class: Cadenya::Models::APIKey
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::APIKey
- Defined in:
- lib/cadenya/models/api_key.rb
Overview
Instance Attribute Summary collapse
- #info ⇒ Cadenya::Models::APIKeyInfo?
-
#metadata ⇒ Cadenya::Models::AccountResourceMetadata
AccountResourceMetadata is used to represent a resource that is associated to an account but not to a workspace.
-
#spec ⇒ Cadenya::Models::APIKeySpec
Configuration for an API key.
Instance Method Summary collapse
-
#initialize(metadata:, spec:, info: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see APIKey for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(metadata:, spec:, info: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::APIKey for more details.
An API key for the account. Use workspace-association RPCs to grant the key access to specific workspaces; a key with zero workspaces is valid but cannot access workspace-scoped resources.
|
|
# File 'lib/cadenya/models/api_key.rb', line 25
|
Instance Attribute Details
#info ⇒ Cadenya::Models::APIKeyInfo?
23 |
# File 'lib/cadenya/models/api_key.rb', line 23 optional :info, -> { Cadenya::APIKeyInfo } |
#metadata ⇒ Cadenya::Models::AccountResourceMetadata
AccountResourceMetadata is used to represent a resource that is associated to an account but not to a workspace.
12 |
# File 'lib/cadenya/models/api_key.rb', line 12 required :metadata, -> { Cadenya::AccountResourceMetadata } |
#spec ⇒ Cadenya::Models::APIKeySpec
Configuration for an API key.
18 |
# File 'lib/cadenya/models/api_key.rb', line 18 required :spec, -> { Cadenya::APIKeySpec } |