Class: Cadenya::Models::AccountAPI
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::AccountAPI
- Defined in:
- lib/cadenya/models/account.rb
Overview
Instance Attribute Summary collapse
-
#info ⇒ Cadenya::Models::AccountInfo
Server-populated information about the account.
-
#metadata ⇒ Cadenya::Models::AccountResourceMetadata
AccountResourceMetadata is used to represent a resource that is associated to an account but not to a workspace.
-
#spec ⇒ Cadenya::Models::AccountSpec
Configuration for an account.
Instance Method Summary collapse
-
#initialize(info:, metadata:, spec:) ⇒ Object
constructor
Some parameter documentations has been truncated, see AccountAPI for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(info:, metadata:, spec:) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::AccountAPI for more details.
An account, the top-level organizational unit. Contains workspaces and account-wide settings such as the webhook signing secret.
|
|
# File 'lib/cadenya/models/account.rb', line 26
|
Instance Attribute Details
#info ⇒ Cadenya::Models::AccountInfo
Server-populated information about the account.
11 |
# File 'lib/cadenya/models/account.rb', line 11 required :info, -> { Cadenya::AccountInfo } |
#metadata ⇒ Cadenya::Models::AccountResourceMetadata
AccountResourceMetadata is used to represent a resource that is associated to an account but not to a workspace.
18 |
# File 'lib/cadenya/models/account.rb', line 18 required :metadata, -> { Cadenya::AccountResourceMetadata } |
#spec ⇒ Cadenya::Models::AccountSpec
Configuration for an account.
24 |
# File 'lib/cadenya/models/account.rb', line 24 required :spec, -> { Cadenya::AccountSpec } |