Class: Cadenya::Models::AccountResourceMetadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::AccountResourceMetadata
- Defined in:
- lib/cadenya/models/account_resource_metadata.rb
Instance Attribute Summary collapse
-
#external_id ⇒ String?
External ID for the resource (e.g., a workflow ID from an external system).
-
#labels ⇒ Hash{Symbol=>String}?
Arbitrary key-value pairs for categorization and filtering Examples: “production”, “team”: “platform”, “version”: “v2”.
-
#name ⇒ String
Human-readable name for the resource (e.g., “Customer Support Agent”, “Email Tool”) Required for resources that users interact with directly.
Instance Method Summary collapse
-
#initialize(id:, account_id:, name:, profile_id:, external_id: nil, labels: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AccountResourceMetadata for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, account_id:, name:, profile_id:, external_id: nil, labels: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::AccountResourceMetadata for more details.
AccountResourceMetadata is used to represent a resource that is associated to an account but not to a workspace.
|
|
# File 'lib/cadenya/models/account_resource_metadata.rb', line 45
|
Instance Attribute Details
#external_id ⇒ String?
External ID for the resource (e.g., a workflow ID from an external system)
17 |
# File 'lib/cadenya/models/account_resource_metadata.rb', line 17 optional :external_id, String, api_name: :externalId |
#labels ⇒ Hash{Symbol=>String}?
Arbitrary key-value pairs for categorization and filtering Examples: “production”, “team”: “platform”, “version”: “v2”
24 |
# File 'lib/cadenya/models/account_resource_metadata.rb', line 24 optional :labels, Cadenya::Internal::Type::HashOf[String] |
#name ⇒ String
Human-readable name for the resource (e.g., “Customer Support Agent”, “Email Tool”) Required for resources that users interact with directly
11 |
# File 'lib/cadenya/models/account_resource_metadata.rb', line 11 required :name, String |