Class: Cadenya::Models::Agents::AgentVariationInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/agents/agent_variation_info.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Cadenya::Internal::Type::BaseModel

Instance Attribute Details

#created_byCadenya::Models::Profile?

A profile identifies a user or non-human principal (such as an API key) at the account level. Profiles are account-scoped and can be granted access to multiple workspaces.

Returns:



13
# File 'lib/cadenya/models/agents/agent_variation_info.rb', line 13

optional :created_by, -> { Cadenya::Profile }, api_name: :createdBy

#feedback_countInteger?

Total number of objective feedbacks received for this variation

Returns:

  • (Integer, nil)


19
# File 'lib/cadenya/models/agents/agent_variation_info.rb', line 19

optional :feedback_count, Integer, api_name: :feedbackCount

#scoreFloat?

Thompson Sampling score: posterior mean of Beta(ts_alpha, ts_beta). Range [0, 1] where 0.5 = neutral, >0.5 = positive, <0.5 = negative.

Returns:

  • (Float, nil)


26
# File 'lib/cadenya/models/agents/agent_variation_info.rb', line 26

optional :score, Float