Class: Cadenya::Models::Agents::AgentVariationSpec
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Agents::AgentVariationSpec
- Defined in:
- lib/cadenya/models/agents/agent_variation_spec.rb
Instance Attribute Summary collapse
-
#compaction_config ⇒ Cadenya::Models::Agents::AgentVariationSpecCompactionConfig?
CompactionConfig defines how context window compaction behaves for objectives using this variation.
-
#constraints ⇒ Cadenya::Models::Agents::AgentVariationSpecConstraints?
Execution constraints.
-
#description ⇒ String?
Human-readable description of what this variation does or when it should be used.
-
#model_config ⇒ Cadenya::Models::Agents::AgentVariationSpecModelConfig?
ModelConfig defines the model configuration for a variation.
-
#progressive_discovery ⇒ Cadenya::Models::Agents::AgentVariationSpecProgressiveDiscovery?
ProgressiveDiscovery is used to indicate that the agent should automatically discover tools that are not explicitly assigned to it.
-
#system_prompt_template ⇒ String?
Liquid template for the system prompt of objectives using this variation.
-
#user_message_template ⇒ String?
Liquid template for the initial user message of objectives using this variation.
-
#weight ⇒ Integer?
Weight for weighted random selection (>= 0).
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Cadenya::Internal::Type::BaseModel
Instance Attribute Details
#compaction_config ⇒ Cadenya::Models::Agents::AgentVariationSpecCompactionConfig?
CompactionConfig defines how context window compaction behaves for objectives using this variation.
12 13 14 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 12 optional :compaction_config, -> { Cadenya::Agents::AgentVariationSpecCompactionConfig }, api_name: :compactionConfig |
#constraints ⇒ Cadenya::Models::Agents::AgentVariationSpecConstraints?
Execution constraints
20 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 20 optional :constraints, -> { Cadenya::Agents::AgentVariationSpecConstraints } |
#description ⇒ String?
Human-readable description of what this variation does or when it should be used
26 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 26 optional :description, String |
#model_config ⇒ Cadenya::Models::Agents::AgentVariationSpecModelConfig?
ModelConfig defines the model configuration for a variation
32 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 32 optional :model_config, -> { Cadenya::Agents::AgentVariationSpecModelConfig }, api_name: :modelConfig |
#progressive_discovery ⇒ Cadenya::Models::Agents::AgentVariationSpecProgressiveDiscovery?
ProgressiveDiscovery is used to indicate that the agent should automatically discover tools that are not explicitly assigned to it. Max tools is the maximum number of tools that can be discovered per search. Hints are optional hints for tool search. These are used in conjunction with the context-aware tool search and can help select the best tools for the task.
42 43 44 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 42 optional :progressive_discovery, -> { Cadenya::Agents::AgentVariationSpecProgressiveDiscovery }, api_name: :progressiveDiscovery |
#system_prompt_template ⇒ String?
Liquid template for the system prompt of objectives using this variation. Rendered with CreateObjectiveRequest.data into Objective.system_prompt.
51 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 51 optional :system_prompt_template, String, api_name: :systemPromptTemplate |
#user_message_template ⇒ String?
Liquid template for the initial user message of objectives using this variation. Rendered with CreateObjectiveRequest.user_data and becomes the first user message in the LLM chat history. CreateObjectiveRequest.initial_message, when set, overrides the rendered result. If neither this template nor initial_message is present, objective creation is rejected with InvalidArgument.
61 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 61 optional :user_message_template, String, api_name: :userMessageTemplate |
#weight ⇒ Integer?
Weight for weighted random selection (>= 0). P(v) = v.weight / sum(all_weights). Only used when the agent’s variation_selection_mode is WEIGHTED. A weight of 0 means never auto-selected, but can still be chosen explicitly via variation_id on CreateObjectiveRequest.
70 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 70 optional :weight, Integer |