Class: Cadenya::Models::Agents::AgentVariationSpec
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Agents::AgentVariationSpec
- Defined in:
- lib/cadenya/models/agents/agent_variation_spec.rb
Instance Attribute Summary collapse
-
#compaction_config ⇒ Cadenya::Models::Agents::AgentVariationSpecCompactionConfig?
CompactionConfig defines how context window compaction behaves for objectives using this variation.
-
#constraints ⇒ Cadenya::Models::Agents::AgentVariationSpecConstraints?
Execution constraints.
-
#description ⇒ String?
Human-readable description of what this variation does or when it should be used.
-
#enable_episodic_memory ⇒ Boolean?
Enable episodic memory for objectives using this variation.
-
#episodic_memory_ttl ⇒ Integer?
How long episodic memories should be retained.
-
#model_config ⇒ Cadenya::Models::Agents::AgentVariationSpecModelConfig?
ModelConfig defines the model configuration for a variation.
-
#progressive_discovery ⇒ Cadenya::Models::Agents::AgentVariationSpecProgressiveDiscovery?
ProgressiveDiscovery is used to indicate that the agent should automatically discover tools that are not explicitly assigned to it.
-
#prompt ⇒ String?
The system prompt for this variation.
-
#weight ⇒ Integer?
Weight for weighted random selection (>= 0).
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Cadenya::Internal::Type::BaseModel
Instance Attribute Details
#compaction_config ⇒ Cadenya::Models::Agents::AgentVariationSpecCompactionConfig?
CompactionConfig defines how context window compaction behaves for objectives using this variation.
12 13 14 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 12 optional :compaction_config, -> { Cadenya::Agents::AgentVariationSpecCompactionConfig }, api_name: :compactionConfig |
#constraints ⇒ Cadenya::Models::Agents::AgentVariationSpecConstraints?
Execution constraints
20 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 20 optional :constraints, -> { Cadenya::Agents::AgentVariationSpecConstraints } |
#description ⇒ String?
Human-readable description of what this variation does or when it should be used
26 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 26 optional :description, String |
#enable_episodic_memory ⇒ Boolean?
Enable episodic memory for objectives using this variation. When true, the system automatically creates a document namespace for each objective using the objective’s episodic_key as the external_id, allowing the agent to store and retrieve documents specific to that episode.
35 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 35 optional :enable_episodic_memory, Cadenya::Internal::Type::Boolean, api_name: :enableEpisodicMemory |
#episodic_memory_ttl ⇒ Integer?
How long episodic memories should be retained. After this duration, episodic document namespaces can be automatically cleaned up. If not set, episodic memories are retained indefinitely.
43 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 43 optional :episodic_memory_ttl, Integer, api_name: :episodicMemoryTtl |
#model_config ⇒ Cadenya::Models::Agents::AgentVariationSpecModelConfig?
ModelConfig defines the model configuration for a variation
49 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 49 optional :model_config, -> { Cadenya::Agents::AgentVariationSpecModelConfig }, api_name: :modelConfig |
#progressive_discovery ⇒ Cadenya::Models::Agents::AgentVariationSpecProgressiveDiscovery?
ProgressiveDiscovery is used to indicate that the agent should automatically discover tools that are not explicitly assigned to it. Max tools is the maximum number of tools that can be discovered per search. Hints are optional hints for tool search. These are used in conjunction with the context-aware tool search and can help select the best tools for the task.
59 60 61 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 59 optional :progressive_discovery, -> { Cadenya::Agents::AgentVariationSpecProgressiveDiscovery }, api_name: :progressiveDiscovery |
#prompt ⇒ String?
The system prompt for this variation
67 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 67 optional :prompt, String |
#weight ⇒ Integer?
Weight for weighted random selection (>= 0). P(v) = v.weight / sum(all_weights). Only used when the agent’s variation_selection_mode is WEIGHTED. A weight of 0 means never auto-selected, but can still be chosen explicitly via variation_id on CreateObjectiveRequest.
76 |
# File 'lib/cadenya/models/agents/agent_variation_spec.rb', line 76 optional :weight, Integer |