Class: Cadenya::Models::Agents::AgentVariationSpecConstraints
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Agents::AgentVariationSpecConstraints
- Defined in:
- lib/cadenya/models/agents/agent_variation_spec_constraints.rb
Instance Attribute Summary collapse
-
#max_sub_objectives ⇒ Integer?
The maximum number of sub-objectives that can be created.
-
#max_tool_calls ⇒ Integer?
The maximum number of tool calls that can be made.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Cadenya::Internal::Type::BaseModel
Instance Attribute Details
#max_sub_objectives ⇒ Integer?
The maximum number of sub-objectives that can be created. 0 means no limit.
11 |
# File 'lib/cadenya/models/agents/agent_variation_spec_constraints.rb', line 11 optional :max_sub_objectives, Integer, api_name: :maxSubObjectives |
#max_tool_calls ⇒ Integer?
The maximum number of tool calls that can be made. 0 means no limit.
17 |
# File 'lib/cadenya/models/agents/agent_variation_spec_constraints.rb', line 17 optional :max_tool_calls, Integer, api_name: :maxToolCalls |