Class: Cadenya::Models::Agents::AgentVariationSpecModelConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Agents::AgentVariationSpecModelConfig
- Defined in:
- lib/cadenya/models/agents/agent_variation_spec_model_config.rb
Instance Attribute Summary collapse
-
#model_id ⇒ String?
The model identifier in family/model format (e.g., “claude/opus-4.6”, “claude/sonnet-4.5”).
-
#temperature ⇒ Float?
Sampling temperature for model inference (0.0 to 1.0) Lower values produce more deterministic outputs, higher values increase randomness.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Cadenya::Internal::Type::BaseModel
Instance Attribute Details
#model_id ⇒ String?
The model identifier in family/model format (e.g., “claude/opus-4.6”, “claude/sonnet-4.5”)
12 |
# File 'lib/cadenya/models/agents/agent_variation_spec_model_config.rb', line 12 optional :model_id, String, api_name: :modelId |
#temperature ⇒ Float?
Sampling temperature for model inference (0.0 to 1.0) Lower values produce more deterministic outputs, higher values increase randomness
19 |
# File 'lib/cadenya/models/agents/agent_variation_spec_model_config.rb', line 19 optional :temperature, Float |