Class: Cadenya::Models::Agents::AgentVariationSpecProgressiveDiscovery
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Agents::AgentVariationSpecProgressiveDiscovery
- Defined in:
- lib/cadenya/models/agents/agent_variation_spec_progressive_discovery.rb
Instance Attribute Summary collapse
- #hints ⇒ Array<String>?
- #max_tools ⇒ Integer?
-
#rerank_threshold ⇒ Float?
Rerank Threshold is an optional value that instructs whether or not to run a search result through a embedding/reranker process which can improve performance and reduce context bloat when tools reach the configured threshold.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Cadenya::Internal::Type::BaseModel
Instance Attribute Details
#hints ⇒ Array<String>?
10 |
# File 'lib/cadenya/models/agents/agent_variation_spec_progressive_discovery.rb', line 10 optional :hints, Cadenya::Internal::Type::ArrayOf[String] |
#max_tools ⇒ Integer?
15 |
# File 'lib/cadenya/models/agents/agent_variation_spec_progressive_discovery.rb', line 15 optional :max_tools, Integer, api_name: :maxTools |
#rerank_threshold ⇒ Float?
Rerank Threshold is an optional value that instructs whether or not to run a search result through a embedding/reranker process which can improve performance and reduce context bloat when tools reach the configured threshold. If a tool match must exceed 0.8, for example, the tool very closely match the query the tool search performed.
25 |
# File 'lib/cadenya/models/agents/agent_variation_spec_progressive_discovery.rb', line 25 optional :rerank_threshold, Float, api_name: :rerankThreshold |