Class: Cadenya::Models::Agents::FeedbackListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Agents::FeedbackListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cadenya/models/agents/feedback_list_params.rb
Overview
Defined Under Namespace
Modules: Sentiment
Instance Attribute Summary collapse
- #agent_id ⇒ String
-
#agent_variation_id ⇒ String?
Optional filter to limit results to feedback on objectives run by a single agent variation.
-
#created_after ⇒ Time?
Inclusive lower bound on feedback creation time.
-
#created_before ⇒ Time?
Exclusive upper bound on feedback creation time.
-
#cursor ⇒ String?
Pagination cursor from previous response.
-
#include_info ⇒ Boolean?
When set to true you may use more of your alloted API rate-limit.
-
#limit ⇒ Integer?
Maximum number of results to return.
-
#query ⇒ String?
Free-text search applied to the feedback comment.
-
#sentiment ⇒ Symbol, ...
Filter by sentiment.
- #workspace_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(workspace_id:, agent_id:, agent_variation_id: nil, created_after: nil, created_before: nil, cursor: nil, include_info: nil, limit: nil, query: nil, sentiment: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see FeedbackListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(workspace_id:, agent_id:, agent_variation_id: nil, created_after: nil, created_before: nil, cursor: nil, include_info: nil, limit: nil, query: nil, sentiment: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::Agents::FeedbackListParams for more details.
|
|
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 71
|
Instance Attribute Details
#agent_id ⇒ String
19 |
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 19 required :agent_id, String |
#agent_variation_id ⇒ String?
Optional filter to limit results to feedback on objectives run by a single agent variation. Supports “external_id:” prefix for external IDs.
26 |
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 26 optional :agent_variation_id, String |
#created_after ⇒ Time?
Inclusive lower bound on feedback creation time.
32 |
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 32 optional :created_after, Time |
#created_before ⇒ Time?
Exclusive upper bound on feedback creation time.
38 |
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 38 optional :created_before, Time |
#cursor ⇒ String?
Pagination cursor from previous response.
44 |
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 44 optional :cursor, String |
#include_info ⇒ Boolean?
When set to true you may use more of your alloted API rate-limit
50 |
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 50 optional :include_info, Cadenya::Internal::Type::Boolean |
#limit ⇒ Integer?
Maximum number of results to return.
56 |
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 56 optional :limit, Integer |
#query ⇒ String?
Free-text search applied to the feedback comment. Case-insensitive substring match.
63 |
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 63 optional :query, String |
#sentiment ⇒ Symbol, ...
Filter by sentiment. UNSPECIFIED returns feedback regardless of score.
69 |
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 69 optional :sentiment, enum: -> { Cadenya::Agents::FeedbackListParams::Sentiment } |
#workspace_id ⇒ String
14 |
# File 'lib/cadenya/models/agents/feedback_list_params.rb', line 14 required :workspace_id, String |