Module: Cadenya::Models::Agents::VariationAddAssignmentParams::Body
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/cadenya/models/agents/variation_add_assignment_params.rb,
sig/cadenya/models/agents/variation_add_assignment_params.rbs
Overview
Attach a single tool, tool set, or sub-agent to a variation. Exactly one of the target fields must be set; the assignment kind is inferred from the populated field.
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Cadenya::Models::Agents::AddAgentVariationAssignmentRequestToolID, Cadenya::Models::Agents::AddAgentVariationAssignmentRequestToolSetID, Cadenya::Models::Agents::AddAgentVariationAssignmentRequestSubAgentID)
|
|
# File 'lib/cadenya/models/agents/variation_add_assignment_params.rb', line 62
|
Instance Method Details
#self?.variants ⇒ ::Array[Cadenya::Models::Agents::VariationAddAssignmentParams::body]
51 |
# File 'sig/cadenya/models/agents/variation_add_assignment_params.rbs', line 51
def self?.variants: -> ::Array[Cadenya::Models::Agents::VariationAddAssignmentParams::body]
|