Class: Cadenya::Models::Agents::VariationAssignmentAgent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Agents::VariationAssignmentAgent
- Defined in:
- lib/cadenya/models/agents/variation_assignment_agent.rb,
sig/cadenya/models/agents/variation_assignment_agent.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#agent ⇒ Cadenya::Models::BareMetadata
BareMetadata contains the minimal metadata for a resource: the ID and an optional human-readable name.
-
#id ⇒ String?
readonly
Returns the value of attribute id.
- #type ⇒ Symbol, Cadenya::Models::Agents::VariationAssignmentAgent::Type
Instance Method Summary collapse
- #id ⇒ String readonly
-
#initialize(agent:, type:, id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see VariationAssignmentAgent for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent:, type:, id: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::Agents::VariationAssignmentAgent for more details.
|
|
# File 'lib/cadenya/models/agents/variation_assignment_agent.rb', line 30
|
Instance Attribute Details
#agent ⇒ Cadenya::Models::BareMetadata
BareMetadata contains the minimal metadata for a resource: the ID and an optional human-readable name. These are used for reference fields where the full metadata (account scoping, timestamps, labels, external IDs) is not needed — e.g., the tool references inside an agent variation spec or the tools assigned to an objective. Both fields are server-populated; clients provide IDs through sibling fields rather than by constructing a BareMetadata themselves.
16 |
# File 'lib/cadenya/models/agents/variation_assignment_agent.rb', line 16 required :agent, -> { Cadenya::BareMetadata } |
#id ⇒ String? (readonly)
Returns the value of attribute id.
18 19 20 |
# File 'sig/cadenya/models/agents/variation_assignment_agent.rbs', line 18 def id @id end |
#type ⇒ Symbol, Cadenya::Models::Agents::VariationAssignmentAgent::Type
21 |
# File 'lib/cadenya/models/agents/variation_assignment_agent.rb', line 21 required :type, enum: -> { Cadenya::Agents::VariationAssignmentAgent::Type } |
Instance Method Details
#id= ⇒ String (readonly)
20 |
# File 'sig/cadenya/models/agents/variation_assignment_agent.rbs', line 20
def id=: (String) -> String
|
#to_hash ⇒ {
28 |
# File 'sig/cadenya/models/agents/variation_assignment_agent.rbs', line 28
def to_hash: -> {
|