Class: Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome::Error
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome::Error
- Defined in:
- lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb
Overview
Defined Under Namespace
Classes: Detail
Instance Attribute Summary collapse
-
#code ⇒ Integer?
The status code, which should be an enum value of [google.rpc.Code].
-
#details ⇒ Array<Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome::Error::Detail>?
A list of messages that carry the error details.
-
#message ⇒ String?
A developer-facing error message, which should be in English.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Cadenya::Internal::Type::BaseModel
Instance Attribute Details
#code ⇒ Integer?
The status code, which should be an enum value of [google.rpc.Code].
69 |
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb', line 69 optional :code, Integer |
#details ⇒ Array<Cadenya::Models::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome::Error::Detail>?
A list of messages that carry the error details. There is a common set of message types for APIs to use.
76 77 |
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb', line 76 optional :details, -> { Cadenya::Internal::Type::ArrayOf[Cadenya::BulkWorkspaceResources::BulkWorkspaceApplyResultDataVariationMemoryLayerOutcome::Error::Detail] } |
#message ⇒ String?
A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the
- google.rpc.Status.details][google.rpc.Status.details
-
field, or localized by
the client.
86 |
# File 'lib/cadenya/models/bulk_workspace_resources/bulk_workspace_apply_result_data_variation_memory_layer_outcome.rb', line 86 optional :message, String |