Module: Cadenya::Models::CallableTool
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/cadenya/models/callable_tool.rb,
sig/cadenya/models/callable_tool.rbs
Overview
CallableTool is a union that represents a tool that can be called by an agent. In Cadenya, a tool that is used within an agent objective might be a user-defined tool (IE: MCP, HTTP), another Agent (useful to separate context), or a Cadenya Tool (one Cadenya provides).
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Cadenya::Models::CallableToolTool, Cadenya::Models::CallableToolAgent, Cadenya::Models::CallableToolCadenyaProvidedTool)
|
|
# File 'lib/cadenya/models/callable_tool.rb', line 20
|
Instance Method Details
#self?.variants ⇒ ::Array[Cadenya::Models::callable_tool]
11 |
# File 'sig/cadenya/models/callable_tool.rbs', line 11
def self?.variants: -> ::Array[Cadenya::Models::callable_tool]
|