Class: Cadenya::Models::CallableTool
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::CallableTool
- Defined in:
- lib/cadenya/models/callable_tool.rb
Instance Attribute Summary collapse
-
#agent ⇒ Cadenya::Models::ResourceMetadata?
Standard metadata for persistent, named resources (e.g., agents, tools, prompts).
-
#cadenya_provided_tool ⇒ Cadenya::Models::ResourceMetadata?
Standard metadata for persistent, named resources (e.g., agents, tools, prompts).
-
#tool ⇒ Cadenya::Models::ResourceMetadata?
Standard metadata for persistent, named resources (e.g., agents, tools, prompts).
Instance Method Summary collapse
-
#initialize(agent: nil, cadenya_provided_tool: nil, tool: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CallableTool for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent: nil, cadenya_provided_tool: nil, tool: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::CallableTool for more details.
CallableTool is a union that represents a tool that can be called by an agent. In Cadenya, a tool that is used within an agent objective might be a user-defined tool (IE: MCP, HTTP), another Agent (useful to separate context), or a Cadenya Tool (one Cadenya provides).
|
|
# File 'lib/cadenya/models/callable_tool.rb', line 24
|
Instance Attribute Details
#agent ⇒ Cadenya::Models::ResourceMetadata?
Standard metadata for persistent, named resources (e.g., agents, tools, prompts)
10 |
# File 'lib/cadenya/models/callable_tool.rb', line 10 optional :agent, -> { Cadenya::ResourceMetadata } |
#cadenya_provided_tool ⇒ Cadenya::Models::ResourceMetadata?
Standard metadata for persistent, named resources (e.g., agents, tools, prompts)
16 |
# File 'lib/cadenya/models/callable_tool.rb', line 16 optional :cadenya_provided_tool, -> { Cadenya::ResourceMetadata }, api_name: :cadenyaProvidedTool |
#tool ⇒ Cadenya::Models::ResourceMetadata?
Standard metadata for persistent, named resources (e.g., agents, tools, prompts)
22 |
# File 'lib/cadenya/models/callable_tool.rb', line 22 optional :tool, -> { Cadenya::ResourceMetadata } |