Class: Cadenya::Models::ContextWindowCompacted
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ContextWindowCompacted
- Defined in:
- lib/cadenya/models/context_window_compacted.rb
Instance Attribute Summary collapse
-
#messages_compacted ⇒ Integer?
Number of messages that were compacted.
-
#new_context_window ⇒ Cadenya::Models::ObjectiveContextWindowData?
The new context window created by this compaction.
-
#strategies ⇒ Array<String>?
The strategies that were applied during this compaction.
-
#summary ⇒ String?
The summary generated by the summarization strategy, if used.
Instance Method Summary collapse
- #initialize(messages_compacted: nil, new_context_window: nil, strategies: nil, summary: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(messages_compacted: nil, new_context_window: nil, strategies: nil, summary: nil) ⇒ Object
|
|
# File 'lib/cadenya/models/context_window_compacted.rb', line 30
|
Instance Attribute Details
#messages_compacted ⇒ Integer?
Number of messages that were compacted
10 |
# File 'lib/cadenya/models/context_window_compacted.rb', line 10 optional :messages_compacted, Integer, api_name: :messagesCompacted |
#new_context_window ⇒ Cadenya::Models::ObjectiveContextWindowData?
The new context window created by this compaction
16 |
# File 'lib/cadenya/models/context_window_compacted.rb', line 16 optional :new_context_window, -> { Cadenya::ObjectiveContextWindowData }, api_name: :newContextWindow |
#strategies ⇒ Array<String>?
The strategies that were applied during this compaction
22 |
# File 'lib/cadenya/models/context_window_compacted.rb', line 22 optional :strategies, Cadenya::Internal::Type::ArrayOf[String] |
#summary ⇒ String?
The summary generated by the summarization strategy, if used.
28 |
# File 'lib/cadenya/models/context_window_compacted.rb', line 28 optional :summary, String |