Class: Cadenya::Models::MemoryLayerListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cadenya/models/memory_layer_list_params.rb

Overview

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workspace_id:, bundle_key: nil, cursor: nil, include_info: nil, limit: nil, prefix: nil, query: nil, sort_order: nil, type: nil, request_options: {}) ⇒ Object

Parameters:

  • workspace_id (String)
  • bundle_key (String) (defaults to: nil)

    Filter by bundle_key — return only resources owned by this bundle.

  • cursor (String) (defaults to: nil)

    Pagination cursor from previous response

  • include_info (Boolean) (defaults to: nil)

    When set to true you may use more of your alloted API rate-limit

  • limit (Integer) (defaults to: nil)

    Maximum number of results to return

  • prefix (String) (defaults to: nil)

    Filter expression (query param: prefix)

  • query (String) (defaults to: nil)

    Free-form search query

  • sort_order (String) (defaults to: nil)

    Sort order for results (asc or desc by creation time)

  • type (Symbol, Cadenya::Models::MemoryLayerListParams::Type) (defaults to: nil)

    Filter by layer type

  • request_options (Cadenya::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/cadenya/models/memory_layer_list_params.rb', line 63

Instance Attribute Details

#bundle_keyString?

Filter by bundle_key — return only resources owned by this bundle.

Returns:

  • (String, nil)


19
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 19

optional :bundle_key, String

#cursorString?

Pagination cursor from previous response

Returns:

  • (String, nil)


25
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 25

optional :cursor, String

#include_infoBoolean?

When set to true you may use more of your alloted API rate-limit

Returns:

  • (Boolean, nil)


31
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 31

optional :include_info, Cadenya::Internal::Type::Boolean

#limitInteger?

Maximum number of results to return

Returns:

  • (Integer, nil)


37
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 37

optional :limit, Integer

#prefixString?

Filter expression (query param: prefix)

Returns:

  • (String, nil)


43
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 43

optional :prefix, String

#queryString?

Free-form search query

Returns:

  • (String, nil)


49
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 49

optional :query, String

#sort_orderString?

Sort order for results (asc or desc by creation time)

Returns:

  • (String, nil)


55
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 55

optional :sort_order, String

#typeSymbol, ...

Filter by layer type



61
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 61

optional :type, enum: -> { Cadenya::MemoryLayerListParams::Type }

#workspace_idString

Returns:

  • (String)


13
# File 'lib/cadenya/models/memory_layer_list_params.rb', line 13

required :workspace_id, String