Class: Cadenya::Models::ObjectiveContinueParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cadenya/models/objective_continue_params.rb,
sig/cadenya/models/objective_continue_params.rbs

Overview

See Also:

  • Cadenya::Resources::Objectives#continue

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workspace_id:, objective_id:, enqueue: nil, message: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::ObjectiveContinueParams for more details.

Parameters:

  • workspace_id (String)
  • objective_id (String)
  • enqueue (Boolean) (defaults to: nil)

    When set to true, the message will be enqueued for when the agent loop is availa

  • message (String) (defaults to: nil)

    The message to continue an objective that has completed (or you are enqueing)

  • request_options (Cadenya::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/cadenya/models/objective_continue_params.rb', line 33

Instance Attribute Details

#enqueueBoolean?

When set to true, the message will be enqueued for when the agent loop is available to process it.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


25
# File 'lib/cadenya/models/objective_continue_params.rb', line 25

optional :enqueue, Cadenya::Internal::Type::Boolean

#messageString?

The message to continue an objective that has completed (or you are enqueing)

Parameters:

  • (String)

Returns:

  • (String, nil)


31
# File 'lib/cadenya/models/objective_continue_params.rb', line 31

optional :message, String

#objective_idString

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/cadenya/models/objective_continue_params.rb', line 18

required :objective_id, String

#workspace_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/cadenya/models/objective_continue_params.rb', line 13

required :workspace_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


36
# File 'sig/cadenya/models/objective_continue_params.rbs', line 36

def to_hash: -> {