Class: Cadenya::Models::ObjectiveContinueParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cadenya/models/objective_continue_params.rb

Overview

Defined Under Namespace

Classes: Secret

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Cadenya::Internal::Type::BaseModel

Instance Attribute Details

#enqueueBoolean?

When set to true, the message will be enqueued for when the agent loop is available to process it.

Returns:

  • (Boolean, nil)


25
# File 'lib/cadenya/models/objective_continue_params.rb', line 25

optional :enqueue, Cadenya::Internal::Type::Boolean

#messageString?

The message to continue an objective that has completed (or you are enqueing)

Returns:

  • (String, nil)


31
# File 'lib/cadenya/models/objective_continue_params.rb', line 31

optional :message, String

#objective_idString

Returns:

  • (String)


18
# File 'lib/cadenya/models/objective_continue_params.rb', line 18

required :objective_id, String

#secretsArray<Cadenya::Models::ObjectiveContinueParams::Secret>?

Secrets that should be included with the message. Helpful for when you need to update secrets on the objective (IE: A secret expires and needs to be refreshed)



38
# File 'lib/cadenya/models/objective_continue_params.rb', line 38

optional :secrets, -> { Cadenya::Internal::Type::ArrayOf[Cadenya::ObjectiveContinueParams::Secret] }

#workspace_idString

Returns:

  • (String)


13
# File 'lib/cadenya/models/objective_continue_params.rb', line 13

required :workspace_id, String