Class: Cadenya::Models::ObjectiveEventData
Defined Under Namespace
Classes: Cancelled
Instance Attribute Summary collapse
Instance Method Summary
collapse
-
#initialize(assistant_message: nil, cancelled: nil, context_window_compacted: nil, error: nil, memory_read: nil, sub_objective_created: nil, tool_approval_requested: nil, tool_approved: nil, tool_called: nil, tool_denied: nil, tool_error: nil, tool_result: nil, type: nil, user_message: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ObjectiveEventData for more details.
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(assistant_message: nil, cancelled: nil, context_window_compacted: nil, error: nil, memory_read: nil, sub_objective_created: nil, tool_approval_requested: nil, tool_approved: nil, tool_called: nil, tool_denied: nil, tool_error: nil, tool_result: nil, type: nil, user_message: nil) ⇒ Object
|
# File 'lib/cadenya/models/objective_event_data.rb', line 88
|
Instance Attribute Details
9
|
# File 'lib/cadenya/models/objective_event_data.rb', line 9
optional :assistant_message, -> { Cadenya::AssistantMessage }, api_name: :assistantMessage
|
ObjectiveCancelled is the terminal event written when an objective is cancelled. After this event, the objective is super-terminal: no further iterations, compaction, or continuation are permitted.
17
|
# File 'lib/cadenya/models/objective_event_data.rb', line 17
optional :cancelled, -> { Cadenya::ObjectiveEventData::Cancelled }
|
22
23
24
|
# File 'lib/cadenya/models/objective_event_data.rb', line 22
optional :context_window_compacted,
-> { Cadenya::ContextWindowCompacted },
api_name: :contextWindowCompacted
|
29
|
# File 'lib/cadenya/models/objective_event_data.rb', line 29
optional :error, -> { Cadenya::ObjectiveError }
|
MemoryRead is emitted each time the agent resolves a key against the memory stack and loads an entry. Lookups that miss (key not found in any layer) do not emit this event.
37
|
# File 'lib/cadenya/models/objective_event_data.rb', line 37
optional :memory_read, -> { Cadenya::MemoryRead }, api_name: :memoryRead
|
42
|
# File 'lib/cadenya/models/objective_event_data.rb', line 42
optional :sub_objective_created, -> { Cadenya::SubObjectiveCreated }, api_name: :subObjectiveCreated
|
47
48
49
50
51
|
# File 'lib/cadenya/models/objective_event_data.rb', line 47
optional :tool_approval_requested,
-> {
Cadenya::ToolApprovalRequested
},
api_name: :toolApprovalRequested
|
56
|
# File 'lib/cadenya/models/objective_event_data.rb', line 56
optional :tool_approved, -> { Cadenya::ToolApproved }, api_name: :toolApproved
|
61
|
# File 'lib/cadenya/models/objective_event_data.rb', line 61
optional :tool_called, -> { Cadenya::ToolCalled }, api_name: :toolCalled
|
66
|
# File 'lib/cadenya/models/objective_event_data.rb', line 66
optional :tool_denied, -> { Cadenya::ToolDenied }, api_name: :toolDenied
|
71
|
# File 'lib/cadenya/models/objective_event_data.rb', line 71
optional :tool_error, -> { Cadenya::ToolError }, api_name: :toolError
|
76
|
# File 'lib/cadenya/models/objective_event_data.rb', line 76
optional :tool_result, -> { Cadenya::ToolResult }, api_name: :toolResult
|
#type ⇒ String?
81
|
# File 'lib/cadenya/models/objective_event_data.rb', line 81
optional :type, String
|
86
|
# File 'lib/cadenya/models/objective_event_data.rb', line 86
optional :user_message, -> { Cadenya::UserMessage }, api_name: :userMessage
|