Class: Cadenya::Models::ObjectiveEventData::Finalized
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ObjectiveEventData::Finalized
- Defined in:
- lib/cadenya/models/objective_event_data.rb
Overview
Instance Attribute Summary collapse
-
#output ⇒ Object?
If the objective was created with an output schema, and the agent successfully completed the objective, this field will contain the structured output of the objective.
Instance Method Summary collapse
-
#initialize(output: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Finalized for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(output: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ObjectiveEventData::Finalized for more details.
ObjectiveFinalized is the terminal event written when an objective is finalized. After this event, the objective is super-terminal: no further iterations, compaction, or continuation are permitted.
|
|
# File 'lib/cadenya/models/objective_event_data.rb', line 168
|
Instance Attribute Details
#output ⇒ Object?
If the objective was created with an output schema, and the agent successfully completed the objective, this field will contain the structured output of the objective.
166 |
# File 'lib/cadenya/models/objective_event_data.rb', line 166 optional :output, Cadenya::Internal::Type::Unknown |