Class: Cadenya::Models::ObjectiveInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/objective_info.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent:, agent_variation:, created_by:, current_context_window_id:, effective_memory_stack:, total_context_windows:, total_events:, total_input_tokens:, total_iterations:, total_output_tokens:, total_tool_calls:) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::ObjectiveInfo for more details.

ObjectiveInfo provides read-only aggregated statistics about an objective’s execution

Parameters:

  • agent (Cadenya::Models::ResourceMetadata)

    Standard metadata for persistent, named resources (e.g., agents, tools, prompts)

  • agent_variation (Cadenya::Models::ResourceMetadata)

    Standard metadata for persistent, named resources (e.g., agents, tools, prompts)

  • created_by (Cadenya::Models::Profile)

    A profile identifies a user or non-human principal (such as an API key)

  • current_context_window_id (String)

    ID of the objective’s current (most recent) context window. Hydrated on

  • effective_memory_stack (Array<Cadenya::Models::MemoryReference>)

    The effective memory stack at objective creation time, flattened

  • total_context_windows (Integer)

    Total number of context windows that this objective has generated

  • total_events (Integer)

    Total number of events generated during this objective’s execution

  • total_input_tokens (Integer)

    Total input tokens consumed across all LLM completions across all context window

  • total_iterations (Integer)
  • total_output_tokens (Integer)

    Total output tokens generated across all LLM completions across all context wind

  • total_tool_calls (Integer)

    Total number of tool calls made during execution



# File 'lib/cadenya/models/objective_info.rb', line 83

Instance Attribute Details

#created_byCadenya::Models::Profile

A profile identifies a user or non-human principal (such as an API key) at the account level. Profiles are account-scoped and can be granted access to multiple workspaces.



12
# File 'lib/cadenya/models/objective_info.rb', line 12

required :created_by, -> { Cadenya::Profile }, api_name: :createdBy