Class: Cadenya::Models::ObjectiveListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ObjectiveListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cadenya/models/objective_list_params.rb
Overview
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#agent_id ⇒ String?
Agent ID for filtering.
-
#agent_schedule_id ⇒ String?
Filter to objectives produced by a specific AgentSchedule.
-
#cursor ⇒ String?
Pagination cursor from previous response.
-
#include_info ⇒ Boolean?
When set to true you may use more of your alloted API rate-limit.
-
#limit ⇒ Integer?
Maximum number of results to return.
-
#parent_objective_id ⇒ String?
Optional filters.
- #profile_id ⇒ String?
-
#sort_order ⇒ String?
Sort order for results (asc or desc by creation time).
-
#state ⇒ Symbol, ...
Filter by state.
- #workspace_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(workspace_id:, agent_id: nil, agent_schedule_id: nil, cursor: nil, include_info: nil, limit: nil, parent_objective_id: nil, profile_id: nil, sort_order: nil, state: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ObjectiveListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(workspace_id:, agent_id: nil, agent_schedule_id: nil, cursor: nil, include_info: nil, limit: nil, parent_objective_id: nil, profile_id: nil, sort_order: nil, state: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ObjectiveListParams for more details.
|
|
# File 'lib/cadenya/models/objective_list_params.rb', line 69
|
Instance Attribute Details
#agent_id ⇒ String?
Agent ID for filtering
19 |
# File 'lib/cadenya/models/objective_list_params.rb', line 19 optional :agent_id, String |
#agent_schedule_id ⇒ String?
Filter to objectives produced by a specific AgentSchedule. Accepts canonical as_… form or external_id:<value> form.
26 |
# File 'lib/cadenya/models/objective_list_params.rb', line 26 optional :agent_schedule_id, String |
#cursor ⇒ String?
Pagination cursor from previous response
32 |
# File 'lib/cadenya/models/objective_list_params.rb', line 32 optional :cursor, String |
#include_info ⇒ Boolean?
When set to true you may use more of your alloted API rate-limit
38 |
# File 'lib/cadenya/models/objective_list_params.rb', line 38 optional :include_info, Cadenya::Internal::Type::Boolean |
#limit ⇒ Integer?
Maximum number of results to return
44 |
# File 'lib/cadenya/models/objective_list_params.rb', line 44 optional :limit, Integer |
#parent_objective_id ⇒ String?
Optional filters
50 |
# File 'lib/cadenya/models/objective_list_params.rb', line 50 optional :parent_objective_id, String |
#profile_id ⇒ String?
55 |
# File 'lib/cadenya/models/objective_list_params.rb', line 55 optional :profile_id, String |
#sort_order ⇒ String?
Sort order for results (asc or desc by creation time)
61 |
# File 'lib/cadenya/models/objective_list_params.rb', line 61 optional :sort_order, String |
#state ⇒ Symbol, ...
Filter by state
67 |
# File 'lib/cadenya/models/objective_list_params.rb', line 67 optional :state, enum: -> { Cadenya::ObjectiveListParams::State } |
#workspace_id ⇒ String
13 |
# File 'lib/cadenya/models/objective_list_params.rb', line 13 required :workspace_id, String |