Class: Cadenya::Models::Objectives::ObjectiveToolCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Objectives::ObjectiveToolCall
- Defined in:
- lib/cadenya/models/objectives/objective_tool_call.rb
Overview
Defined Under Namespace
Modules: ExecutionStatus, Status
Instance Attribute Summary collapse
- #data ⇒ Cadenya::Models::Objectives::ObjectiveToolCallData
- #info ⇒ Cadenya::Models::Objectives::ObjectiveToolCallInfo?
-
#metadata ⇒ Cadenya::Models::OperationMetadata
Metadata for ephemeral operations and activities (e.g., objectives, executions, runs).
-
#status ⇒ Symbol, Cadenya::Models::Objectives::ObjectiveToolCall::Status
Current status of the tool call.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(data:, metadata:, status:, execution_status: nil, info: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ObjectiveToolCall for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data:, metadata:, status:, execution_status: nil, info: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::Objectives::ObjectiveToolCall for more details.
ObjectiveToolCall is a record of a tool call made during an objective’s execution. Tool calls are mutable — their status changes as they are approved, denied, or executed.
|
|
# File 'lib/cadenya/models/objectives/objective_tool_call.rb', line 40
|
Instance Attribute Details
#data ⇒ Cadenya::Models::Objectives::ObjectiveToolCallData
11 |
# File 'lib/cadenya/models/objectives/objective_tool_call.rb', line 11 required :data, -> { Cadenya::Objectives::ObjectiveToolCallData } |
#info ⇒ Cadenya::Models::Objectives::ObjectiveToolCallInfo?
29 |
# File 'lib/cadenya/models/objectives/objective_tool_call.rb', line 29 optional :info, -> { Cadenya::Objectives::ObjectiveToolCallInfo } |
#metadata ⇒ Cadenya::Models::OperationMetadata
Metadata for ephemeral operations and activities (e.g., objectives, executions, runs)
18 |
# File 'lib/cadenya/models/objectives/objective_tool_call.rb', line 18 required :metadata, -> { Cadenya::OperationMetadata } |
#status ⇒ Symbol, Cadenya::Models::Objectives::ObjectiveToolCall::Status
Current status of the tool call
24 |
# File 'lib/cadenya/models/objectives/objective_tool_call.rb', line 24 required :status, enum: -> { Cadenya::Objectives::ObjectiveToolCall::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/cadenya/models/objectives/objective_tool_call.rb', line 70
|