Class: Cadenya::Models::Objectives::ObjectiveToolCallData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/objectives/objective_tool_call_data.rb,
sig/cadenya/models/objectives/objective_tool_call_data.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



36
# File 'sig/cadenya/models/objectives/objective_tool_call_data.rbs', line 36

def initialize: (

Instance Attribute Details

#argumentsHash{Symbol=>Object}?

The arguments passed to the tool

Parameters:

  • (::Hash[Symbol, top])

Returns:

  • (Hash{Symbol=>Object}, nil)


20
# File 'lib/cadenya/models/objectives/objective_tool_call_data.rb', line 20

optional :arguments, Cadenya::Internal::Type::HashOf[Cadenya::Internal::Type::Unknown]

#callableCadenya::Models::CallableTool

CallableTool is a union that represents a tool that can be called by an agent. In Cadenya, a tool that is used within an agent objective might be a user-defined tool (IE: MCP, HTTP), another Agent (useful to separate context), or a Cadenya Tool (one Cadenya provides).

Parameters:

Returns:



14
# File 'lib/cadenya/models/objectives/objective_tool_call_data.rb', line 14

required :callable, -> { Cadenya::CallableTool }

#memoString?

A memo supplied by the reviewer when denying the tool call

Parameters:

  • (String)

Returns:

  • (String, nil)


26
# File 'lib/cadenya/models/objectives/objective_tool_call_data.rb', line 26

optional :memo, String

#resolved_secrets::Array[Cadenya::Objectives::ResolvedSecret]? (readonly)

Returns the value of attribute resolved_secrets.

Returns:

  • (::Array[Cadenya::Objectives::ResolvedSecret], nil)


26
27
28
# File 'sig/cadenya/models/objectives/objective_tool_call_data.rbs', line 26

def resolved_secrets
  @resolved_secrets
end

#status_changed_byCadenya::Profile? (readonly)

Returns the value of attribute status_changed_by.

Returns:



32
33
34
# File 'sig/cadenya/models/objectives/objective_tool_call_data.rbs', line 32

def status_changed_by
  @status_changed_by
end

Instance Method Details

#resolved_secrets=Object (readonly)



28
# File 'sig/cadenya/models/objectives/objective_tool_call_data.rbs', line 28

def resolved_secrets=: (

#status_changed_by=Cadenya::Profile (readonly)

Parameters:

Returns:



34
# File 'sig/cadenya/models/objectives/objective_tool_call_data.rbs', line 34

def status_changed_by=: (Cadenya::Profile) -> Cadenya::Profile

#to_hash{

Returns:

  • ({)


44
# File 'sig/cadenya/models/objectives/objective_tool_call_data.rbs', line 44

def to_hash: -> {