Class: Cadenya::Models::Objectives::ObjectiveToolCallData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/objectives/objective_tool_call_data.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Cadenya::Internal::Type::BaseModel

Instance Attribute Details

#argumentsHash{Symbol=>Object}?

The arguments passed to the tool

Returns:

  • (Hash{Symbol=>Object}, nil)


20
# File 'lib/cadenya/models/objectives/objective_tool_call_data.rb', line 20

optional :arguments, Cadenya::Internal::Type::HashOf[Cadenya::Internal::Type::Unknown]

#callableCadenya::Models::CallableTool

CallableTool is a union that represents a tool that can be called by an agent. In Cadenya, a tool that is used within an agent objective might be a user-defined tool (IE: MCP, HTTP), another Agent (useful to separate context), or a Cadenya Tool (one Cadenya provides).



14
# File 'lib/cadenya/models/objectives/objective_tool_call_data.rb', line 14

required :callable, -> { Cadenya::CallableTool }

#memoString?

A memo supplied by the reviewer when denying the tool call

Returns:

  • (String, nil)


26
# File 'lib/cadenya/models/objectives/objective_tool_call_data.rb', line 26

optional :memo, String