Class: Cadenya::Models::Objectives::ToolCallListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Objectives::ToolCallListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cadenya/models/objectives/tool_call_list_params.rb,
sig/cadenya/models/objectives/tool_call_list_params.rbs
Overview
Defined Under Namespace
Modules: ExecutionStatus, Status
Instance Attribute Summary collapse
-
#cursor ⇒ String?
Pagination cursor from previous response.
-
#execution_status ⇒ Symbol, ...
Filter by tool call execution status.
-
#include_info ⇒ Boolean?
When set to true you may use more of your alloted API rate-limit.
-
#limit ⇒ Integer?
Maximum number of results to return.
- #objective_id ⇒ String
-
#status ⇒ Symbol, ...
Filter by tool call status.
- #workspace_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(workspace_id:, objective_id:, cursor: nil, execution_status: nil, include_info: nil, limit: nil, status: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ToolCallListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(workspace_id:, objective_id:, cursor: nil, execution_status: nil, include_info: nil, limit: nil, status: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::Objectives::ToolCallListParams for more details.
|
|
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 53
|
Instance Attribute Details
#cursor ⇒ String?
Pagination cursor from previous response
25 |
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 25 optional :cursor, String |
#execution_status ⇒ Symbol, ...
Filter by tool call execution status. Useful for reverse-harness polling of bare tool calls waiting for externally supplied content (TOOL_CALL_EXECUTION_STATUS_WAITING_FOR_CONTENT).
33 |
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 33 optional :execution_status, enum: -> { Cadenya::Objectives::ToolCallListParams::ExecutionStatus } |
#include_info ⇒ Boolean?
When set to true you may use more of your alloted API rate-limit
39 |
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 39 optional :include_info, Cadenya::Internal::Type::Boolean |
#limit ⇒ Integer?
Maximum number of results to return
45 |
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 45 optional :limit, Integer |
#objective_id ⇒ String
19 |
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 19 required :objective_id, String |
#status ⇒ Symbol, ...
Filter by tool call status
51 |
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 51 optional :status, enum: -> { Cadenya::Objectives::ToolCallListParams::Status } |
#workspace_id ⇒ String
14 |
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 14 required :workspace_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 86
|
Instance Method Details
#to_hash ⇒ {
59 |
# File 'sig/cadenya/models/objectives/tool_call_list_params.rbs', line 59
def to_hash: -> {
|