Class: Cadenya::Models::Objectives::ToolCallListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Objectives::ToolCallListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cadenya/models/objectives/tool_call_list_params.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#cursor ⇒ String?
Pagination cursor from previous response.
-
#include_info ⇒ Boolean?
When set to true you may use more of your alloted API rate-limit.
-
#limit ⇒ Integer?
Maximum number of results to return.
- #objective_id ⇒ String
-
#status ⇒ Symbol, ...
Filter by tool call status.
- #workspace_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(workspace_id:, objective_id:, cursor: nil, include_info: nil, limit: nil, status: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 45
|
Instance Attribute Details
#cursor ⇒ String?
Pagination cursor from previous response
25 |
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 25 optional :cursor, String |
#include_info ⇒ Boolean?
When set to true you may use more of your alloted API rate-limit
31 |
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 31 optional :include_info, Cadenya::Internal::Type::Boolean |
#limit ⇒ Integer?
Maximum number of results to return
37 |
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 37 optional :limit, Integer |
#objective_id ⇒ String
19 |
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 19 required :objective_id, String |
#status ⇒ Symbol, ...
Filter by tool call status
43 |
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 43 optional :status, enum: -> { Cadenya::Objectives::ToolCallListParams::Status } |
#workspace_id ⇒ String
14 |
# File 'lib/cadenya/models/objectives/tool_call_list_params.rb', line 14 required :workspace_id, String |