Class: Cadenya::Models::ResourceMetadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ResourceMetadata
- Defined in:
- lib/cadenya/models/resource_metadata.rb
Instance Attribute Summary collapse
-
#bundle_key ⇒ String?
Optional bundle ownership key.
-
#external_id ⇒ String?
External ID for the resource (e.g., a workflow ID from an external system).
-
#labels ⇒ Hash{Symbol=>String}?
Arbitrary key-value pairs for categorization and filtering Examples: “production”, “team”: “platform”, “version”: “v2”.
-
#name ⇒ String
Human-readable name for the resource (e.g., “Customer Support Agent”, “Email Tool”) Required for resources that users interact with directly.
Instance Method Summary collapse
-
#initialize(id:, account_id:, created_at:, name:, profile_id:, workspace_id:, bundle_key: nil, external_id: nil, labels: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ResourceMetadata for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, account_id:, created_at:, name:, profile_id:, workspace_id:, bundle_key: nil, external_id: nil, labels: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ResourceMetadata for more details.
Standard metadata for persistent, named resources (e.g., agents, tools, prompts)
|
|
# File 'lib/cadenya/models/resource_metadata.rb', line 67
|
Instance Attribute Details
#bundle_key ⇒ String?
Optional bundle ownership key. When set, indicates the resource is managed by a configuration bundle identified by this key. Used by BulkWorkspaceResources.Apply to track which resources belong to which bundle for reconciliation / soft-delete on re-apply.
20 |
# File 'lib/cadenya/models/resource_metadata.rb', line 20 optional :bundle_key, String, api_name: :bundleKey |
#external_id ⇒ String?
External ID for the resource (e.g., a workflow ID from an external system)
26 |
# File 'lib/cadenya/models/resource_metadata.rb', line 26 optional :external_id, String, api_name: :externalId |
#labels ⇒ Hash{Symbol=>String}?
Arbitrary key-value pairs for categorization and filtering Examples: “production”, “team”: “platform”, “version”: “v2”
33 |
# File 'lib/cadenya/models/resource_metadata.rb', line 33 optional :labels, Cadenya::Internal::Type::HashOf[String] |
#name ⇒ String
Human-readable name for the resource (e.g., “Customer Support Agent”, “Email Tool”) Required for resources that users interact with directly
11 |
# File 'lib/cadenya/models/resource_metadata.rb', line 11 required :name, String |