Class: Cadenya::Models::SubAgentUpdated
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::SubAgentUpdated
- Defined in:
- lib/cadenya/models/sub_agent_updated.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#agent ⇒ Cadenya::Models::BareMetadata?
BareMetadata contains the minimal metadata for a resource: the ID and an optional human-readable name.
- #message ⇒ String?
-
#objective ⇒ Cadenya::Models::BareMetadata?
BareMetadata contains the minimal metadata for a resource: the ID and an optional human-readable name.
- #status ⇒ Symbol, ...
Instance Method Summary collapse
-
#initialize(agent: nil, message: nil, objective: nil, status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see SubAgentUpdated for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent: nil, message: nil, objective: nil, status: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::SubAgentUpdated for more details.
|
|
# File 'lib/cadenya/models/sub_agent_updated.rb', line 38
|
Instance Attribute Details
#agent ⇒ Cadenya::Models::BareMetadata?
BareMetadata contains the minimal metadata for a resource: the ID and an optional human-readable name. These are used for reference fields where the full metadata (account scoping, timestamps, labels, external IDs) is not needed —e.g., the tool references inside an agent variation spec or the tools assigned to an objective. Both fields are server-populated; clients provide IDs through sibling fields rather than by constructing a BareMetadata themselves.
15 |
# File 'lib/cadenya/models/sub_agent_updated.rb', line 15 optional :agent, -> { Cadenya::BareMetadata } |
#message ⇒ String?
20 |
# File 'lib/cadenya/models/sub_agent_updated.rb', line 20 optional :message, String |
#objective ⇒ Cadenya::Models::BareMetadata?
BareMetadata contains the minimal metadata for a resource: the ID and an optional human-readable name. These are used for reference fields where the full metadata (account scoping, timestamps, labels, external IDs) is not needed —e.g., the tool references inside an agent variation spec or the tools assigned to an objective. Both fields are server-populated; clients provide IDs through sibling fields rather than by constructing a BareMetadata themselves.
31 |
# File 'lib/cadenya/models/sub_agent_updated.rb', line 31 optional :objective, -> { Cadenya::BareMetadata } |
#status ⇒ Symbol, ...
36 |
# File 'lib/cadenya/models/sub_agent_updated.rb', line 36 optional :status, enum: -> { Cadenya::SubAgentUpdated::Status } |