Class: Cadenya::Models::ToolCalled
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolCalled
- Defined in:
- lib/cadenya/models/tool_called.rb,
sig/cadenya/models/tool_called.rbs
Instance Attribute Summary collapse
-
#tool_call_id ⇒ String?
The ID of the objective tool call record that was executed.
Instance Method Summary collapse
-
#initialize(tool_call_id: nil) ⇒ ToolCalled
constructor
A new instance of ToolCalled.
- #to_hash ⇒ { tool_call_id: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tool_call_id: nil) ⇒ ToolCalled
Returns a new instance of ToolCalled.
|
|
# File 'lib/cadenya/models/tool_called.rb', line 12
|
Instance Attribute Details
#tool_call_id ⇒ String?
The ID of the objective tool call record that was executed.
10 |
# File 'lib/cadenya/models/tool_called.rb', line 10 optional :tool_call_id, String, api_name: :toolCallId |
Instance Method Details
#to_hash ⇒ { tool_call_id: String }
12 |
# File 'sig/cadenya/models/tool_called.rbs', line 12
def to_hash: -> { tool_call_id: String }
|