Class: Cadenya::Models::ToolSetUsage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolSetUsage
- Defined in:
- lib/cadenya/models/tool_set_usage.rb,
sig/cadenya/models/tool_set_usage.rbs
Overview
Constant Summary collapse
- Cadenya =
Instance Attribute Summary collapse
-
#agent ⇒ Cadenya::ResourceMetadata?
readonly
Returns the value of attribute agent.
-
#agent_variation ⇒ Cadenya::ResourceMetadata?
readonly
Returns the value of attribute agent_variation.
-
#assigned_at ⇒ Time
Returns the value of attribute assigned_at.
-
#model ⇒ Cadenya::ResourceMetadata?
readonly
Returns the value of attribute model.
Instance Method Summary collapse
- #agent ⇒ Cadenya::ResourceMetadata readonly
- #agent_variation ⇒ Object readonly
-
#initialize(assigned_at:, agent: nil, agent_variation: nil, model: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ToolSetUsage for more details.
- #model ⇒ Cadenya::ResourceMetadata readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(assigned_at:, agent: nil, agent_variation: nil, model: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ToolSetUsage for more details.
ToolSetUsage describes one agent variation that uses the tool set (or, when filtering by tool, an individual tool within it).
|
|
# File 'lib/cadenya/models/tool_set_usage.rb', line 33
|
Instance Attribute Details
#agent ⇒ Cadenya::ResourceMetadata? (readonly)
Returns the value of attribute agent.
14 15 16 |
# File 'sig/cadenya/models/tool_set_usage.rbs', line 14 def agent @agent end |
#agent_variation ⇒ Cadenya::ResourceMetadata? (readonly)
Returns the value of attribute agent_variation.
18 19 20 |
# File 'sig/cadenya/models/tool_set_usage.rbs', line 18 def agent_variation @agent_variation end |
#assigned_at ⇒ Time
Returns the value of attribute assigned_at.
12 13 14 |
# File 'sig/cadenya/models/tool_set_usage.rbs', line 12 def assigned_at @assigned_at end |
#model ⇒ Cadenya::ResourceMetadata? (readonly)
Returns the value of attribute model.
24 25 26 |
# File 'sig/cadenya/models/tool_set_usage.rbs', line 24 def model @model end |
Instance Method Details
#agent= ⇒ Cadenya::ResourceMetadata (readonly)
16 |
# File 'sig/cadenya/models/tool_set_usage.rbs', line 16
def agent=: (Cadenya::ResourceMetadata) -> Cadenya::ResourceMetadata
|
#agent_variation= ⇒ Object (readonly)
20 |
# File 'sig/cadenya/models/tool_set_usage.rbs', line 20
def agent_variation=: (
|
#model= ⇒ Cadenya::ResourceMetadata (readonly)
26 |
# File 'sig/cadenya/models/tool_set_usage.rbs', line 26
def model=: (Cadenya::ResourceMetadata) -> Cadenya::ResourceMetadata
|
#to_hash ⇒ {
35 |
# File 'sig/cadenya/models/tool_set_usage.rbs', line 35
def to_hash: -> {
|