Class: Cadenya::Models::ToolSets::ConfigHTTP
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolSets::ConfigHTTP
- Defined in:
- lib/cadenya/models/tool_sets/config_http.rb
Defined Under Namespace
Modules: RequestMethod
Instance Attribute Summary collapse
- #headers ⇒ Hash{Symbol=>String}?
- #path ⇒ String?
- #query ⇒ String?
- #request_body_content_type ⇒ String?
-
#request_body_template ⇒ String?
These are only used when the request method is a POST, PUT, or PATCH.
- #request_method ⇒ Symbol, Cadenya::Models::ToolSets::ConfigHTTP::RequestMethod
-
#tool_name ⇒ String?
The tool name (commonly an “operation id” in OpenAPI specs) to call on the HTTP adapter.
Instance Method Summary collapse
-
#initialize(request_method:, headers: nil, path: nil, query: nil, request_body_content_type: nil, request_body_template: nil, tool_name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ConfigHTTP for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(request_method:, headers: nil, path: nil, query: nil, request_body_content_type: nil, request_body_template: nil, tool_name: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ToolSets::ConfigHTTP for more details.
|
|
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 48
|
Instance Attribute Details
#headers ⇒ Hash{Symbol=>String}?
17 |
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 17 optional :headers, Cadenya::Internal::Type::HashOf[String] |
#path ⇒ String?
22 |
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 22 optional :path, String |
#query ⇒ String?
27 |
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 27 optional :query, String |
#request_body_content_type ⇒ String?
32 |
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 32 optional :request_body_content_type, String, api_name: :requestBodyContentType |
#request_body_template ⇒ String?
These are only used when the request method is a POST, PUT, or PATCH
38 |
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 38 optional :request_body_template, String, api_name: :requestBodyTemplate |
#request_method ⇒ Symbol, Cadenya::Models::ToolSets::ConfigHTTP::RequestMethod
10 11 12 |
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 10 required :request_method, enum: -> { Cadenya::ToolSets::ConfigHTTP::RequestMethod }, api_name: :requestMethod |
#tool_name ⇒ String?
The tool name (commonly an “operation id” in OpenAPI specs) to call on the HTTP adapter. This is used to match the tool spec to the correct endpoint on the HTTP adapter. it will be derived from the name of the tool if not provided.
46 |
# File 'lib/cadenya/models/tool_sets/config_http.rb', line 46 optional :tool_name, String, api_name: :toolName |