Class: Cadenya::Models::ToolSets::ToolSpec
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::ToolSets::ToolSpec
- Defined in:
- lib/cadenya/models/tool_sets/tool_spec.rb
Instance Attribute Summary collapse
-
#config ⇒ Cadenya::Models::ToolSets::ToolSpecConfig
Config defines the adapter to use for the tool.
- #description ⇒ String
-
#llm_tool_name ⇒ String?
The name provided to the LLM, which may differ from the metadata.name on the tool.
- #parameters ⇒ Hash{Symbol=>Object}
- #requires_approval ⇒ Boolean
Instance Method Summary collapse
-
#initialize(config:, description:, parameters:, requires_approval:, llm_tool_name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ToolSpec for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(config:, description:, parameters:, requires_approval:, llm_tool_name: nil) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::ToolSets::ToolSpec for more details.
|
|
# File 'lib/cadenya/models/tool_sets/tool_spec.rb', line 39
|
Instance Attribute Details
#config ⇒ Cadenya::Models::ToolSets::ToolSpecConfig
Config defines the adapter to use for the tool. This is used to determine how the tool is called. For example, if the tool is an HTTP tool, the adapter will be Http. If the tool is an inline tool, the adapter will be Inline.
13 |
# File 'lib/cadenya/models/tool_sets/tool_spec.rb', line 13 required :config, -> { Cadenya::ToolSets::ToolSpecConfig } |
#description ⇒ String
18 |
# File 'lib/cadenya/models/tool_sets/tool_spec.rb', line 18 required :description, String |
#llm_tool_name ⇒ String?
The name provided to the LLM, which may differ from the metadata.name on the tool. LLMs have specific length and format requirements, and tool set sources may not comply with them, so Cadenya does its best to format names into a usable format.
37 |
# File 'lib/cadenya/models/tool_sets/tool_spec.rb', line 37 optional :llm_tool_name, String, api_name: :llmToolName |