Class: Cadenya::Models::ToolSets::ToolSpecConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/tool_sets/tool_spec_config.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(http: nil, mcp: nil) ⇒ Object

Config defines the adapter to use for the tool. This is used to determine how the tool is called. For example, if the tool is an HTTP tool, the adapter will be Http. If the tool is an inline tool, the adapter will be Inline.

Parameters:



# File 'lib/cadenya/models/tool_sets/tool_spec_config.rb', line 17

Instance Attribute Details

#httpCadenya::Models::ToolSets::ConfigHTTP?



10
# File 'lib/cadenya/models/tool_sets/tool_spec_config.rb', line 10

optional :http, -> { Cadenya::ToolSets::ConfigHTTP }

#mcpCadenya::Models::ToolSets::ConfigMcp?



15
# File 'lib/cadenya/models/tool_sets/tool_spec_config.rb', line 15

optional :mcp, -> { Cadenya::ToolSets::ConfigMcp }