Class: Cadenya::Models::Upload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::Upload
- Defined in:
- lib/cadenya/models/upload.rb
Overview
Instance Attribute Summary collapse
- #info ⇒ Cadenya::Models::UploadInfo
-
#metadata ⇒ Cadenya::Models::ResourceMetadata
Standard metadata for persistent, named resources (e.g., agents, tools, prompts).
- #spec ⇒ Cadenya::Models::UploadSpec
Instance Method Summary collapse
-
#initialize(info:, metadata:, spec:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Upload for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(info:, metadata:, spec:) ⇒ Object
Some parameter documentations has been truncated, see Cadenya::Models::Upload for more details.
A handle representing a single file upload flow. Clients call CreateUpload to receive a short-lived presigned URL, PUT the file directly to object storage, then reference the upload by id when creating or updating resources that accept binary content.
Uploads are one-shot: once consumed by a creating or updating resource the upload transitions to UPLOAD_STATUS_CONSUMED and cannot be reused. Unused uploads expire and are garbage-collected.
|
|
# File 'lib/cadenya/models/upload.rb', line 23
|
Instance Attribute Details
#info ⇒ Cadenya::Models::UploadInfo
10 |
# File 'lib/cadenya/models/upload.rb', line 10 required :info, -> { Cadenya::UploadInfo } |
#metadata ⇒ Cadenya::Models::ResourceMetadata
Standard metadata for persistent, named resources (e.g., agents, tools, prompts)
16 |
# File 'lib/cadenya/models/upload.rb', line 16 required :metadata, -> { Cadenya::ResourceMetadata } |
#spec ⇒ Cadenya::Models::UploadSpec
21 |
# File 'lib/cadenya/models/upload.rb', line 21 required :spec, -> { Cadenya::UploadSpec } |