Class: Cadenya::Models::Workspace

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cadenya/models/workspace.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(metadata:, spec:) ⇒ Object

Some parameter documentations has been truncated, see Cadenya::Models::Workspace for more details.

Parameters:



# File 'lib/cadenya/models/workspace.rb', line 19

Instance Attribute Details

#metadataCadenya::Models::AccountResourceMetadata

AccountResourceMetadata is used to represent a resource that is associated to an account but not to a workspace.



12
# File 'lib/cadenya/models/workspace.rb', line 12

required :metadata, -> { Cadenya::AccountResourceMetadata }

#specCadenya::Models::WorkspaceSpec



17
# File 'lib/cadenya/models/workspace.rb', line 17

required :spec, -> { Cadenya::WorkspaceSpec }