Class: Cadenya::Models::WorkspaceMember
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cadenya::Models::WorkspaceMember
- Defined in:
- lib/cadenya/models/workspace_member.rb,
sig/cadenya/models/workspace_member.rbs
Instance Attribute Summary collapse
-
#actor_id ⇒ String
Returns the value of attribute actor_id.
-
#added_at ⇒ Time?
readonly
Returns the value of attribute added_at.
-
#email ⇒ String?
readonly
Returns the value of attribute email.
-
#name ⇒ String?
readonly
Returns the value of attribute name.
-
#profile_id ⇒ String
Returns the value of attribute profile_id.
Instance Method Summary collapse
- #added_at ⇒ Time readonly
- #email ⇒ String readonly
-
#initialize(actor_id:, profile_id:, added_at: nil, email: nil, name: nil) ⇒ Object
constructor
A member of a workspace: the profile granted access plus the actor row that links it to the workspace.
- #name ⇒ String readonly
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(actor_id:, profile_id:, added_at: nil, email: nil, name: nil) ⇒ Object
A member of a workspace: the profile granted access plus the actor row that links it to the workspace. Returned by member list/add operations.
|
|
# File 'lib/cadenya/models/workspace_member.rb', line 38
|
Instance Attribute Details
#actor_id ⇒ String
Returns the value of attribute actor_id.
13 14 15 |
# File 'sig/cadenya/models/workspace_member.rbs', line 13 def actor_id @actor_id end |
#added_at ⇒ Time? (readonly)
Returns the value of attribute added_at.
17 18 19 |
# File 'sig/cadenya/models/workspace_member.rbs', line 17 def added_at @added_at end |
#email ⇒ String? (readonly)
Returns the value of attribute email.
21 22 23 |
# File 'sig/cadenya/models/workspace_member.rbs', line 21 def email @email end |
#name ⇒ String? (readonly)
Returns the value of attribute name.
25 26 27 |
# File 'sig/cadenya/models/workspace_member.rbs', line 25 def name @name end |
#profile_id ⇒ String
Returns the value of attribute profile_id.
15 16 17 |
# File 'sig/cadenya/models/workspace_member.rbs', line 15 def profile_id @profile_id end |
Instance Method Details
#added_at= ⇒ Time (readonly)
19 |
# File 'sig/cadenya/models/workspace_member.rbs', line 19
def added_at=: (Time) -> Time
|
#email= ⇒ String (readonly)
23 |
# File 'sig/cadenya/models/workspace_member.rbs', line 23
def email=: (String) -> String
|
#name= ⇒ String (readonly)
27 |
# File 'sig/cadenya/models/workspace_member.rbs', line 27
def name=: (String) -> String
|
#to_hash ⇒ {
37 |
# File 'sig/cadenya/models/workspace_member.rbs', line 37
def to_hash: -> {
|