Class: Cadenya::Resources::Objectives
- Inherits:
-
Object
- Object
- Cadenya::Resources::Objectives
- Defined in:
- lib/cadenya/resources/objectives.rb,
lib/cadenya/resources/objectives/tasks.rb,
lib/cadenya/resources/objectives/tools.rb,
lib/cadenya/resources/objectives/feedback.rb,
lib/cadenya/resources/objectives/tool_calls.rb
Defined Under Namespace
Classes: Feedback, Tasks, ToolCalls, Tools
Instance Attribute Summary collapse
- #feedback ⇒ Cadenya::Resources::Objectives::Feedback readonly
- #tasks ⇒ Cadenya::Resources::Objectives::Tasks readonly
- #tool_calls ⇒ Cadenya::Resources::Objectives::ToolCalls readonly
- #tools ⇒ Cadenya::Resources::Objectives::Tools readonly
Instance Method Summary collapse
-
#cancel(objective_id, workspace_id:, reason: nil, request_options: {}) ⇒ Cadenya::Models::Objective
Some parameter documentations has been truncated, see Models::ObjectiveCancelParams for more details.
-
#compact(objective_id, workspace_id:, compaction_config: nil, request_options: {}) ⇒ Cadenya::Models::ObjectiveCompactResponse
Some parameter documentations has been truncated, see Models::ObjectiveCompactParams for more details.
-
#continue(objective_id, workspace_id:, enqueue: nil, message: nil, secrets: nil, request_options: {}) ⇒ Cadenya::Models::ObjectiveContinueResponse
Some parameter documentations has been truncated, see Models::ObjectiveContinueParams for more details.
-
#create(workspace_id, agent_id:, data:, metadata:, variation_id: nil, request_options: {}) ⇒ Cadenya::Models::Objective
Some parameter documentations has been truncated, see Models::ObjectiveCreateParams for more details.
-
#initialize(client:) ⇒ Objectives
constructor
private
A new instance of Objectives.
-
#list(workspace_id, agent_id: nil, agent_schedule_id: nil, cursor: nil, include_info: nil, limit: nil, parent_objective_id: nil, profile_id: nil, sort_order: nil, state: nil, request_options: {}) ⇒ Cadenya::Internal::CursorPagination<Cadenya::Models::Objective>
Some parameter documentations has been truncated, see Models::ObjectiveListParams for more details.
-
#list_context_windows(objective_id, workspace_id:, cursor: nil, include_info: nil, limit: nil, request_options: {}) ⇒ Cadenya::Internal::CursorPagination<Cadenya::Models::ObjectiveContextWindow>
Read-only list of the last five windows of execution for this objective, ordered by most recent first.
-
#list_events(objective_id, workspace_id:, cursor: nil, include_info: nil, limit: nil, sort_order: nil, window_id: nil, request_options: {}) ⇒ Cadenya::Internal::CursorPagination<Cadenya::Models::ObjectiveListEventsResponse>
Lists all events for an objective.
-
#retrieve(id, workspace_id:, request_options: {}) ⇒ Cadenya::Models::Objective
Retrieves an objective by ID from the workspace.
Constructor Details
#initialize(client:) ⇒ Objectives
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Objectives.
317 318 319 320 321 322 323 |
# File 'lib/cadenya/resources/objectives.rb', line 317 def initialize(client:) @client = client @tools = Cadenya::Resources::Objectives::Tools.new(client: client) @tool_calls = Cadenya::Resources::Objectives::ToolCalls.new(client: client) @tasks = Cadenya::Resources::Objectives::Tasks.new(client: client) @feedback = Cadenya::Resources::Objectives::Feedback.new(client: client) end |
Instance Attribute Details
#feedback ⇒ Cadenya::Resources::Objectives::Feedback (readonly)
16 17 18 |
# File 'lib/cadenya/resources/objectives.rb', line 16 def feedback @feedback end |
#tasks ⇒ Cadenya::Resources::Objectives::Tasks (readonly)
13 14 15 |
# File 'lib/cadenya/resources/objectives.rb', line 13 def tasks @tasks end |
#tool_calls ⇒ Cadenya::Resources::Objectives::ToolCalls (readonly)
10 11 12 |
# File 'lib/cadenya/resources/objectives.rb', line 10 def tool_calls @tool_calls end |
#tools ⇒ Cadenya::Resources::Objectives::Tools (readonly)
7 8 9 |
# File 'lib/cadenya/resources/objectives.rb', line 7 def tools @tools end |
Instance Method Details
#cancel(objective_id, workspace_id:, reason: nil, request_options: {}) ⇒ Cadenya::Models::Objective
Some parameter documentations has been truncated, see Models::ObjectiveCancelParams for more details.
Cancels a running or pending objective. The objective’s state will be set to STATE_CANCELLED.
147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/cadenya/resources/objectives.rb', line 147 def cancel(objective_id, params) parsed, = Cadenya::ObjectiveCancelParams.dump_request(params) workspace_id = parsed.delete(:workspace_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :post, path: ["v1/workspaces/%1$s/objectives/%2$s/cancel", workspace_id, objective_id], body: parsed, model: Cadenya::Objective, options: ) end |
#compact(objective_id, workspace_id:, compaction_config: nil, request_options: {}) ⇒ Cadenya::Models::ObjectiveCompactResponse
Some parameter documentations has been truncated, see Models::ObjectiveCompactParams for more details.
Triggers compaction on a running objective. Optionally override the variation’s compaction config.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/cadenya/resources/objectives.rb', line 181 def compact(objective_id, params) parsed, = Cadenya::ObjectiveCompactParams.dump_request(params) workspace_id = parsed.delete(:workspace_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :post, path: ["v1/workspaces/%1$s/objectives/%2$s/compact", workspace_id, objective_id], body: parsed, model: Cadenya::Models::ObjectiveCompactResponse, options: ) end |
#continue(objective_id, workspace_id:, enqueue: nil, message: nil, secrets: nil, request_options: {}) ⇒ Cadenya::Models::ObjectiveContinueResponse
Some parameter documentations has been truncated, see Models::ObjectiveContinueParams for more details.
Continues an objective that has completed
218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/cadenya/resources/objectives.rb', line 218 def continue(objective_id, params) parsed, = Cadenya::ObjectiveContinueParams.dump_request(params) workspace_id = parsed.delete(:workspace_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :post, path: ["v1/workspaces/%1$s/objectives/%2$s/continue", workspace_id, objective_id], body: parsed, model: Cadenya::Models::ObjectiveContinueResponse, options: ) end |
#create(workspace_id, agent_id:, data:, metadata:, variation_id: nil, request_options: {}) ⇒ Cadenya::Models::Objective
Some parameter documentations has been truncated, see Models::ObjectiveCreateParams for more details.
Creates a new objective in the workspace
40 41 42 43 44 45 46 47 48 49 |
# File 'lib/cadenya/resources/objectives.rb', line 40 def create(workspace_id, params) parsed, = Cadenya::ObjectiveCreateParams.dump_request(params) @client.request( method: :post, path: ["v1/workspaces/%1$s/objectives", workspace_id], body: parsed, model: Cadenya::Objective, options: ) end |
#list(workspace_id, agent_id: nil, agent_schedule_id: nil, cursor: nil, include_info: nil, limit: nil, parent_objective_id: nil, profile_id: nil, sort_order: nil, state: nil, request_options: {}) ⇒ Cadenya::Internal::CursorPagination<Cadenya::Models::Objective>
Some parameter documentations has been truncated, see Models::ObjectiveListParams for more details.
Lists all objectives in the workspace
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/cadenya/resources/objectives.rb', line 108 def list(workspace_id, params = {}) parsed, = Cadenya::ObjectiveListParams.dump_request(params) query = Cadenya::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: ["v1/workspaces/%1$s/objectives", workspace_id], query: query.transform_keys( agent_id: "agentId", agent_schedule_id: "agentScheduleId", include_info: "includeInfo", parent_objective_id: "parentObjectiveId", profile_id: "profileId", sort_order: "sortOrder" ), page: Cadenya::Internal::CursorPagination, model: Cadenya::Objective, options: ) end |
#list_context_windows(objective_id, workspace_id:, cursor: nil, include_info: nil, limit: nil, request_options: {}) ⇒ Cadenya::Internal::CursorPagination<Cadenya::Models::ObjectiveContextWindow>
Read-only list of the last five windows of execution for this objective, ordered by most recent first
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/cadenya/resources/objectives.rb', line 253 def list_context_windows(objective_id, params) parsed, = Cadenya::ObjectiveListContextWindowsParams.dump_request(params) query = Cadenya::Internal::Util.encode_query_params(parsed) workspace_id = parsed.delete(:workspace_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["v1/workspaces/%1$s/objectives/%2$s/context_windows", workspace_id, objective_id], query: query.transform_keys(include_info: "includeInfo"), page: Cadenya::Internal::CursorPagination, model: Cadenya::ObjectiveContextWindow, options: ) end |
#list_events(objective_id, workspace_id:, cursor: nil, include_info: nil, limit: nil, sort_order: nil, window_id: nil, request_options: {}) ⇒ Cadenya::Internal::CursorPagination<Cadenya::Models::ObjectiveListEventsResponse>
Lists all events for an objective
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/cadenya/resources/objectives.rb', line 293 def list_events(objective_id, params) parsed, = Cadenya::ObjectiveListEventsParams.dump_request(params) query = Cadenya::Internal::Util.encode_query_params(parsed) workspace_id = parsed.delete(:workspace_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["v1/workspaces/%1$s/objectives/%2$s/events", workspace_id, objective_id], query: query.transform_keys( include_info: "includeInfo", sort_order: "sortOrder", window_id: "windowId" ), page: Cadenya::Internal::CursorPagination, model: Cadenya::Models::ObjectiveListEventsResponse, options: ) end |
#retrieve(id, workspace_id:, request_options: {}) ⇒ Cadenya::Models::Objective
Retrieves an objective by ID from the workspace
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/cadenya/resources/objectives.rb', line 62 def retrieve(id, params) parsed, = Cadenya::ObjectiveRetrieveParams.dump_request(params) workspace_id = parsed.delete(:workspace_id) do raise ArgumentError.new("missing required path argument #{_1}") end @client.request( method: :get, path: ["v1/workspaces/%1$s/objectives/%2$s", workspace_id, id], model: Cadenya::Objective, options: ) end |